/*
   Copyright 2020 Siemens Digital Industries Software
   ==================================================
   Copyright 2014.
   Siemens Product Lifecycle Management Software Inc.
   All Rights Reserved.
   ==================================================
   Copyright 2020 Siemens Digital Industries Software
 */


/**
    @file

    This file contains the published identifiers of error codes that can be
    generated by this module. Obtaining and using the numeric values of these
    manifest constants is not supported. We reserve the right to change the
    actual values as necessary.

*/


#ifndef BMIDE_ERRORS_H
#define BMIDE_ERRORS_H

#include <common/emh_const.h>
#include <bmidebase/bmidebase_errors.h>

/**
    @defgroup BMIDE_ERRORS BMIDE Errors
    @ingroup BMIDE
    @{
*/

#define BMIDE_ERROR_BASE                      EMH_BMIDE_error_base

/*
 * RBFUpdaters error messages
 */
#define BMIDE_reqd_buscontext_does_not_exist                (BMIDE_ERROR_BASE + 1)
#define BMIDE_reqd_accessor_does_not_exist                  (BMIDE_ERROR_BASE + 2)
#define BMIDE_typeName_is_null_for_BusinessObject           (BMIDE_ERROR_BASE + 3)

/**
 * BMIDE Updater error messages
 */
#define BMIDE_class_already_exists            (BMIDE_ERROR_BASE + 4)
#define BMIDE_class_does_not_exist            (BMIDE_ERROR_BASE + 5)
#define BMIDE_type_does_not_exist             (BMIDE_ERROR_BASE + 6)
#define BMIDE_type_already_exists             (BMIDE_ERROR_BASE + 7)
#define BMIDE_element_not_leaf_element        (BMIDE_ERROR_BASE + 8)

/**
 * Business Rule related error
 * These errors are common to all business rules
 */
#define BMIDE_business_rule_already_exists    (BMIDE_ERROR_BASE + 9)
#define BMIDE_business_rule_does_not_exist    (BMIDE_ERROR_BASE + 10)
#define BMIDE_business_rule_internal          (BMIDE_ERROR_BASE + 11)
#define BMIDE_business_rule_not_replaceable   (BMIDE_ERROR_BASE + 12)
#define BMIDE_related_rule_element_does_not_exist  (BMIDE_ERROR_BASE + 13)

/**
 * Type Display Rule error messages
 */
#define BMIDE_accessor_does_not_exist         (BMIDE_ERROR_BASE + 14)

/**
 * GRM Rule error messages
 */
#define BMIDE_grm_rule_secured                (BMIDE_ERROR_BASE + 15)
#define BMIDE_grm_relation_does_not_exist     (BMIDE_ERROR_BASE + 16)

/**
 * Class Updater error messages
 */
#define BMIDE_reference_class_does_not_exist  (BMIDE_ERROR_BASE + 17)
#define BMIDE_class_referenced_by_rule_tree   (BMIDE_ERROR_BASE + 18)
#define BMIDE_class_referenced_by_type        (BMIDE_ERROR_BASE + 19)
#define BMIDE_class_referenced_by_form_type   (BMIDE_ERROR_BASE + 20)
#define BMIDE_class_referenced_by_saved_query (BMIDE_ERROR_BASE + 21)
#define BMIDE_class_referenced                (BMIDE_ERROR_BASE + 22)
#define BMIDE_class_not_leaf_class            (BMIDE_ERROR_BASE + 23)

/**
 * Attribute Updater error messages
 */
#define BMIDE_invalid_attribute_type          (BMIDE_ERROR_BASE + 24)
#define BMIDE_invalid_attr_array_length       (BMIDE_ERROR_BASE + 25)
#define BMIDE_invalid_max_string_length       (BMIDE_ERROR_BASE + 26)

/**
 * Generic Element error messages
 */
#define BMIDE_element_already_exists          (BMIDE_ERROR_BASE + 27)
#define BMIDE_element_does_not_exist          (BMIDE_ERROR_BASE + 28)
#define BMIDE_element_referenced              (BMIDE_ERROR_BASE + 29)
#define BMIDE_element_unexpected_input        (BMIDE_ERROR_BASE + 30)
#define BMIDE_related_element_does_not_exist  (BMIDE_ERROR_BASE + 31)
/**
 * Item Element error messages
 */
#define BMIDE_view_type_does_not_exist        (BMIDE_ERROR_BASE + 32)

/**
 * NoteType error messages
 */
#define BMIDE_lov_type_does_not_exist         (BMIDE_ERROR_BASE + 33)

/**
 * Dataset Type error messages
 */
#define BMIDE_dataset_type_edit_tool_req           (BMIDE_ERROR_BASE + 34)
#define BMIDE_dataset_type_tool_does_not_exist     (BMIDE_ERROR_BASE + 35)
#define BMIDE_dataset_type_parent_does_not_exist   (BMIDE_ERROR_BASE + 36)
#define BMIDE_dataset_type_tool_already_exists     (BMIDE_ERROR_BASE + 37)

/**
 * ExtensionAttach error messages
 */
#define BMIDE_operation_does_not_exist                          (BMIDE_ERROR_BASE + 38)
#define BMIDE_operation_invalid_combination                     (BMIDE_ERROR_BASE + 39)
#define BMIDE_extension_point_not_configured                    (BMIDE_ERROR_BASE + 40)
#define BMIDE_extension_point_not_overridable                   (BMIDE_ERROR_BASE + 41)
#define BMIDE_extension_not_valid                               (BMIDE_ERROR_BASE + 42)
#define BMIDE_operation_already_exists                          (BMIDE_ERROR_BASE + 43)
#define BMIDE_extension_point_isactive_flag_already_set         (BMIDE_ERROR_BASE + 44)

/**
 * List of Values error messages
 */
#define BMIDE_lov_value_does_not_exist          (BMIDE_ERROR_BASE + 45)
#define BMIDE_lov_filter_already_exists         (BMIDE_ERROR_BASE + 46)
#define BMIDE_lov_filter_does_not_exist         (BMIDE_ERROR_BASE + 47)
#define BMIDE_lov_usage_not_valid               (BMIDE_ERROR_BASE + 48)
#define BMIDE_lov_name_not_found                (BMIDE_ERROR_BASE + 49)
#define BMIDE_lov_invalid_value                 (BMIDE_ERROR_BASE + 50)
#define BMIDE_lov_value_already_exists          (BMIDE_ERROR_BASE + 51)
#define BMIDE_basedon_lov_does_not_exist        (BMIDE_ERROR_BASE + 52)

/**
 * FormType error messages
 */
#define BMIDE_form_type_does_not_exist         (BMIDE_ERROR_BASE + 53)
#define BMIDE_process_template_does_not_exist  (BMIDE_ERROR_BASE + 54)

/**
 * Property error messages for LOVAttach
 */
#define BMIDE_property_does_not_exist_on_type  (BMIDE_ERROR_BASE + 55)

/**
 * Generic NamingRule error messages
 */
#define BMIDE_namingrule_cannot_DeleteOrModify (BMIDE_ERROR_BASE + 56)

/**
 * Generic NamingRule error messages
 */
#define BMIDE_GRMRule_Check_Failed (BMIDE_ERROR_BASE + 57)

/**
 * Dataset Type error messages
 */
#define BMIDE_dataset_type_reference_already_exists         (BMIDE_ERROR_BASE + 58)
#define BMIDE_dataset_type_reference_does_not_exist         (BMIDE_ERROR_BASE + 59)
#define BMIDE_dataset_type_tool_action_param_already_exists (BMIDE_ERROR_BASE + 60)
#define BMIDE_dataset_type_tool_action_param_does_not_exist (BMIDE_ERROR_BASE + 61)
#define BMIDE_dataset_type_tool_action_ref_already_exists   (BMIDE_ERROR_BASE + 62)
#define BMIDE_dataset_type_tool_action_ref_does_not_exist   (BMIDE_ERROR_BASE + 63)

/**
 * When attachment is found, cannot delete LOV
 */
#define BMIDE_canonot_delete_lov_attach_exist               (BMIDE_ERROR_BASE + 64)

/**
 * AttributeAttach Updater error messages
 */
#define BMIDE_invalid_attribute_on_class                    (BMIDE_ERROR_BASE + 65)
#define BMIDE_attribute_already_exists_on_class             (BMIDE_ERROR_BASE + 66)

/**
 * ToolInputFormatAttachUpdater Updater error messages
 */
#define BMIDE_tool_input_format_does_not_exist              (BMIDE_ERROR_BASE + 67)
#define BMIDE_tool_input_format_already_exists              (BMIDE_ERROR_BASE + 68)

/**
 * ToolOutputFormatAttachUpdater Updater error messages
 */
#define BMIDE_tool_output_format_does_not_exist              (BMIDE_ERROR_BASE + 69)
#define BMIDE_tool_output_format_already_exists              (BMIDE_ERROR_BASE + 70)


/**
 * Change-Type-AttachUpdater Updater error messages
 */
#define BMIDE_Change_form_type_not_attached              (BMIDE_ERROR_BASE + 71)
#define BMIDE_Change_form_type_already_exists            (BMIDE_ERROR_BASE + 72)
#define BMIDE_Change_process_template_not_attached       (BMIDE_ERROR_BASE + 73)
#define BMIDE_Change_process_template_already_exists     (BMIDE_ERROR_BASE + 74)
#define BMIDE_Change_id_format_not_attached              (BMIDE_ERROR_BASE + 75)
#define BMIDE_Change_id_format_not_found                 (BMIDE_ERROR_BASE + 76)
#define BMIDE_Change_id_format_already_exists            (BMIDE_ERROR_BASE + 77)
#define BMIDE_Change_revid_format_not_attached           (BMIDE_ERROR_BASE + 78)
#define BMIDE_Change_revid_format_not_found              (BMIDE_ERROR_BASE + 79)
#define BMIDE_Change_revid_format_already_exists         (BMIDE_ERROR_BASE + 80)
#define BMIDE_Change_id_format_overlaps                  (BMIDE_ERROR_BASE + 81)
#define BMIDE_Change_revid_format_overlaps               (BMIDE_ERROR_BASE + 82)

/**
 * ViewTypeAttachUpdater Updater error messages
 */
#define BMIDE_type_AI_or_IE_does_not_exist               (BMIDE_ERROR_BASE + 83)

/**
 * Businessmodelupdater messages
 */
#define BMIDE_mandatory_element_does_not_exist           (BMIDE_ERROR_BASE + 84)

/**
 * NamingRuleAttachUpdater error messages
 */
#define BMIDE_namingrule_attach_does_not_exist              (BMIDE_ERROR_BASE + 85)
#define BMIDE_namingrule_attach_already_exists              (BMIDE_ERROR_BASE + 86)


#define BMIDE_extension_point_already_attached    (BMIDE_ERROR_BASE + 87)

/**
 * Constants Updaters errors
 */
#define BMIDE_global_const_already_exists         (BMIDE_ERROR_BASE + 88)
#define BMIDE_global_const_does_not_exist         (BMIDE_ERROR_BASE + 89)
#define BMIDE_type_const_already_exists           (BMIDE_ERROR_BASE + 90)
#define BMIDE_type_const_does_not_exist           (BMIDE_ERROR_BASE + 91)
#define BMIDE_property_const_already_exists       (BMIDE_ERROR_BASE + 92)
#define BMIDE_property_const_does_not_exist       (BMIDE_ERROR_BASE + 93)
#define BMIDE_global_const_referenced             (BMIDE_ERROR_BASE + 94)
#define BMIDE_type_const_referenced               (BMIDE_ERROR_BASE + 95)
#define BMIDE_property_const_referenced           (BMIDE_ERROR_BASE + 96)
#define BMIDE_global_constattach_already_exists   (BMIDE_ERROR_BASE + 97)
#define BMIDE_global_constattach_does_not_exist   (BMIDE_ERROR_BASE + 98)
#define BMIDE_type_constattach_already_exists     (BMIDE_ERROR_BASE + 99)
#define BMIDE_type_constattach_does_not_exist     (BMIDE_ERROR_BASE + 100)
#define BMIDE_property_constattach_already_exists (BMIDE_ERROR_BASE + 101)
#define BMIDE_property_constattach_does_not_exist (BMIDE_ERROR_BASE + 102)
#define BMIDE_related_property_on_type_does_not_exist (BMIDE_ERROR_BASE + 103)
#define BMIDE_scopetype_does_not_match            (BMIDE_ERROR_BASE + 104)
#define BMIDE_constant_choice_does_not_match      (BMIDE_ERROR_BASE + 105)
#define BMIDE_scopeproperty_does_not_match        (BMIDE_ERROR_BASE + 106)
#define BMIDE_scope_on_constant_cannot_reduce     (BMIDE_ERROR_BASE + 107)

/**
 * List of Values error messages contd...
 */
#define BMIDE_lov_prop_not_attached          (BMIDE_ERROR_BASE + 108)

/**
 * Generic Element error messages
 */
#define BMIDE_element_skipped_for_missing_type  (BMIDE_ERROR_BASE + 109)

#define BMIDE_namingrule_attach_already_exists2  (BMIDE_ERROR_BASE + 110)

/**
 *Library Updaters errors
 */

#define BMIDE_library_already_exists             (BMIDE_ERROR_BASE + 111)
#define BMIDE_library_does_not_exist              (BMIDE_ERROR_BASE + 112)
#define BMIDE_dependent_library_does_not_exist              (BMIDE_ERROR_BASE + 113)
#define BMIDE_library_createdRelease_does_not_exist              (BMIDE_ERROR_BASE + 114)
#define BMIDE_library_deprecatedRelease_does_not_exist              (BMIDE_ERROR_BASE + 115)
/**
 *Release Updaters errors
 */
#define BMIDE_release_referenced                  (BMIDE_ERROR_BASE + 116)
#define BMIDE_release_does_not_exist              (BMIDE_ERROR_BASE + 117)
#define BMIDE_release_already_exists              (BMIDE_ERROR_BASE + 118)
#define BMIDE_priorRelease_is_NULL                (BMIDE_ERROR_BASE + 119)
/**
 *PrimitiveDataType Updaters errors
 */
#define BMIDE_PrimitiveDataType_already_exists    (BMIDE_ERROR_BASE + 120)
#define BMIDE_PrimitiveDataType_does_not_exist    (BMIDE_ERROR_BASE + 121)
/**
 *ExternalDataType Updaters errors
 */
#define BMIDE_ExternalDataType_already_exists     (BMIDE_ERROR_BASE + 122)
#define BMIDE_ExternalDataType_does_not_exist     (BMIDE_ERROR_BASE + 123)

/**
 *Business Object Interface Updater errors
 */
#define BMIDE_businessobjectinterface_does_not_exist (BMIDE_ERROR_BASE + 124)
#define BMIDE_businessobjectinterface_already_exists (BMIDE_ERROR_BASE + 125)

/**
 *Operation Updaters errors
 */
#define BMIDE_Operation_already_exists                  (BMIDE_ERROR_BASE + 126)
#define BMIDE_Operation_does_not_exist                  (BMIDE_ERROR_BASE + 127)
#define BMIDE_operation_createdRelease_does_not_exist   (BMIDE_ERROR_BASE + 128)
#define BMIDE_operation_BussObjInterface_does_not_exist (BMIDE_ERROR_BASE + 129)


/**
 *MetaOperationAttach
 */
#define BMIDE_operationtemplate_does_not_exist            (BMIDE_ERROR_BASE + 130)
#define BMIDE_operation_attach_does_not_exists            (BMIDE_ERROR_BASE + 131)
#define BMIDE_operation_attach_already_exists             (BMIDE_ERROR_BASE + 132)

/**
 *PropertyOperation Updater errors
 */
#define BMIDE_propertyOperation_already_exists             (BMIDE_ERROR_BASE + 133)
#define BMIDE_PropertyOperation_does_not_exist             (BMIDE_ERROR_BASE + 134)

/**
 *OperationTemplate Updaters errors
 */
#define BMIDE_operationParameter_already_exist           (BMIDE_ERROR_BASE + 135)
#define BMIDE_operationtemplate_already_exists           (BMIDE_ERROR_BASE + 136)
#define BMIDE_metaexception_does_not_exist               (BMIDE_ERROR_BASE + 137)

/**
 *OperationParameter Updaters errors
 */
#define BMIDE_operationparameter_does_not_exist           (BMIDE_ERROR_BASE + 138)
#define BMIDE_DataType_does_not_exist                     (BMIDE_ERROR_BASE + 139)
#define BMIDE_operationDataTypeRef_does_not_exist         (BMIDE_ERROR_BASE + 140)

/**
 *TemplateDataType Updaters errors
 */
#define BMIDE_templateDataType_already_exists             (BMIDE_ERROR_BASE + 141)
#define BMIDE_templateDataType_does_not_exist             (BMIDE_ERROR_BASE + 142)

/**
 *Property Updaters errors
 */
#define BMIDE_property_does_not_exist                     (BMIDE_ERROR_BASE + 143)

/**
 *Condition Updater errors
 */
#define BMIDE_reqd_type_does_not_exist                    (BMIDE_ERROR_BASE + 144)
#define BMIDE_condition_not_changed                       (BMIDE_ERROR_BASE + 145)

/**
 *PropertyAttach and OperationAttach Updater errors
 */
#define BMIDE_operationAttachs_is_not_valid               (BMIDE_ERROR_BASE + 146)
#define BMIDE_operation_attach_getting_parentTypeList_failed             (BMIDE_ERROR_BASE + 147)
#define BMIDE_invalid_property_value_type                 (BMIDE_ERROR_BASE + 148)
#define BMIDE_reference_type_does_not_exist               (BMIDE_ERROR_BASE + 149)
#define BMIDE_property_already_exists_on_type             (BMIDE_ERROR_BASE + 150)
/**
 *RevisionNameRule Updaters errors
 */
#define BMIDE_RevisionNameRule_already_exists             (BMIDE_ERROR_BASE + 151)
#define BMIDE_RevisionNameRule_does_not_exist             (BMIDE_ERROR_BASE + 152)
#define BMIDE_RevisionNameRuleAttach_already_exists       (BMIDE_ERROR_BASE + 153)
#define BMIDE_RevisionNameRuleAttach_does_not_exists      (BMIDE_ERROR_BASE + 154)
#define BMIDE_RevisionNameRuleAttach_obj_creation_error   (BMIDE_ERROR_BASE + 155)
#define BMIDE_RevisionNextId_obj_creation_error           (BMIDE_ERROR_BASE + 156)

/**
 *Service Interface Updater errors
 */
#define BMIDE_serviceinterface_does_not_exist             (BMIDE_ERROR_BASE + 157)
#define BMIDE_serviceinterface_already_exists             (BMIDE_ERROR_BASE + 158)

/**
 *struct Updater errors
 */
#define BMIDE_struct_does_not_exist                       (BMIDE_ERROR_BASE + 159)
#define BMIDE_struct_already_exists                       (BMIDE_ERROR_BASE + 160)

/**
 *typedef Updater errors
 */
#define BMIDE_typedef_does_not_exist                      (BMIDE_ERROR_BASE + 161)
#define BMIDE_typedef_already_exists                      (BMIDE_ERROR_BASE + 162)

/**
 *metaenum Updater errors
 */
#define BMIDE_metaenum_does_not_exist                     (BMIDE_ERROR_BASE + 163)
#define BMIDE_metaenum_already_exists                     (BMIDE_ERROR_BASE + 164)

/**
 *structelement Updater errors
 */
#define BMIDE_structelement_does_not_exist                (BMIDE_ERROR_BASE + 165)
#define BMIDE_structelement_already_exists                (BMIDE_ERROR_BASE + 166)

/**
 *datatyperef Updater errors
 */
#define BMIDE_datatyperef_does_not_exist                  (BMIDE_ERROR_BASE + 167)
#define BMIDE_datatyperef_already_exists                  (BMIDE_ERROR_BASE + 168)

/**
 *metaenum Updater errors
 */
#define BMIDE_metaenumliteral_does_not_exist              (BMIDE_ERROR_BASE + 169)
#define BMIDE_metaenumliteral_already_exists              (BMIDE_ERROR_BASE + 170)

#define BMIDE_condition_does_not_exist                    (BMIDE_ERROR_BASE + 171)

/**
 *DispatcherServiceConfig/IRDC Updater errors
 */
#define BMIDE_updater_specify_not_changed                 (BMIDE_ERROR_BASE + 172)
#define BMIDE_attribute_input_error                       (BMIDE_ERROR_BASE + 173)
#define BMIDE_irdc_same_objcondition_error                (BMIDE_ERROR_BASE + 174)

#define BMIDE_property_update_failure                     (BMIDE_ERROR_BASE + 175)

#define BMIDE_override_can_be_set_only_with_isTrue        (BMIDE_ERROR_BASE + 176)

/**
 * Type updater error messages
 */
#define BMIDE_reference_check_query_execution_failed      (BMIDE_ERROR_BASE + 177)
#define BMIDE_reference_check_query_creation_failed       (BMIDE_ERROR_BASE + 178)

/**
 Constants Updaters errors
 */
#define BMIDE_const_invalid_multi_valued                  (BMIDE_ERROR_BASE + 179)
#define BMIDE_const_invalid_multi_valued2                 (BMIDE_ERROR_BASE + 180)

/**
 * TcDatasetToolActionAttach errors
 */
#define BMIDE_dataset_action_attach_already_deleted        (BMIDE_ERROR_BASE + 181)

/**
 *DispatcherServiceConfig Updater errors
 */
#define BMIDE_dspcfg_same_srcdersortorder_error            (BMIDE_ERROR_BASE + 182)

/**
 *MultiFieldKey Updaters errors
 */
#define BMIDE_MultiFieldKey_value_cannot_change            (BMIDE_ERROR_BASE + 183)

/**
 *MultiFieldKey Updaters errors
 */
#define BMIDE_MultiFieldKey_not_enabled                    (BMIDE_ERROR_BASE + 184)

/**
 *OperationInputType Updater errors
 *The Type Constant Attachment "%1$" cannot be deleted, because the Operation Input Type "%2$" exists in the database. Please delete the Operation Input Type first and try again.
 */
#define BMIDE_operationinputtype_exists                    (BMIDE_ERROR_BASE + 185)

/**
 * TcDatasetToolAttach errors
 */
#define BMIDE_dataset_tool_attach_already_deleted          (BMIDE_ERROR_BASE + 186)

/**
 * SystemStampConfiguration Updater errors
 */
#define BMIDE_systemstampconfig_same_objcondition_error    (BMIDE_ERROR_BASE + 187)

#define BMIDE_property_validation_error_for_type           (BMIDE_ERROR_BASE + 188)
#define BMIDE_property_update_error_for_type               (BMIDE_ERROR_BASE + 189)

/**
 * Bootstrap class skipped error
 */
#define BMIDE_class_is_bootstrap                           (BMIDE_ERROR_BASE + 190)

/**
 * Localization Updater error messages
 */
#define BMIDE_attribute_already_localized_on_class         (BMIDE_ERROR_BASE + 191)
#define BMIDE_attribute_nonlocalizable_on_class            (BMIDE_ERROR_BASE + 192)
#define BMIDE_invalid_localization_status_type             (BMIDE_ERROR_BASE + 193)
#define BMIDE_property_nonlocalizable_on_type              (BMIDE_ERROR_BASE + 194)
#define BMIDE_localization_does_not_exist                  (BMIDE_ERROR_BASE + 195)
#define BMIDE_skip_localization_population                 (BMIDE_ERROR_BASE + 196)
#define BMIDE_locale_to_change_does_not_exist              (BMIDE_ERROR_BASE + 197)
#define BMIDE_locale_to_delete_does_not_exist              (BMIDE_ERROR_BASE + 198)
#define BMIDE_cannot_delete_all_localizations              (BMIDE_ERROR_BASE + 199)
#define BMIDE_element_skipped_for_missing_property         (BMIDE_ERROR_BASE + 200)
#define BMIDE_element_skipped_for_restricted_update_option (BMIDE_ERROR_BASE + 201)

/**
 * Batch LOV error messages
 */
#define BMIDE_batchLOV_delta_not_supported                       (BMIDE_ERROR_BASE + 202)
#define BMIDE_batchLOV_key_data_diff                             (BMIDE_ERROR_BASE + 203)
#define BMIDE_batchLOV_values_ignored                            (BMIDE_ERROR_BASE + 204)
#define BMIDE_batchLOV_sublovvalueattach_ignored                 (BMIDE_ERROR_BASE + 205)
#define BMIDE_batchLOV_localization_ignored                      (BMIDE_ERROR_BASE + 206)
#define BMIDE_batchLOV_locale_not_supported_in_db                (BMIDE_ERROR_BASE + 207)
#define BMIDE_batchLOV_invalid_lov_type                          (BMIDE_ERROR_BASE + 208)

#define BMIDE_lov_value_type_mismatch                            (BMIDE_ERROR_BASE + 209)
#define BMIDE_functionalityrule_create_error                     (BMIDE_ERROR_BASE + 210)
#define BMIDE_functionalityrule_parameters_not_defined           (BMIDE_ERROR_BASE + 211)
#define BMIDE_functionalityrule_signatures_not_defined           (BMIDE_ERROR_BASE + 212)
#define BMIDE_verificationrule_create_error                      (BMIDE_ERROR_BASE + 213)
#define BMIDE_reqd_functionality_does_not_exist                  (BMIDE_ERROR_BASE + 214)
#define BMIDE_reqd_contextfilter_does_not_exist                  (BMIDE_ERROR_BASE + 215)
#define BMIDE_conditionsignatureparameter_does_not_exist         (BMIDE_ERROR_BASE + 216)
#define BMIDE_conditionsignature_does_not_exist                  (BMIDE_ERROR_BASE + 217)
#define BMIDE_conditionsignature_delete_fail                     (BMIDE_ERROR_BASE + 218)

/**
 * BMIDE manage model files error messages
 */
#define BMIDE_missing_login_credentials                           (BMIDE_ERROR_BASE + 219)
#define BMIDE_invalid_option_parameter_value                      (BMIDE_ERROR_BASE + 220)

/**
 * BMIDE cpp test errors
 */
#define BMIDE_cpptest_value_mismatch                              (BMIDE_ERROR_BASE + 221)

/**
 * Class Updater error messages
 */
#define BMIDE_invalid_revisability_option                         (BMIDE_ERROR_BASE + 222)
#define BMIDE_invalid_isPreciseRef_class_not_revisable            (BMIDE_ERROR_BASE + 223)
#define BMIDE_invalid_isPreciseRef_attr_incorrect_type            (BMIDE_ERROR_BASE + 224)
#define BMIDE_class_has_instances                                 (BMIDE_ERROR_BASE + 225)

/**
 * Attribute Updater error messages
 */
#define BMIDE_PreciseRef_update_not_allowed                       (BMIDE_ERROR_BASE + 226)

#define BMIDE_condition_invalid_param_count                       (BMIDE_ERROR_BASE + 227)

/**
 * Tool Updater error message
 */
#define BMIDE_tool_referenced                                     (BMIDE_ERROR_BASE + 228)

/**
 * Dataset Updater error message
 */
#define BMIDE_cannot_delete_dataset_as_instances_exist            (BMIDE_ERROR_BASE + 229)

/**
 * Class Updater error messages
 */
#define BMIDE_parent_class_does_not_exist                         (BMIDE_ERROR_BASE + 230)

/**
 * Type display rule updater error messages
 */
#define BMIDE_unsupported_accessor_type                           (BMIDE_ERROR_BASE + 231)

/**
 * Attribute Attach updater error messages
 */
#define BMIDE_attribute_referenced_by_constantattach              (BMIDE_ERROR_BASE + 232)

/**
 * Property Attach updater error messages
 */
#define BMIDE_property_referenced_by_constantattach               (BMIDE_ERROR_BASE + 233)

/**
 * Type attribute attach updater error messages
 */
#define BMIDE_unsupported_attribute_change                        (BMIDE_ERROR_BASE + 234)

/**
 * Class Updater error message
 * The revisability option "%1$" of the class "%2$" is not compatible with the revisability option "%3$" of its parent class "%4$".
 */
#define BMIDE_incompatible_revisability_option                    (BMIDE_ERROR_BASE + 235)

/**
 * Extension updater validity configured error message
 * The extension validity parameter "%1$" cannot be removed, because it is referenced by an extension attachment for the extension "%2$".
 */
#define BMIDE_extension_validity_configured                       (BMIDE_ERROR_BASE + 236)

/**
 * The property "%1$" cannot be deleted, because it is not owned by the type "%2$".
 */
#define BMIDE_delete_inherited_property                           (BMIDE_ERROR_BASE + 237)

/**
 * A property of type &quot;Table&quot; cannot contain a value for &quot;referencedTypeConstant&quot;. Please contact your Teamcenter administrator.
 */
#define BMIDE_invalid_reftypeconst_for_table_property             (BMIDE_ERROR_BASE + 238)

/**
 * The refernce type of "%1$" is invalid for a property of type "Table". The reference type must be "Fnd0TableRow" or one of its children in that type hierarchy.
 */
#define BMIDE_invalid_table_property_reftype                      (BMIDE_ERROR_BASE + 239)

/**
 * Property Renderer error messages
 */
#define BMIDE_property_renderer_does_not_exist                    (BMIDE_ERROR_BASE + 240)
#define BMIDE_property_renderer_referenced                        (BMIDE_ERROR_BASE + 241)
#define BMIDE_property_renderer_already_exists                    (BMIDE_ERROR_BASE + 242)
#define BMIDE_property_rendererattach_already_exists              (BMIDE_ERROR_BASE + 243)
#define BMIDE_property_rendererattach_does_not_exist              (BMIDE_ERROR_BASE + 244)
#define BMIDE_property_rendererattach_update_not_allowed          (BMIDE_ERROR_BASE + 245)

#define BMIDE_no_initial_value_for_null_attr                      (BMIDE_ERROR_BASE + 246)
/**
 * Class instances loaded while trying to deploy
 */
#define BMIDE_instances_loaded_error                              (BMIDE_ERROR_BASE + 247)
#define BMIDE_subclass_instances_loaded_error                     (BMIDE_ERROR_BASE + 248)

#define BMIDE_mfk_update_not_allowed                              (BMIDE_ERROR_BASE + 249)

/**
 * Attribute Attach updater error messages
 */
#define BMIDE_attribute_referenced_by_localizationattr            (BMIDE_ERROR_BASE + 250)
/**
 * OperationInputType updater error messages
 */
#define BMIDE_operationinputtype_parent_does_not_exist            (BMIDE_ERROR_BASE + 251)

/**
 * LOV updater error messages
 */
#define BMIDE_unsupported_usage_change                            (BMIDE_ERROR_BASE + 252)

/**
 * Type updater error messages
 */
#define BMIDE_type_referenced                                     (BMIDE_ERROR_BASE + 253)
/**
 * Type updater error messages
 */
#define BMIDE_type_parenttype_cannot_change                       (BMIDE_ERROR_BASE + 254)

/**
 * Class updater error message.
 * The subclass "%1$" cannot be added to the class "%2$", because it is a Lightweight Object class.
 */
#define BMIDE_LWO_cannot_have_subclasses                          (BMIDE_ERROR_BASE + 255)

/**
 * Class updater error message.
 * The Lightweight Object class "%1$" must be Uninheritable.
 */
#define BMIDE_LWO_isuninheritable_should_be_set                   (BMIDE_ERROR_BASE + 256)

/**
 * Class updater error message.
 * The Lightweight Object class "%1$" should be either a direct descendent of the "POM_object" class, or
 * the parent class "%2$" should be a direct descendent of the "POM_object" class.
 */
#define BMIDE_LWO_should_be_pomobject_descendent                  (BMIDE_ERROR_BASE + 257)

/**
 * Class updater error message.
 * The parent class "%1$" of a Lightweight Object class such as "%2$" cannot have persistent properties.
 */
#define BMIDE_LWO_parentclass_cannot_have_attributes              (BMIDE_ERROR_BASE + 258)

/**
 * Class updater error message.
 * The attribute "%1$" cannot be altered because the class "%2$" is a Lightweight Object class.
 */
#define BMIDE_LWO_cannot_change_attribute                         (BMIDE_ERROR_BASE + 259)

/**
 * Attribute updater error message.
 * The type for the attribute "%1$" cannot be "character" or "Untyped Reference" for Lightweight Object class.
 */
#define BMIDE_LWO_attr_type_restriction                           (BMIDE_ERROR_BASE + 260)

/**
 * Attribute updater error message.
 * The parameter "NoBackpointer" of the attribute "%1$" cannot be set to "true"
 * because the class "%2$" is a Lightweight Object class.
 */
#define BMIDE_LWO_nobackpointer_restriction                       (BMIDE_ERROR_BASE + 261)

/**
 * Attribute updater error message.
 * The persistent property "%1$" cannot be added to the class "%2$", because the class has Lightweight Object subclasses.
 */
#define BMIDE_LWO_attributes_cannot_be_added_on_parent            (BMIDE_ERROR_BASE + 262)

/**
 * TypeConstant updater error message.
 * The Lightweight Object type "%1$" cannot contain a type constant "MultiFieldKey".
 */
#define BMIDE_LWO_type_constant_restriction                       (BMIDE_ERROR_BASE + 263)

/**
 * PropertyConstant updater error message.
 * The property constant "Localizable" cannot be set to "true" for the properties of Lightweight Object type "%1$".
 */
#define BMIDE_LWO_prop_constant_restriction                       (BMIDE_ERROR_BASE + 264)

/**
 * Type constant attachment defining the MFK is not updated in the restricted_update mode
 */
#define BMIDE_mfk_typeconstantattach_skipped_for_restricted_update  (BMIDE_ERROR_BASE + 265)

/**
 * Dynamic LOV error message
 * The filter attribute "%1$" of the dynamic LOV "%2$" is not available in the database.
 */
#define BMIDE_dlov_searchableAttribute_does_not_exist             (BMIDE_ERROR_BASE + 266)

/**
 * Dynamic LOV error message
 * The attribute "%1$" is already attached to the dynamic LOV "%2$" as an LOV value attribute, description attribute or filter attribute.
 */
#define BMIDE_dlov_attribute_already_attached                     (BMIDE_ERROR_BASE + 267)

/**
 * Dynamic LOV error message
 * The filter attribute "%1$" cannot be changed.
 */
#define BMIDE_dlov_searchableAttribute_can_not_change             (BMIDE_ERROR_BASE + 268)

/**
 * Dynamic LOV error message
 * The dynamic LOV "%1$" cannot be created.
 */
#define BMIDE_dlov_can_not_be_created                             (BMIDE_ERROR_BASE + 269)

/**
 * Dynamic LOV error message
 * The object of the dynamic LOV "%1$" does not exist.
 */
#define BMIDE_dlov_obj_does_not_exist                             (BMIDE_ERROR_BASE + 270)

/**
 * Dynamic LOV error message
 * The dynamic LOV type "%1$" is not valid. Change the type to "Fnd0ListOfvalueDynamic" or any of its sub-types.
 */
#define BMIDE_dlov_type_not_valid                                 (BMIDE_ERROR_BASE + 271)

/**
 * Dynamic LOV error message
 * The type of the dynamic LOV value attribute "%1$" is not valid.
 */
#define BMIDE_dlov_valAttr_type_not_valid                         (BMIDE_ERROR_BASE + 272)

/**
 * Dynamic LOV error message
 * The selected attribute "%1$" must be either persistent or runtime.
 */
#define BMIDE_dlov_attr_is_not_persistent_or_runtime              (BMIDE_ERROR_BASE + 273)

/**
 * Dynamic LOV error message
 * An invalid query clause was detected for the dynamic LOV "%1$".
 */
#define BMIDE_dlov_invalid_query_clause                           (BMIDE_ERROR_BASE + 274)

/**
 * Dynamic LOV error message
 * The type of the dynamic LOV value description attribute "%1$" is not valid.
 */
#define BMIDE_dlov_valDescAttr_type_not_valid                     (BMIDE_ERROR_BASE + 275)

/**
 * Dynamic LOV error message
 * The query for the dynamic LOV has failed to execute. Please refer to the Teamcenter server syslog file for details, and check the query attributes.
 */
#define BMIDE_dlov_failed_to_execute_query                        (BMIDE_ERROR_BASE + 276)

/**
 * Dynamic LOV error message
 * An error has occurred while retrieving properties values. Please contact your Teamcenter administrator.
 */
#define BMIDE_dlov_unable_to_retrieve_properties                  (BMIDE_ERROR_BASE + 277)

/**
 * Naming Rule error message
 * The pattern "%1$" is duplicated in the Naming Rule "%2$". Please remove the duplicate pattern from the Naming Rule.
 */
#define BMIDE_namingrule_duplicate_pattern                        (BMIDE_ERROR_BASE + 278)

/**
 * Property Formatter error message
 * The property formatter "%1$" cannot be deleted, because it is referenced by other data model elements. If this property formatter must be deleted, all references to this property formatter must be removed from the data model definitions (for example, property formatter attachment objects that refer to the property formatter by name).
 */
#define BMIDE_property_formatter_referenced                       (BMIDE_ERROR_BASE + 279)

/**
 * Property Formatter error message
 * The property formatter "%1$" already exists.
 */
#define BMIDE_property_formatter_already_exists                   (BMIDE_ERROR_BASE + 280)

/**
 * Property Formatter Attachment error message
 * The property formatter attachment "%1$" already exists.
 */
#define BMIDE_property_formatterattach_already_exists             (BMIDE_ERROR_BASE + 281)

/**
 * Property Formatter Attachment error message
 * The property formatter attachment "%1$" does not exist.
 */
#define BMIDE_property_formatterattach_does_not_exist             (BMIDE_ERROR_BASE + 282)

/**
 * Property Formatter Attachment error message
 * The deployment contains a "Change" on the property formatter attachment which is not allowed.
 */
#define BMIDE_property_formatterattach_update_not_allowed         (BMIDE_ERROR_BASE + 283)

/**
 * Property Formatter error message
 * The property formatter "%1$" does not exist.
 */
#define BMIDE_property_formatter_does_not_exist                   (BMIDE_ERROR_BASE + 284)

/**
 * Propagation Rule error message
 * The Propagation rule "%1$" cannot be created. Please refer to the Teamcenter server syslog file for details.
 */
#define BMIDE_propagationrule_can_not_be_created                  (BMIDE_ERROR_BASE + 285)

/**
 * Propagation Rule error message
 * The Propagation rule "%1$" does not exist.
 */
#define BMIDE_propagationrule_does_not_exist                      (BMIDE_ERROR_BASE + 286)

/**
 * Propagation Rule error message
 * The Propagation rule "%1$" already exists.
 */
#define BMIDE_propagationrule_already_exists                      (BMIDE_ERROR_BASE + 287)

/**
 * Propagation Rule error message
 * The Relation type "%1$" must be a sub-type of "ImanRelation".
 */
#define BMIDE_propagationrule_relType_is_not_imanrelation_type    (BMIDE_ERROR_BASE + 288)

/**
 * Propagation Rule error message
 * The Propagation Group "%1$" is not valid. It must be a value from the List Of Values (LOV) "Fnd0PropertyGroupNames".
 */
#define BMIDE_propagationrule_invalid_propagation_group           (BMIDE_ERROR_BASE + 289)

/**
 * Propagation Rule error message
 * The relRefPropName attribute "%1$" is not valid. It must be a typed/untyped reference property on the source business object.
 */
#define BMIDE_propagationrule_invalid_reference_property          (BMIDE_ERROR_BASE + 290)

/**
    @defgroup ID_GENERATION_UPDATER_ERRORS Messages related to ID Generation objects
    @{
 */

/**
 * Multiple patterns are found in the Concatenation Rule &quot;%1$&quot;. Only one pattern is allowed per Concatenation Rule.
 */
#define BMIDE_concatenationrule_multiple_patterns_found                             (BMIDE_ERROR_BASE + 291)

/**
 * No valid Concatenation Segment can be found in the Concatenation Rule &quot;%1$&quot;.
 */
#define BMIDE_none_valid_concatenation_segment_found                                (BMIDE_ERROR_BASE + 292)

/**
 * The Concatenation Rule &quot;%1$&quot; already exists.
 */
#define BMIDE_concatenation_rule_already_exists                                     (BMIDE_ERROR_BASE + 293)

/**
 * For the Concatenation Rule &quot;%1$&quot;, Properties are defined, but the Type is not set.
 */
#define BMIDE_concatenation_rule_no_type_defined                                    (BMIDE_ERROR_BASE + 294)

/**
 * No Condition is defined for the Concatenation Rule &quot;%1$&quot;. A Condition element is required for a Concatenation Rule.
 */
#define BMIDE_concatenation_rule_no_condition_defined                               (BMIDE_ERROR_BASE + 295)

/**
 * Update is not allowed on the ID Generation Rule Attachment object &quot;%1$&quot;. Detach the ID Generation Rule and re-create the attachment with the desired ID Generation Rule and Item Type.
 */
#define BMIDE_idgenerationrule_attach_update_not_allowed                            (BMIDE_ERROR_BASE + 296)

/**
 * The Business Object ID Generation Rule Attachment referring to the ID Generation Rule &quot;%1$&quot; and Type &quot;%2$&quot; does not exist.
 */
#define BMIDE_idgenerationrule_attach_does_not_exist                                (BMIDE_ERROR_BASE + 297)

/**
 * The Business Object ID Generation Rule Attachment referring to the ID Generation Rule &quot;%1$&quot; and Type &quot;%2$&quot; already exists.
 */
#define BMIDE_idgenerationrule_attach_already_exists                                (BMIDE_ERROR_BASE + 298)

/**
 * The Business Object Concatenation Rule &quot;%1$&quot; does not exist.
 */
#define BMIDE_concatenation_rule_does_not_exist                                     (BMIDE_ERROR_BASE + 299)

/**
 * For the Business Object Concatenation Rule &quot;%1$&quot;, no Property or Pattern definition can be found in the expression. Delete this Concatenation Rule and re-create it with all the needed information.
 */
#define BMIDE_concatenation_rule_no_property_and_pattern                            (BMIDE_ERROR_BASE + 300)

/**
 * For the Business Object Concatenation Rule &quot;%1$&quot;, Concatenation Expression is erroneous because it contains elements other than a pattern and a property. Delete this Concatenation Rule, and re-create it with all needed information.
 */
#define BMIDE_concatenation_rule_errorneous_expression                              (BMIDE_ERROR_BASE + 301)

/**
 * For the Business Object ID Generation Rule &quot;%1$&quot;, its type is not a sub-type of Base ID Generator.
 */
#define BMIDE_idgeneration_rule_type_not_subtype_of_baseidgenerator                 (BMIDE_ERROR_BASE + 302)

/**
 * For the Business Object ID Generation Rule &quot;%1$&quot;, its type name cannot be changed.
 */
#define BMIDE_idgeneration_rule_type_name_can_not_be_changed                        (BMIDE_ERROR_BASE + 303)

/**
 * For the Business Object ID Generation Rule &quot;%1$&quot;, its name cannot be changed.
 */
#define BMIDE_idgeneration_rule_name_can_not_be_changed                             (BMIDE_ERROR_BASE + 304)

/**
 * The Condition &quot;%1$&quot; does not exist.
 */
#define BMIDE_conditionName_is_null_for_BusinessObject                              (BMIDE_ERROR_BASE + 305)

/**
 * The property &quot;%1$&quot; contains null value for the ID Generation Rule &quot;%2$&quot;.
 */
#define BMIDE_propertyName_is_null_for_BusinessObject                               (BMIDE_ERROR_BASE + 306)

/**
 * Attaching an ID Generation Rule to the property &quot;%1$&quot; is not permitted. An ID Generation Rule can be attached only to the &quot;item_id&quot; property.
 */
#define BMIDE_propertyName_is_not_an_itemid                                         (BMIDE_ERROR_BASE + 307)

/**
 * The Concatenation Rule &quot;%1$&quot; is duplicated in the ID Generation Rule &quot;%2$&quot;. Please remove the duplicate Concatenation Rule from the ID Generation Rule.
 */
#define BMIDE_idgeneration_rule_duplicate_concatenation_rule_entry_found            (BMIDE_ERROR_BASE + 308)

/**
 * At least one Concatenation Rule is required for creating the ID Generation Rule &quot;%1$&quot;.
 */
#define BMIDE_idgeneration_rule_invalid_concatenation_rule_count                    (BMIDE_ERROR_BASE + 309)

/**
 * A duplicate Condition &quot;%1$&quot; is found on the Concatenation Rule &quot;%2$&quot;. Please change the Condition, or remove the ConcatenationRule from the ID Generation Rule &quot;%3$&quot;.
 */
#define BMIDE_concatenation_rule_duplicate_condition_found_on_concatenation_rule    (BMIDE_ERROR_BASE + 310)

/**
 * The required parameter &quot;%1$&quot; is missing for the ID Generation Rule &quot;%2$&quot;.
 */
#define BMIDE_idgeneration_missing_required_parameter                               (BMIDE_ERROR_BASE + 311)

/**
 * The Concatenation Rule &quot;%1$&quot; is invalid, because it contains a Pattern without auto-increment.
 */
#define BMIDE_concatenation_rule_pattern_without_autoincrement                      (BMIDE_ERROR_BASE + 312)

/**
 * An invalid Condition &quot;%1$&quot; is found on the ID Generation Rule Attachment. Ensure to specify the &quot;isTrue&quot; Condition while attaching an ID Generation Rule to an Item Type.
 */
#define BMIDE_idgeneration_rule_attach_invalid_condition_found                      (BMIDE_ERROR_BASE + 313)

/**
 * The Type &quot;%1$&quot; is not a sub-type of Item.
 */
#define BMIDE_idgeneration_rule_attach_type_not_subtype_of_item                     (BMIDE_ERROR_BASE + 314)

/**
 * An invalid override attribute value &quot;%1$&quot; is found while attaching the ID Generation Rule &quot;%2$&quot; to the Business Object &quot;%3$&quot;. Ensure that the override value is set to &quot;false&quot;.
 */
#define BMIDE_idgeneration_rule_attach_override_is_true                             (BMIDE_ERROR_BASE + 315)

/**
 * Changes of value for the &quot;Offset&quot; property in Pattern Counter are not allowed.
 */
#define BMIDE_pattern_counter_offset_cannot_be_changed                              (BMIDE_ERROR_BASE + 316)

/**
 * Changes of value for the property &quot;isDecrement&quot; in Pattern Counter are not allowed.
 */
#define BMIDE_pattern_counter_isDecrement_cannot_be_changed                         (BMIDE_ERROR_BASE + 317)

/**
 * The Concatenation Rule &quot;%1$&quot; contains a pattern with an invalid value for the property Step.
 */
#define BMIDE_concatenationrule_with_pattern_having_invalid_step_found              (BMIDE_ERROR_BASE + 318)

/**
 * The Concatenation Rule &quot;%1$&quot; contains a pattern with an invalid value for the property Offset.
 */
#define BMIDE_concatenationrule_with_pattern_having_invalid_offset_found            (BMIDE_ERROR_BASE + 319)

/**
 * The Concatenation Rule &quot;%1$&quot; has a Condition based on the invalid type &quot;%2$&quot;.
 */
#define BMIDE_concatenationrule_with_condition_based_on_invalid_type                (BMIDE_ERROR_BASE + 320)

/** @} */

/**
 * The reference type value for a "Name-Value" property can only be "Fnd0NameValue".
 */
#define BMIDE_invalid_name_value_property_reftype                                   (BMIDE_ERROR_BASE + 321)

/**
 * The Table property cannot refer to an abstract Business Object.
 */
#define BMIDE_abstract_reftype_not_allowed_in_table_property                        (BMIDE_ERROR_BASE + 322)

/**
 * The class "%1$" cannot be made uninheritable, because it is not a leaf element. Remove the subclasses before attempting to change the specified class to uninheritable.
 */
#define BMIDE_class_cannot_be_uninheritable                                         (BMIDE_ERROR_BASE + 323)

/**
 * The attribute type "%1$" is not supported on Business Objects of type "%2$".
 */
#define BMIDE_unsupported_attribute_type                                            (BMIDE_ERROR_BASE + 324)

/*
 * The client "%1$" cannot be deleted, because it does not exist.
 */
#define BMIDE_client_does_not_exist                                                 (BMIDE_ERROR_BASE + 325)

/*
 * The client "%1$" cannot be deleted, because it is referenced by a client scope. Please remove all the references before deleting the client.
 */
#define BMIDE_client_referenced                                                     (BMIDE_ERROR_BASE + 326)

/*
 * The client cannot be created as specified, because a client with name "%1$" already exists.
 */
#define BMIDE_client_already_exists                                                 (BMIDE_ERROR_BASE + 327)

/*
 * No client scope exists with the URI "%1$".
 */
#define BMIDE_client_scope_does_not_exist                                           (BMIDE_ERROR_BASE + 328)

/*
 * The client scope "%1$" cannot be deleted, because it is referenced. Please remove all the references before deleting the client scope.
 */
#define BMIDE_client_scope_referenced                                               (BMIDE_ERROR_BASE + 329)

/*
 * The command collection "%1$" cannot be deleted, because it is referenced. Please remove all the references before deleting the command collection.
 */
#define BMIDE_command_collection_referenced                                         (BMIDE_ERROR_BASE + 330)

/*
 * No command collection exists with the ID "%1$".
 */
#define BMIDE_command_collection_does_not_exist                                     (BMIDE_ERROR_BASE + 331)

/*
 * No command exists with the ID "%1$".
 */
#define BMIDE_command_does_not_exist                                                (BMIDE_ERROR_BASE + 332)

/*
 * The client "%1$" cannot be deleted, because it is referenced. Please remove all the references before deleting the command.
 */
#define BMIDE_command_referenced                                                    (BMIDE_ERROR_BASE + 333)

/*
 * No icon exists with ID "%1$".
 */
#define BMIDE_icon_does_not_exist                                                   (BMIDE_ERROR_BASE + 334)

/*
 * No command collection attach exists with ID "%1$".
 */
#define BMIDE_command_collection_attach_does_not_exist                              (BMIDE_ERROR_BASE + 335)

/*
 * No command attach exists with ID "%1$".
 */
#define BMIDE_command_attach_does_not_exist                                         (BMIDE_ERROR_BASE + 336)

/*
 * The icon file "%1$" could not be opened.
 */
#define BMIDE_fail_to_open_icon_file                                                (BMIDE_ERROR_BASE + 337)

/*
 * No command condition attach exists with ID "%1$".
 */
#define BMIDE_command_condition_attach_does_not_exist                               (BMIDE_ERROR_BASE + 338)

/*
 * No command condition attach condition with the name "%1$" exists.
 */
#define BMIDE_command_condition_attach_name_does_not_exist                          (BMIDE_ERROR_BASE + 339)

/*
 * A command condition attach of ID "%1$" already exists.
 */
#define BMIDE_command_condition_attach_already_exists                               (BMIDE_ERROR_BASE + 340)

/*
 * A Unit of Measure "%1$" with the same symbol already exists.
 */
#define BMIDE_uom_symbol_already_exists                                             (BMIDE_ERROR_BASE + 341)

/*
 * Type conversion is not allowed because non-augmented stubs exist for the secondary type class "%1$".
 */
#define BMIDE_type_conversion_nonaugmented_stubs_exist                              (BMIDE_ERROR_BASE + 342)

/*
 * Property is source property on Operation Input Type
 */
#define BMIDE_property_is_source_property_on_operationinputtype                     (BMIDE_ERROR_BASE + 343)

/** @} */
#endif
