/*=============================================================================
 Copyright 2020 Siemens Digital Industries Software
 ==================================================
 Copyright 2015
 Siemens Product Lifecycle Management Software Inc.
 All Rights Reserved.
 ==================================================
 Copyright 2020 Siemens Digital Industries Software
 ===============================================================================*/

/**
    @file

    This file contains the published identifiers of error codes that can be
    generated by this module. Obtaining and using the numeric values of these
    manifest constants is not supported. We reserve the right to change the
    actual values as necessary.

*/


#ifndef BMIDEBASE_ERRORS_H
#define BMIDEBASE_ERRORS_H

#include <common/emh_const.h>

/**
    @defgroup BMIDEBASE_ERRORS BMIDE Errors
    @ingroup BMIDEBASE
    @{
*/

#define BMIDEBASE_ERROR_BASE                      EMH_BMIDEBASE_error_base

/**
    @name BMIDE instance delete utility parameter errors
    @{
*/
/**
* The utility "bmide_instance_delete" has identified some instances of the data model to be removed. Please refer to the utility syslog file for more information.
*/
#define BMIDE_bmide_instance_delete_error     (BMIDEBASE_ERROR_BASE + 1)
/**
* An invalid value is specified in the instances parameter "TypeX:ItemX".
*/
#define BMIDE_invalid_instances_parm          (BMIDEBASE_ERROR_BASE + 2)
/**
* The "tcxmlOutput" parameter is required when using the option "-mode=delete".
*/
#define BMIDE_missing_tcxmloutput_parm        (BMIDEBASE_ERROR_BASE + 3)
/**
* An invalid limit parameter value is provided. Valid values are "all" or any integer.
*/
#define BMIDE_invalid_limit_parm              (BMIDEBASE_ERROR_BASE + 4)
/**
* An invalid mode parameter value is provided. Valid values are "count", "delete" and "report".
*/
#define BMIDE_invalid_mode_parm               (BMIDEBASE_ERROR_BASE + 5)
/** @} */

/**
 * BMIDE Updater rollback message
 */
#define BMIDE_rollback                        (BMIDEBASE_ERROR_BASE + 6)

/**
   @name Business Model Updater messages
   @{
*/
#define BMIDE_unprocessed_updaters_exist      (BMIDEBASE_ERROR_BASE + 7)
#define BMIDE_xerces_c_init_error             (BMIDEBASE_ERROR_BASE + 10)
#define BMIDE_cannot_parse_xml_file           (BMIDEBASE_ERROR_BASE + 11)
/** @} */ 

/**
   BMIDE Schema error messages
 */
#define BMIDE_pom_index_definition_error      (BMIDEBASE_ERROR_BASE + 12)

/**
   @name BMIDE Updater error messages
   @{
*/
#define BMIDE_internal_error                  (BMIDEBASE_ERROR_BASE + 13)
#define BMIDE_delta_operation_not_supported   (BMIDEBASE_ERROR_BASE + 14)
/** @} */ 

/**
   @name Event type error messages
   @{
 */
#define BMIDE_eventtype_find_error            (BMIDEBASE_ERROR_BASE + 15)
#define BMIDE_eventtype_create_error          (BMIDEBASE_ERROR_BASE + 16)
#define BMIDE_eventtype_save_error            (BMIDEBASE_ERROR_BASE + 17)
/** @} */ 

/**
   Generic Element error messages
*/
#define BMIDE_element_skipped                 (BMIDEBASE_ERROR_BASE + 18)

/**
  @name Business Model Updater (ITK Main) Log Messages
  @{
*/
#define BMIDE_business_model_updater_failed       (BMIDEBASE_ERROR_BASE + 19)
#define BMIDE_missing_parm_specifier              (BMIDEBASE_ERROR_BASE + 20)
#define BMIDE_missing_mode_parm                   (BMIDEBASE_ERROR_BASE + 21)
#define BMIDE_missing_update_parm                 (BMIDEBASE_ERROR_BASE + 22)
#define BMIDE_missing_file_parm                   (BMIDEBASE_ERROR_BASE + 23)
#define BMIDE_system_init_error                   (BMIDEBASE_ERROR_BASE + 24)
#define BMIDE_init_text_services_error            (BMIDEBASE_ERROR_BASE + 25)
#define BMIDE_login_error                         (BMIDEBASE_ERROR_BASE + 26)
#define BMIDE_failed_to_update                    (BMIDEBASE_ERROR_BASE + 27)
#define BMIDE_reopen_POM_after_schema_mod         (BMIDEBASE_ERROR_BASE + 28)
#define BMIDE_failed_POM_logout                   (BMIDEBASE_ERROR_BASE + 29)
#define BMIDE_failed_ITK_exit_module              (BMIDEBASE_ERROR_BASE + 30)
#define BMIDE_invalid_include_parm                (BMIDEBASE_ERROR_BASE + 31)
#define BMIDE_invalid_include_parm_for_mode       (BMIDEBASE_ERROR_BASE + 32)
#define BMIDE_invalid_lov_parm_for_mode           (BMIDEBASE_ERROR_BASE + 33)
/** @} */ 

/**
   @name Deploy Archive error messages
   @{
*/
/**
   Error creating deployment archive zip file. Please refer to the deploy_archive syslog for details.
*/
#define BMIDE_deploy_archive_error                (BMIDEBASE_ERROR_BASE + 34)

/**
   An invalid archive dataset prefix was specified. Valid values are "bmide" or "tem".
*/
#define BMIDE_invalid_archive_dsn_prefix_error    (BMIDEBASE_ERROR_BASE + 35)

/**
   An invalid archive action was specified. Valid values are "deploy" or "retrieve".
*/
#define BMIDE_invalid_archive_action_error        (BMIDEBASE_ERROR_BASE + 36)

/**
   The required "-dir=" parameter is missing from deploy archive processing.
*/
#define BMIDE_archive_dir_required_error          (BMIDEBASE_ERROR_BASE + 37)

/**
   The optional "-retrieveNum=" parameter must be a numeric value.
*/
#define BMIDE_invalid_retrievenum_error           (BMIDEBASE_ERROR_BASE + 38)

/**
   The date string did not represent a valid date/time stamp. The required format is "yyyy-mm-dd hh:mm:ss".
*/
#define BMIDE_invalid_date_error                  (BMIDEBASE_ERROR_BASE + 39)
/** @} */ 

/**
 @name BMIDE Updater Log Messages
 @{
 */
#define BMIDE_update_option_invalid               (BMIDEBASE_ERROR_BASE + 51)
#define BMIDE_process_option_invalid              (BMIDEBASE_ERROR_BASE + 52)
#define BMIDE_cannot_open_files                   (BMIDEBASE_ERROR_BASE + 53)
#define BMIDE_rollback_state_maybe_affected       (BMIDEBASE_ERROR_BASE + 54)
#define BMIDE_noprocess_due_to_schema_error       (BMIDEBASE_ERROR_BASE + 55)
/** @} */ 

/**
   BMIDE manage templates code
*/
#define BMIDE_no_templates                        (BMIDEBASE_ERROR_BASE + 57)

/**
   @name BMIDE extractor errors
   @{
*/
#define BMIDE_business_model_extractor_failed     (BMIDEBASE_ERROR_BASE + 58)

#define BMIDE_authorization_failed                (BMIDEBASE_ERROR_BASE + 59)

/**
 * Template Removal Validation error message
 * The utility "template_removal_validation" has experienced errors that need to be fixed. Please refer to the utility syslog file for more information.
 */
#define BMIDE_template_removal_validation_error       (BMIDEBASE_ERROR_BASE + 60)
/** @} */ 

/**
  @name Custom Library Loading Error messages
  @{
 */
#define BMIDE_could_not_load_custom_lib               (BMIDEBASE_ERROR_BASE + 61)
#define BMIDE_could_not_find_entrypoint_custom_lib    (BMIDEBASE_ERROR_BASE + 62)
#define BMIDE_directory_does_not_exist                (BMIDEBASE_ERROR_BASE + 63)
#define BMIDE_duplicate_updater_element_registering   (BMIDEBASE_ERROR_BASE + 64)
#define BMIDE_duplicate_extractor_element_registering (BMIDEBASE_ERROR_BASE + 65)
/** @} */ 

/**
   Generic Element error messages
*/
#define BMIDE_cannot_delete_as_references_exist       (BMIDEBASE_ERROR_BASE + 68)

/**
 * Template Removal Validation error message
 * The removal validation for the element of name "%1$" and type "%2$" is not implemented. Removal validation for the model element is skipped.
 */
#define BMIDE_validation_element_skipped              (BMIDEBASE_ERROR_BASE + 69)

/**
 * Template Removal Validation error message
 * Data instances (references) were found in the Teamcenter database for the element of name "%1$" and type "%2$". The delta transaction cannot be processed while these references exist. Please remove them, and try again.
 */
#define BMIDE_validation_references_exist             (BMIDEBASE_ERROR_BASE + 70)

/** @} */
 
/**
 @name Businessmodelupdater messages
 @{
 */
#define BMIDE_processed_but_rollback                    (BMIDEBASE_ERROR_BASE + 71)
#define BMIDE_processed_but_rollback_due_to_save_failed (BMIDEBASE_ERROR_BASE + 72)
/** @} */ 

/**
   @name BMIDE deployment lock utility error messages
   @{
*/
#define BMIDE_missing_required_parameter              (BMIDEBASE_ERROR_BASE + 73)
#define BMIDE_mutually_exclusive_parameter            (BMIDEBASE_ERROR_BASE + 74)
#define BMIDE_sysadmin_access_required                (BMIDEBASE_ERROR_BASE + 75)
#define BMIDE_installed_template_missing              (BMIDEBASE_ERROR_BASE + 76)
#define BMIDE_deployment_online_process_lock          (BMIDEBASE_ERROR_BASE + 77)
#define BMIDE_deployment_offline_process_lock         (BMIDEBASE_ERROR_BASE + 78)
/** @} */ 

/**
 @name BMIDE manage model files error messages
 @{
*/
#define BMIDE_missing_files                           (BMIDEBASE_ERROR_BASE + 79)
#define BMIDE_open_dir_failed                         (BMIDEBASE_ERROR_BASE + 80)
#define BMIDE_version_file_open_error                 (BMIDEBASE_ERROR_BASE + 81)
/** @} */ 

/**
   @name InstalledTemplates code
   @{
*/
#define BMIDE_cant_generate_CS                        (BMIDEBASE_ERROR_BASE + 82)
#define BMIDE_load_instances_failed                   (BMIDEBASE_ERROR_BASE + 83)
/** @} */ 

/**
 @name bmide_manage_templates error strings
 @{
*/
#define BMIDE_max_one_template                        (BMIDEBASE_ERROR_BASE + 84)
#define BMIDE_no_templates_found                      (BMIDEBASE_ERROR_BASE + 85)
/** @} */ 

/**
 @name BMIDE manage model files error messages
 @{
*/
#define BMIDE_invalid_template_found                  (BMIDEBASE_ERROR_BASE + 86)
#define BMIDE_missing_language_files                  (BMIDEBASE_ERROR_BASE + 87)
#define BMIDE_missing_template_files                  (BMIDEBASE_ERROR_BASE + 88)
/** @} */ 

/**
  @name InstalledTemplates code
  @{
*/
#define BMIDE_cant_update_generated_CS                (BMIDEBASE_ERROR_BASE + 89)
/** @} */

/**
 @name Missing temp directory error messages
 @{
*/
#define BMIDE_missing_temp_dir_win                    (BMIDEBASE_ERROR_BASE + 90)
#define BMIDE_missing_temp_dir_unix                   (BMIDEBASE_ERROR_BASE + 91)
/** @} */ 

/**
   @name Invalid file path error messages
   @{
*/
#define BMIDE_invalid_xml_file_path                   (BMIDEBASE_ERROR_BASE + 92)

#define BMIDE_invalid_delta_for_soadeploy             (BMIDEBASE_ERROR_BASE + 93)
/** @} */ 

/**
   @}
*/

#endif
