/*==============================================================================
                Copyright (c) 2003-2005 UGS Corporation
                   Unpublished - All Rights Reserved
 ==============================================================================*/

/**
    @file

    This file contains the publish identifiers of error codes that can be
    generated by this module. Obtaining and using the numeric values of these
    manifest constants is not supported. We reserve the right to change the
    actual values as necessary.
*/

/*  */

#ifndef MATERIALMGMT_ERRORS_HXX
#define MATERIALMGMT_ERRORS_HXX

#include <common/emh_const.h>

/**
    @defgroup MATERIALMGMT_ERRORS Errors
    @ingroup MATERIALMGMT
    @{
*/
/**
    The initialization of the the Material Management module has failed for the class "%1$". Please contact your system administrator.
*/
#define MATERIALMGMT_initialization_failed              (EMH_MATERIALMGMT_error_base + 2)
/**
    Objects of type "%1$" cannot be added to BOM structures.
*/
#define MATERIALMGMT_cannot_add_to_structure            (EMH_MATERIALMGMT_error_base + 4)
/**
    The Part Material relation cannot be deleted because it is active in an external tool.
*/
#define MATERIALMGMT_relation_active_in_external_tool   (EMH_MATERIALMGMT_error_base + 6)
/**
    The entered composition is invalid.
*/
#define MATERIALMGMT_min_composition_error              (EMH_MATERIALMGMT_error_base + 8)
/**
    The maximum composition is invalid.
*/
#define MATERIALMGMT_max_composition_error              (EMH_MATERIALMGMT_error_base + 10)
/**
    The overall minimum composition percent cannot be more than 100.
*/
#define MATERIALMGMT_overall_min_composition_error      (EMH_MATERIALMGMT_error_base + 12)
/**
    The External Identifier "%1$" already exists. External Identifier must be unique.
*/
#define MATERIALMGMT_unique_attribute_duplicate         (EMH_MATERIALMGMT_error_base + 14)
/**
    The current role or group is not part of the material and substance creators.
*/
#define MATERIALMGMT_invalid_material_creator           (EMH_MATERIALMGMT_error_base + 16)
/**
    The minimum or maximum composition must be greater than 0, and less or equal to 100.
*/
#define MATERIALMGMT_percent_composition_error          (EMH_MATERIALMGMT_error_base + 18)
/**
    Either the CAS number or external identifier is missing, or a duplicate entry is found in the input MatML file.
*/
#define MATERIALMGMT_mandatory_field_missing_error      (EMH_MATERIALMGMT_error_base + 20)
/**
    The mass of the material must be greater than 0.
*/
#define MATERIALMGMT_invalid_mass_error                 (EMH_MATERIALMGMT_error_base + 22)
/**
    The number of non-library materials created in Teamcenter is restricted to one. The value defined through the preference "MATERIALMGMT_allow_only_one_non_library_material" restricts the creation of the non-library materials in Teamcenter.
*/
#define MATERIALMGMT_non_library_material_error         (EMH_MATERIALMGMT_error_base + 24)

/**
   The substance "%1$" was not created because the provided Chemical Abstract Service (CAS) number "%2$" is not in a valid format. Please refer to the website "http://www.cas.org".
*/
#define MATERIALMGMT_invalid_CAS_number_error           (EMH_MATERIALMGMT_error_base + 26)
/**
    Compound Materials cannot have materials and substances attached at the same level. If substances need to be attached on a compound material, attach a new material that contains the same substances.
*/
#define MATERIALMGMT_subs_and_mats_error                 (EMH_MATERIALMGMT_error_base + 28)
/**
    The substance "%1$" is already marked as inactive, and cannot therefore be marked as active. In order to use this substance, create a copy of it.
*/
#define MATERIALMGMT_subs_inactive_error                 (EMH_MATERIALMGMT_error_base + 30)
/**
    A cyclic material relation is detected. The material "%1$" is already part of the composition of the material "%2$".
*/
#define MATERIALMGMT_cyclic_material_relation_error      (EMH_MATERIALMGMT_error_base + 32)
/**
    The substance "%1$" is marked as inactive, and should not therefore be part of the composition for any material. Please modify the preference "%2$" if inactive substances need to be attached to materials.
*/
#define MATERIALMGMT_inactive_substance_error            (EMH_MATERIALMGMT_error_base + 34)
/**
    The material "%1$" cannot be attached to itself using the relation "%2$".
*/
#define MATERIALMGMT_self_attach_error                   (EMH_MATERIALMGMT_error_base + 36)
/**
   The material "%1$" was not created because the provided Chemical Abstract Service (CAS) number "%2$" is not in a valid format. Please refer to the website "http://www.cas.org".
*/
#define MATERIALMGMT_material_invalid_cas_number_error   (EMH_MATERIALMGMT_error_base + 38)
/**
    The Unique Identifier "%1$" already exists. Unique Identifier should not duplicate.
*/
#define MATERIALMGMT_material_uniqueid_duplicate         (EMH_MATERIALMGMT_error_base + 40)
/** 
    The CAS "%1$" already exists. CAS number must be unique.
*/
#define MATERIALMGMT_material_cas_duplicate              (EMH_MATERIALMGMT_error_base + 42)
/** 
   The Substance "%1$" was not added to the Material "%2$" because its maximum composition is either invalid or not specified when the composition was marked to be in range. A valid percentage value must be used for the maximum composition while adding the substance.
*/
#define MATERIALMGMT_substance_composition_error         (EMH_MATERIALMGMT_error_base + 44)

/** 
    The composition of "%1$" cannot be modified because this substance is inherited.
*/
#define MATERIALMGMT_inherited_substance_composition_not_modifiable  (EMH_MATERIALMGMT_error_base + 46)

/** 
   The Material "%1$" cannot be part of the composition for any Item Revision because it is marked as inactive. Please modify the value of preference "MATERIALMGMT_allow_inactive_material_use" to attach inactive material to Item Revisions.
*/
#define MATERIALMGMT_inactive_material_error             (EMH_MATERIALMGMT_error_base + 48)

/** 
   The Material "%1$" does not have a density parameter or the parameter density name is not configured. If the parameter density exists please add it to the preference "IMM_PARAMETER_DENSITY" list of values.
*/
#define MATERIALMGMT_density_parameter_not_found         (EMH_MATERIALMGMT_error_base + 49)

/** 
   The unit conversion from "%1$" to "%2$" has failed and the mass will be set to "0.0". Please check if the IMM units exist and are unique.
*/
#define MATERIALMGMT_unit_conversion_failed              (EMH_MATERIALMGMT_error_base + 50)

/**
   No materials are provided for the export operation.
*/
#define MATERIALMGMT_no_materials_selected_for_export    (EMH_MATERIALMGMT_error_base + 51)    

/** @} */
#endif
