/*==============================================================================
                Copyright (c) 2003-2005 UGS Corporation
                   Unpublished - All Rights Reserved
 ==============================================================================*/

/**
    @file

    This file contains the published identifiers of error codes that can be
    generated by this module. Obtaining and using the numeric values of these
    manifest constants is not supported. We reserve the right to change the
    actual values as necessary.

    See prop_errors.uih for error descriptions.
*/

/*  */

#ifndef PROP_ERRORS_H
#define PROP_ERRORS_H

#ifndef EMH_CONST_H
    #include <common/emh_const.h>
#endif

#include <property/libproperty_exports.h>

/**
    @defgroup PROP_ERRORS Errors
    @ingroup PROP
    @{
*/

/** @if DOX_IGNORE
#define PROP_unable_to_create_enq                   (EMH_PROP_error_base + 1)
#define PROP_unable_to_execute_enq                  (EMH_PROP_error_base + 2)
#define PROP_unknown_attr_type                      (EMH_PROP_error_base + 3)
#define PROP_invalid_value                          (EMH_PROP_error_base + 4)
#define PROP_not_a_number                           (EMH_PROP_error_base + 5)
@endif */
#define PROP_not_a_char                             (EMH_PROP_error_base + 6)
#define PROP_not_a_date                             (EMH_PROP_error_base + 7)
#define PROP_not_a_double                           (EMH_PROP_error_base + 8)
#define PROP_not_an_integer                         (EMH_PROP_error_base + 9)
#define PROP_not_a_logical                          (EMH_PROP_error_base + 10)
#define PROP_not_a_conjunction                      (EMH_PROP_error_base + 11)
#define PROP_not_an_operator                        (EMH_PROP_error_base + 12)
#define PROP_no_properties                          (EMH_PROP_error_base + 13)
#define PROP_no_display                             (EMH_PROP_error_base + 14)
#define PROP_not_found                              (EMH_PROP_error_base + 15)

#define PROP_invalid_name                           (EMH_PROP_error_base + 20)
#define PROP_no_attr_defn                           (EMH_PROP_error_base + 21)
#define PROP_invalid_object_type                    (EMH_PROP_error_base + 22)
#define PROP_invalid_relation_type                  (EMH_PROP_error_base + 23)
#define PROP_register_failed                        (EMH_PROP_error_base + 24)
/** @if DOX_IGNORE
#define PROP_unregister_failed                      (EMH_PROP_error_base + 25)
@endif */

#define PROP_type_already_set                       (EMH_PROP_error_base + 26)
#define PROP_invalid_prop_type                      (EMH_PROP_error_base + 27)
#define PROP_value_type_already_set                 (EMH_PROP_error_base + 28)
#define PROP_invalid_value_type                     (EMH_PROP_error_base + 29)
/** The sorting has failed, because the number of properties to use for sorting (%1$) exceeds the maximum allowed number of properties (%2$).*/
#define PROP_sort_with_too_many_properties          (EMH_PROP_error_base + 30)
/** The sorting has failed, because no property is specified to be used for sorting. */
#define PROP_sort_with_no_properties                (EMH_PROP_error_base + 31)

#define PROP_invalid_descriptor                     (EMH_PROP_error_base + 40)
#define PROP_invalid_object                         (EMH_PROP_error_base + 41)
#define PROP_invalid_attr                           (EMH_PROP_error_base + 42)
#define PROP_failed_get_value                       (EMH_PROP_error_base + 43)
#define PROP_null_value                             (EMH_PROP_error_base + 44)
#define PROP_multivalued                            (EMH_PROP_error_base + 45)
#define PROP_singular                               (EMH_PROP_error_base + 46)
#define PROP_cant_alloc_space                       (EMH_PROP_error_base + 47)
#define PROP_value_not_set                          (EMH_PROP_error_base + 48)
#define PROP_not_created                            (EMH_PROP_error_base + 49)

#define PROP_invalid_day                            (EMH_PROP_error_base + 50)
#define PROP_invalid_date_format                    (EMH_PROP_error_base + 51)
#define PROP_invalid_hour                           (EMH_PROP_error_base + 52)
#define PROP_invalid_month                          (EMH_PROP_error_base + 53)
#define PROP_invalid_minute                         (EMH_PROP_error_base + 54)
#define PROP_invalid_second                         (EMH_PROP_error_base + 55)
#define PROP_invalid_year                           (EMH_PROP_error_base + 56)
#define PROP_invalid_date                           (EMH_PROP_error_base + 57)
#define PROP_incomplete_date                        (EMH_PROP_error_base + 58)
#define PROP_invalid_value                          (EMH_PROP_error_base + 59)
#define PROP_not_modifiable                         (EMH_PROP_error_base + 60)
#define PROP_use_date_format                        (EMH_PROP_error_base + 61)
#define PROP_not_a_tag                              (EMH_PROP_error_base + 62)
#define PROP_bad_date_range                         (EMH_PROP_error_base + 63)
#define PROP_cant_modify_saved                      (EMH_PROP_error_base + 64)
#define PROP_integer_out_of_range                   (EMH_PROP_error_base + 65)

/** Some parameters from the format "%1$" could not be applied when converting the string "%2$" to a date. */
#define PROP_date_incomplete_conversion             (EMH_PROP_error_base + 66)

#define PROP_invalid_index                          (EMH_PROP_error_base + 70)
#define PROP_exceeds_array_limit                    (EMH_PROP_error_base + 71)
#define PROP_edit_delete_propagated_is_not_allowed  (EMH_PROP_error_base + 72)

/** The operation "%1$" is not implemented for property "%2$" of "%3$" type. */
#define PROP_not_implemented                        (EMH_PROP_error_base + 99)

/** The type of the input object does not match the type expected by the given property. */
#define PROP_invalid_reference                      (EMH_PROP_error_base + 100)

/** An invalid object reference was passed to the property operation.
    Please refer to the Teamcenter syslog file for more information, and report this error to your system administrator. */
#define PROP_null_input_not_allowed                 (EMH_PROP_error_base + 101)

/**
    @name Compound Property related errors
    @{
*/
#define PROP_failed_to_create_cpdesc                (EMH_PROP_error_base + 110)
#define PROP_cpdef_instance_not_found               (EMH_PROP_error_base + 111)
#define PROP_unable_to_set_cp_value                 (EMH_PROP_error_base + 112)
#define PROP_unable_to_get_cp_value                 (EMH_PROP_error_base + 113)
#define PROP_bad_object_hierarchy                   (EMH_PROP_error_base + 114)
#define PROP_cannot_traverse_object_hierarchy       (EMH_PROP_error_base + 115)
#define PROP_invalid_prop_name                      (EMH_PROP_error_base + 116)
#define PROP_null_inputs_not_allowed                (EMH_PROP_error_base + 117)
#define PROP_compound_prop_is_not_allowed_as_source (EMH_PROP_error_base + 118)
/** @} */

/**
    @name Property Rule related errors
    @{
*/
#define PROP_duplicate_rule                         (EMH_PROP_error_base + 200)
#define PROP_initialize_failed                      (EMH_PROP_error_base + 201)
#define PROP_write_once_err                         (EMH_PROP_error_base + 202)
#define PROP_is_required_err                        (EMH_PROP_error_base + 203)
#define PROP_invalid_complex_prop_token             (EMH_PROP_error_base + 204)
#define PROP_invalid_init_value                     (EMH_PROP_error_base + 205)
#define PROP_invalid_complex_property               (EMH_PROP_error_base + 206)
#define PROP_required_prop_not_set                  (EMH_PROP_error_base + 207)
#define PROP_id_name_exceeds_allowed_length         (EMH_PROP_error_base + 208)
#define PROP_invalid_operation_input_source         (EMH_PROP_error_base + 209)
#define PROP_invalid_operation_input_field_type     (EMH_PROP_error_base + 210)
#define PROP_fail_to_define_runtime_property        (EMH_PROP_error_base + 211)
#define PROP_fail_to_define_operation_input_property (EMH_PROP_error_base + 212)
#define PROP_fail_to_define_relation_property       (EMH_PROP_error_base + 213)
#define PROP_invalid_display_name_token             (EMH_PROP_error_base + 214)
#define PROP_display_name_error                     (EMH_PROP_error_base + 215)

/** @} */

/**
    @name Localization related errors
    @{
*/
/** The property "%1$" is not marked as localizable. */
#define PROP_not_marked_localizable                 (EMH_PROP_error_base + 300)
#define PROP_VLA_adapter_error                      (EMH_PROP_error_base + 301)
#define PROP_locale_not_supported                   (EMH_PROP_error_base + 302)
#define PROP_translations_out_of_index              (EMH_PROP_error_base + 303)
#define PROP_zero_objects_props_locales             (EMH_PROP_error_base + 304)
#define PROP_input_data_not_well_organized          (EMH_PROP_error_base + 305)
#define PROP_objects_in_different_types             (EMH_PROP_error_base + 306)
#define PROP_wrong_number_of_values                 (EMH_PROP_error_base + 307)
#define PROP_no_master_locale                       (EMH_PROP_error_base + 308)
#define PROP_no_locale_value_specified              (EMH_PROP_error_base + 309)
#define PROP_no_status_value_specified              (EMH_PROP_error_base + 310)
#define PROP_is_marked_localizable                  (EMH_PROP_error_base + 311)

/** The property "%1$" on the object "%2$" does not contain any value for the requested locale "%3$". */
#define PROP_no_localized_value                     (EMH_PROP_error_base + 312)

/** The property "%1$" on the object "%2$" contains %3$ values for the locale "%4$", while it contains %5$ values for the master locale "%6$". */
#define PROP_number_of_values_discrepancy           (EMH_PROP_error_base + 313)

/** The operation has failed, because the property "%1$" on the object "%2$" contains at least one value for the locale "%3$" (at index %4$) for which the translation status is not approved. */
#define PROP_invalid_translation_status             (EMH_PROP_error_base + 314)
/** @} */


/**
    @name Bulk property related errors
    @{
*/
/** The evaluation of this property has been excluded.*/
#define PROP_PVM_value_excluded                     (EMH_PROP_error_base + 400)

/** Values cannot be retrieved because the Property Value Matrix (PVM) is not populated. Please report this error to your system administrator. */
#define PROP_PVM_not_initialized                    (EMH_PROP_error_base + 401)

/** The property "%1$" cannot be set as Real and Display values are same, because it has custom display value override already. */
#define PROP_cannot_set_real_disp_same              (EMH_PROP_error_base + 402)

/** @} */


/**
    @name Auto assign functionality related errors
    @{
*/

/** The value for the property "%1$" cannot be autogenerated,
    because neither Naming Rules nor User Exits are configured on this property. */
#define PROP_not_autoassignable                     (EMH_PROP_error_base + 500)
/** The value for the property "%1$" cannot be autogenerated during
    revise/save as action, because the revised or saved object is missing. */
#define PROP_source_object_missing                  (EMH_PROP_error_base + 501)

/** An error has occurred while generating the value for the following
    properties: %1$. Please provide valid combination of input values. */
#define PROP_error_autogenerate                     (EMH_PROP_error_base + 502)

/**
    @}
    @name Property Formatting functionality related errors
    @{
*/

/** An error has occurred while parsing the format definition "%1$". The format definition is incorrect.
    Please refer to the documentation on how to define a valid property formatting definition. */
#define PROP_formatter_invalid_format_def           (EMH_PROP_error_base + 503)

/** @} */

/**
    @name Backward Reference Property related errors
    @{
*/

/** An error was encountered while setting values for property "%1$". Please refer to the Teamcenter syslog for additional details. */
#define PROP_invalid_input_object                           (EMH_PROP_error_base + 504)

/** An input object is already specified for the property "%1$". */
#define PROP_duplicate_object                               (EMH_PROP_error_base + 505)

/** The table row creation has failed, because the create input descriptor contains an empty value for one of the following attributes: fnd0OwningObject, fnd0OwningPropName. */
#define PROP_invalid_input_for_table_row                     (EMH_PROP_error_base + 506)

/** The create input descriptor contains the property "%1$", which is not a table property. */
#define PROP_invalid_table_prop_for_table_row                (EMH_PROP_error_base + 507)

/** Removal of table rows is not supported for the property "%1$". Please refer to the Teamcenter syslog for additional details. */
#define PROP_table_row_del_not_supported                     (EMH_PROP_error_base + 508)

/** The given value for the attribute "%1$" fails the bounds check. The value needs to be between %2$ and %3$. */
#define PROP_value_out_of_bounds                             (EMH_PROP_error_base + 509)

/** @} */

/**
    @name Property Overwrite Detection related errors
    @{
*/

/** The object "%1$" has been changed by another client while being edited in this session. Both sessions have changed the following properties: "%2$".*/
#define PROP_overwrite_detected_properties                   (EMH_PROP_error_base + 510)

/** An error has occured while detecting the overwrite condition. Please refer to the Teamcenter syslog for additional details. */
#define PROP_error_detecting_overwrite                       (EMH_PROP_error_base + 511)

/** One or more objects could not be locked. Possible reasons are: The object is already locked or checked-out by another user; The object is already released; The user does not have access permissions to modify the object. Please refer to the Teamcenter syslog for additional details. */
#define PROP_objects_not_locked                              (EMH_PROP_error_base + 512)

/** The property "%1$" of the type "%2$" is not valid to perform the traversal because the property is not based on persistent properties or relations. */
#define PROP_type_invalid_for_traversal                      (EMH_PROP_error_base + 513)

/** The traversal direction "%1$" is not valid. The only valid values are "forward" or "reverse". */
#define PROP_invalid_traversal_direction                     (EMH_PROP_error_base + 514)

/** The presented property "%1$" cannot be created for the Logical Object Type "%2$". The property "%3$" should be a root or member property. */
#define PROP_invalid_root_or_member_property                 (EMH_PROP_error_base + 515)

/** The presented property "%1$" cannot be created for the Logical Object Type "%2$". The property "%3$" should be a valid source property. */
#define PROP_invalid_source_property                         (EMH_PROP_error_base + 516)

/** The source property for the compound property "%1$" is not defined. */
#define PROP_source_property_not_defined                     (EMH_PROP_error_base + 517)

/** The specified member "%1$" on the Logical Object Type "%2$" cannot be deleted because it is not owned by the selected Logical Object Type. */
#define PROP_cannot_delete_inherited_member_property         (EMH_PROP_error_base + 518)

/** The specified presented property "%1$" on the Logical Object Type "%2$" cannot be deleted because it is not owned by the selected Logical Object Type. */
#define PROP_cannot_delete_inherited_presented_property      (EMH_PROP_error_base + 519)

/** The included logical object "%1$" cannot be added to the Logical Object Type "%2$" because the navigation path is invalid. The business object on the last segment should be of Logical Object Type. */
#define PROP_invalid_navigation_path                         (EMH_PROP_error_base + 520)

/** The specified included logical object "%1$" on the Logical Object Type "%2$" cannot be deleted because it is not owned by the selected Logical Object Type. */
#define PROP_cannot_delete_inherited_included_lo             (EMH_PROP_error_base + 521)

/** The property "%1$" of the type "%2$" does not allow blank value. */
#define PROP_property_blank_forbidden                        (EMH_PROP_error_base + 522)

/** The configuration context cannot be set for the property "%1$" on the Logical Object Type "%2$". The property should be a member on the Logical Object Type.*/
#define PROP_cannot_set_configuration_context                (EMH_PROP_error_base + 523)


/** @} */
/** @} */

#include <property/libproperty_undef.h>
#endif

