/* @<COPYRIGHT_START>@
 ==================================================
 Copyright 2007.
 Siemens Product Lifecycle Management Software Inc.
 All Rights Reserved.
 ==================================================
 @<COPYRIGHT_END>@ */


/** 
    @file 

    This file contains the published identifiers of error codes that can be
    generated by this module. Obtaining and using the numeric values of these
    manifest constants is not supported. We reserve the right to change the
    actual values as necessary.

*/


#ifndef RBF_ERRORS_H
#define RBF_ERRORS_H

#include <common/emh_const.h>


/**
    @defgroup RBF_ERRORS Errors
    @ingroup RBF
    @{
*/

#define RBF_ERROR_BASE                       EMH_RBF_error_base

/** The Module definition identifier "%1$" does not exist. */
#define RBF_defmodule_not_found_error        (RBF_ERROR_BASE + 6)

/** The Application Extension Point identifier "%1$" does not exist. */
#define RBF_AEP_not_found_error              (RBF_ERROR_BASE + 7)

/** The input object type "%1$" does not match the Application Extension Point definition. */
#define RBF_wrong_object_type_error          (RBF_ERROR_BASE + 8)

/** The input name "%1$" does not match the Application Extension Point definition. */
#define RBF_invalid_input_name_error         (RBF_ERROR_BASE + 9)

/** An Application Extension Rule cannot be created without a Decision Table definition. */
#define RBF_missing_DecisionTable            (RBF_ERROR_BASE + 10)

/** An Application Extension Point cannot be created without any Input definitions. */
#define RBF_missing_RBFInputData             (RBF_ERROR_BASE + 11)

/** An Application Extension Point cannot be created without any Output definitions. */
#define RBF_missing_RBFOutputData            (RBF_ERROR_BASE + 12)

/** The Business Context cannot be created because a minimum of one Accessor is required. */
#define RBF_missing_AccessorData             (RBF_ERROR_BASE + 13)

/** A Row instance cannot be created because a minimum of one Cell is required. */
#define RBF_missing_CellData                 (RBF_ERROR_BASE + 14)

/** A parameter must be preceeded by a "-" character. */
#define RBF_missing_parm_specifier           (RBF_ERROR_BASE + 15)

/** An Application Extension Point identifier is required. */
#define RBF_missing_id                       (RBF_ERROR_BASE + 16)

/** An input file name is required. */
#define RBF_missing_input_file               (RBF_ERROR_BASE + 17)

/** The text services for the Teamcenter session could not be initialized. Please check the execute_rbf_rules utility syslog file for more information. */
#define RBF_init_text_services_error         (RBF_ERROR_BASE + 20)

/** The Teamcenter session login failed. Please check the execute_rbf_rules utility syslog file for more information. */
#define RBF_login_error                      (RBF_ERROR_BASE + 21)

/** The Teamcenter session logout failed. Please check the execute_rbf_rules utility syslog file for more information. */
#define RBF_failed_ITK_exit_module           (RBF_ERROR_BASE + 23)

/** Invalid input values specified. The valid format is "ColumnName | DataType | Value". */
#define RBF_invalid_input_values             (RBF_ERROR_BASE + 24)

/** An invalid data type was selected. Valid values are 0 through 5. */
#define RBF_data_type_not_supported          (RBF_ERROR_BASE + 25)
/** @} */

#endif
