/* 
   Copyright 2020 Siemens Digital Industries Software
   ==================================================
   Copyright 2014.
   Siemens Product Lifecycle Management Software Inc.
   All Rights Reserved.
   ==================================================
   Copyright 2020 Siemens Digital Industries Software
*/

/** 
    @file 

    This file contains the published identifiers of error codes that can be
    generated by this module. Obtaining and using the numeric values of these
    manifest constants is not supported. We reserve the right to change the
    actual values as necessary.

*/

#ifndef SHAREDCACHE_ERRORS_H
#define SHAREDCACHE_ERRORS_H

#ifndef EMH_CONST_H
    #include <common/emh_const.h>
#endif

/**
    @defgroup SHAREDCACHE_ERRORS SHAREDCACHE Errors
    @ingroup SHAREDCACHE
    @{
*/

#define SHAREDCACHE_ERROR_BASE                       EMH_SHAREDCACHE_error_base

/**
 * An error has occurred during shared cache initialization.
 * Please report this error to your system administrator.
 */
#define SHAREDCACHE_init_error                       (SHAREDCACHE_ERROR_BASE + 1)

/**
 * The size of the deploy file "%1$" is zero, so it cannot be read.
 * Please report this error to your system administrator.
 */
#define SHAREDCACHE_deployfile_size_error            (SHAREDCACHE_ERROR_BASE + 2)

/**
 * The deploy file "%1$" does not exist.
 * Please report this error to your system administrator.
 */
#define SHAREDCACHE_deployfile_error                 (SHAREDCACHE_ERROR_BASE + 3)

/**
 * The deploy file "%1$" has an improper format.
 * Please re-run the utility "generate_metadata_cache" to generate the deploy file.
 * Please report this error to your system administrator.
 */
#define SHAREDCACHE_deployfile_format_error          (SHAREDCACHE_ERROR_BASE + 4)

/**
 * The Shared Metadata Cache is out of date.  The dataset version %1$ is older
 * than the version %2$ which is deployed in the database, so Metadata is
 * populated locally in this process.  The "generate_metadata_cache" utility
 * will re-generate the Shared Metadata Cache.
 */
#define SHAREDCACHE_deployfile_old                   (SHAREDCACHE_ERROR_BASE + 5)

/**
 * The Shared Metadata Cache cannot be updated, because it has not been
 * initialized.  Please report this error to your system administrator.
 */
#define SHAREDCACHE_not_initialized                  (SHAREDCACHE_ERROR_BASE + 6)

/** @} */

#endif

