/* @<COPYRIGHT_START>@
* ===============================================
* Copyright 2006 UGS Corp. All Rights Reserved.
* ===============================================
* @<COPYRIGHT_END>@
*/


/**
    @file

    describe this file here

*/

#ifndef TIE_ERRORS_H
#define TIE_ERRORS_H

#include <common/emh_const.h>
#include <common/tc_deprecation_macros.h>
#include <tie/libtie_exports.h>

/**
    @defgroup TIE_ERRORS TIE Errors
    @ingroup TIE
    @{
*/

#define TIE_error_base                      EMH_TIE_error_base

/**
    TIE internal error
*/
#define TIE_internal_error                  (TIE_error_base + 1)

/**
    Transfermode name passed for import/export is missing in the database
*/
#define TIE_invalid_transfermode            (TIE_error_base + 2)

/**
    Closure Rule information is missing in the Transfermode passed for import/export
*/
#define TIE_invalid_closurerule             (TIE_error_base + 3)

/**
    Failed to create Log file for import/export
*/
#define TIE_file_open_fail                  (TIE_error_base + 4)

/**
    Directive skip
*/
#define TIE_directive_skip                  (TIE_error_base + 5)

/**
    Object not defined
*/
#define TIE_object_not_defined              (TIE_error_base + 6)


/**
    Bad GMR type
*/
#define TIE_bad_GMR_type                    (TIE_error_base + 9)

/**
    XmlElement is NULL
*/
#define TIE_no_xmlElem                      (TIE_error_base + 10)

/**
    Message object is NULL
*/
#define TIE_no_message                      (TIE_error_base + 11)

/**
    Session object is NULL
*/
#define TIE_no_session                      (TIE_error_base + 12)

/**
    The required XML attribute is missing in element
*/
#define TIE_no_xmlAttributes                (TIE_error_base + 13)


/**
    Export status passed to exporter is invalid
*/
#define TIE_invalid_export_status           (TIE_error_base + 15)

/**
    XmlElement Name is NULL
*/
#define TIE_null_element_name               (TIE_error_base + 17)

/**
    Xml attribute has NULL/invalid value
*/
#define TIE_null_attribute_value            (TIE_error_base + 18)

/**
    Element Type is NULL
*/
#define TIE_null_element_type               (TIE_error_base + 19)

/**
    Item related to ItemRevision/Identifier is not found
*/
#define TIE_no_item                         (TIE_error_base + 20)

/**
    Dataset Tool does not exist
*/
#define TIE_null_dataset_tool               (TIE_error_base + 21)

/**
    Owning site attribute is either missing or points to wrong value
*/
#define TIE_null_remote_site                (TIE_error_base + 22)

/**
    Primary/Secondary object is missing
*/
#define TIE_null_primary_secondary_object   (TIE_error_base + 23)


/**
    Failed to find GSIdentity object
*/
#define TIE_GSIdentity_find                 (TIE_error_base + 25)

/**
    SchemaMap is NULL
*/
#define TIE_no_schemaMap                    (TIE_error_base + 26)

/**
    SchemaMapEntry is NULL
*/
#define TIE_no_schemaMapEntry               (TIE_error_base + 27)

/**
    Function pointer is NULL
*/
#define TIE_no_function_pointer             (TIE_error_base + 28)

/**
    Xml attribute is NULL/invalid
*/
#define TIE_null_attribute                  (TIE_error_base + 29)

/**
    Transfer Formula info is not set
*/
#define TIE_no_transferformula              (TIE_error_base + 30)

/**
    Session Options are missing in Transfer Formula
*/
#define TIE_no_session_option               (TIE_error_base + 31)

/**
    Target site is Invalid
*/
#define TIE_invalid_targetsite              (TIE_error_base + 32)


/**
    Teamcenter object is not site Checked-Out to the sending site
*/
#define TIE_site_does_not_own_lock          (TIE_error_base + 34)


/**
    Fail to create export record
*/
#define TIE_create_IXR_fail                 (TIE_error_base + 36)


/**
    ImanReservation UID in TcXML does not match the ImanReservation UID in the database
*/
#define TIE_reservation_uids_dont_match     (TIE_error_base + 39)

/**
    Transformation on input xml failed
*/
#define TIE_xml_transform_failed            (TIE_error_base + 40)

/**
    Invalid Input file for import/export
*/
#define TIE_invalid_input_file              (TIE_error_base + 41)

/**
    XML file fails schema validation
*/
#define TIE_invalid_xml_schema              (TIE_error_base + 42)

/**
    File name is NULL
*/
#define TIE_null_filename                   (TIE_error_base + 43)

/**
    The output XML file does not conform to the schema, even though it has been generated by Teamcenter. Please report this error to the system administrator.
*/
#define TIE_schema_mismatch                 (TIE_error_base + 44)

/**
    Invalid Option
*/
#define TIE_invalid_option                  (TIE_error_base + 45)

/**
    Constants Query has failed
*/
#define TIE_unable_to_execute_const_query   (TIE_error_base + 46)


/**
    Value passed for continue_on_error parameter is invalid
*/
#define TIE_invalid_continue_on_error       (TIE_error_base + 48)

/**
    Invalid scope rule mode. Possible values are ignore and overwrite
*/
#define TIE_invalid_scope_rule              (TIE_error_base + 49)

/**
    Invalid scope rule mode, can be used only with scope rule paremeter
*/
#define TIE_invalid_scope_rule_mode         (TIE_error_base + 50)

/**
    Invalid Optionset or site or transfermode used while importing scope rules
*/
#define TIE_invalid_scope_rule_usage        (TIE_error_base + 51)

/**
    One target site must be specified to transfer ownership
*/
#define TIE_target_sites_must_be_specified  (TIE_error_base + 52)

/**
    Invalid transfermode or option set
*/
#define TIE_invalid_transfermode_optionset  (TIE_error_base + 53)

/**
    Invalid internal transfermode
*/
#define TIE_invalid_internal_transfermode   (TIE_error_base + 54)

/**
    Invalid Owning site
*/
#define TIE_invalid_owningsite              (TIE_error_base + 55)

/**
    Unexpected null or empty string for Xml Element
*/
#define TIE_null_or_empty_str_unexpected    (TIE_error_base + 56)

/**
    Invalid transfer option
*/
#define TIE_invalid_transfer_options        (TIE_error_base + 57)

/**
    Conflicting site ownership transfer options
*/
#define TIE_conflicting_transfer_options    (TIE_error_base + 58)

/**
    Invalid item revision export selector supplied
*/
#define TIE_invalid_revision_selector       (TIE_error_base + 59)

/**
    Export option specified is only valid when transferring site ownership
*/
#define TIE_invalid_option_not_xferring     (TIE_error_base + 60)

/**
    Export option specified is valid only when BOM components are included
*/
#define TIE_valid_for_assy_export_only      (TIE_error_base + 61)

/**
    Invalid Attribute (Name is too long)
*/
#define TIE_invalid_attribute               (TIE_error_base + 62)


/**
    TcXML import error
*/
#define TIE_common_import_error             (TIE_error_base + 64)

/**
    Options "Include Modified only", "Transfer Ownership", and "Force Replica"
    conflict with each other
*/
#define TIE_conflicting_export_options      (TIE_error_base + 65)

/**
    Revisions attribute is missing in RevisionAnchor xml element
*/
#define TIE_dataset_missing_version_info    (TIE_error_base + 66)


/**
    Notes type is missing in the DB
*/
#define TIE_note_types_not_found_on_import  (TIE_error_base + 69)

/**
    For occurrence note in input XML, there is a count mismatch for
    note types and texts
*/
#define TIE_note_type_and_text_cnt_mismatch (TIE_error_base + 70)

/**
    Invalid organization attribute
*/
#define TIE_invalid_organization_attr       (TIE_error_base + 71)

/**
    Object not found in the database
*/
#define TIE_obj_not_found_in_database       (TIE_error_base + 72)

/**
    Site attribute not found in the database
*/
#define TIE_site_not_found_in_database      (TIE_error_base + 73)

/**
    Invalid child element
*/
#define TIE_invalid_child_element           (TIE_error_base + 74)

/**
    Target site is not offline
*/
#define TIE_not_offline                     (TIE_error_base + 75)

/**
    Error in mapping
*/
#define TIE_mapper_error                    (TIE_error_base + 76)

/**
    Dataset has only one version to import
*/
#define TIE_one_dsversion                   (TIE_error_base + 77)

/**
    Assignee is not found in the database
*/
#define TIE_participant_assignee_not_found  (TIE_error_base + 78)

/**
    Owning site is inconsistent between the related objects
*/
#define TIE_conflicting_owning_site         (TIE_error_base + 79)


/**
    The Revise function is not currently supported via Global Services
*/
#define TIE_revise_not_supported            (TIE_error_base + 81)

/**
    Named References object is missing
*/
#define TIE_missing_named_references        (TIE_error_base + 82)

/**
    TIE_Concurrent table sql(select/insert/delete) query failed during
    concurrent import
*/
#define TIE_concurrent_import_db_error      (TIE_error_base + 83)

/**
    Export primary language for attribute not found
*/
#define TIE_no_export_primary               (TIE_error_base + 84)

/**
    No export primary candidates is defined
*/
#define TIE_no_export_primary_candidates    (TIE_error_base + 85)

/**
    The language information can only be in the Transfer Formula or in the
    TIE_transfermode name_languages site preference
*/
#define TIE_languages_given_by_multiple_resources    (TIE_error_base + 86)

/**
    The site master languages of source and destination sites are different
*/
#define TIE_different_sml                   (TIE_error_base + 87)

/**
    The list of languages given in the XML file is not a subset of the
    languages at the importing site
*/
#define TIE_xml_lang_not_subset             (TIE_error_base + 88)

/**
    There are no common languages between the languages in the XML file and the
    languages given by the transfer formula
*/
#define TIE_no_common_lang                  (TIE_error_base + 89)

/**
    The attribute Master Language is not found
*/
#define TIE_AML_not_found                   (TIE_error_base + 90)

/**
    Invalid property value
*/
#define TIE_invalid_property_value          (TIE_error_base + 91)

/**
    TIE de-serialize method returns null tag
*/
#define TIE_deserialize_null_tag            (TIE_error_base + 92)

/**
    Wildcard characters are not supported
*/
#define TIE_wildcard_not_supported          (TIE_error_base + 93)

/**
    Invalid relationship type
*/
#define TIE_invalid_relationshiptype        (TIE_error_base + 94)

/**
    Invalid action
*/
#define TIE_invalid_action                  (TIE_error_base + 95)

/**
    No export candidates
*/
#define TIE_no_export_candidates            (TIE_error_base + 96)

/**
    Error while authenticating the key defined by the variable SITCONS_AUTH_KEY
*/
#define TIE_sitcons_encrypt_decript_failed  (TIE_error_base + 97)

/**
    There are no candidates for synchronization
*/
#define TIE_no_sync_candidates              (TIE_error_base + 98)

/**
    There are no candidates for ownership transfer
*/
#define TIE_no_objects_for_ownership_xfr    (TIE_error_base + 99)

/**
    The input argument is invalid
*/
#define TIE_invalid_argument                (TIE_error_base + 100)

/**
    The TIE_Volume_Map preference is not defined
*/
#define TIE_pref_volume_map_not_defined     (TIE_error_base + 101)

/**
    No values in the preference TIE_Volume_Map
*/
#define TIE_no_values_in_pref_tie_volume_map     (TIE_error_base + 102)

/**
    The shadow volume is not found
*/
#define TIE_shadow_volume_not_found         (TIE_error_base + 103)

/**
    Incorrect value is provided for shadow volume preference
*/
#define TIE_incorrect_value_in_shadow_volume_pref         (TIE_error_base + 104)

/**
    The object is not imported
*/
#define TIE_object_not_imported             (TIE_error_base + 105)

/**
    Accountability Table does not exist
*/
#define TIE_accountability_table_does_not_exist    (TIE_error_base + 106)

/**
    Invalid element ID
*/
#define TIE_invalid_elemID                  (TIE_error_base + 107)


/**
    There is not enough disk space on the transient volume
*/
#define TIE_low_vol_disk_space              (TIE_error_base + 109)

/**
    Schema file is not Available
*/
#define TIE_schema_file_not_available       (TIE_error_base + 110)

/**
    The input XML file is not valid
*/
#define TIE_XML_file_not_valid              (TIE_error_base + 111)

/**
    No configured revision is found for the given top line Item.In order to export the required
    structure, either change the default revision rule or choose a specific revision
*/
#define TIE_no_configured_revision_for_topline      (TIE_error_base + 112)

/**
    The utility "%1$" cannot run because the environment variable UGII_BASE_DIR is not set.
*/
#define TIE_UGII_BASE_DIR_not_set           (TIE_error_base + 113)

/** 
    @deprecated #TIE_problem_running_ugclone deprecated in Teamcenter 11.2.2. Use TIE_problem_running_import_utility instead.
*/
#define TIE_problem_running_ugclone         (TIE_error_base + 114)
TC_DEPRECATED_PREPROCESSOR( "11.2.2", TIE_problem_running_ugclone, "TIE_problem_running_import_utility" )

/**
    No BOM structure with a proper top line is specified for the "Export" operation
*/
#define TIE_topline_is_empty                (TIE_error_base + 115)

/**
    The BOM Window to export is invalid
*/
#define TIE_invalid_bomwindow               (TIE_error_base + 116)

/**
    Unconfigured TCXML export to unmanaged site is not supported
*/
#define TIE_unconf_exp_to_unmanaged_not_sup (TIE_error_base + 117)

/**
    Unable to open the specified file
*/
#define TIE_unable_to_open_file             (TIE_error_base + 118)

/**
    An invalid bucket is found in the provided XML file.The Item element is not present in it
*/
#define TIE_item_not_present_in_bucket      (TIE_error_base + 119)

/**
    Empty labels in "GSIdentity" objects are not allowed in "TCXML import from managed site" operations
*/
#define TIE_empty_label                     (TIE_error_base + 120)

/**
    Unconfigured revision exports are not supported to unmanaged sites
*/
#define TIE_unconfigured_revision_export    (TIE_error_base + 121)

/**
    No Multi-Site license (key: multisite_server) is available to export to, or import from, the offline site. Please obtain the license and try again.
*/
#define TIE_bc_export_import_req_multisite_license  (TIE_error_base + 122)

/**
    The import operation has failed for the following number of islands: %1$. Please check the following log file for more details: %2$.
*/
#define TIE_partial_import_failure          (TIE_error_base + 123)

/**
    A time-out has occurred while waiting for an import process to release Global Service identities(GSIDs) from the concurrency table.
*/
#define TIE_import_concurrency_timeout_occurred      (TIE_error_base + 124)

/**
    CAD incomplete assembly is not supported in configured export to unmanaged site
*/
#define TIE_cad_incomplete_error                    (TIE_error_base + 125)

/**
    The conditional clause of the closure rule &quot;%1$&quot; is invalid.
*/
#define TIE_invalid_conditional_clause      (TIE_error_base + 126)


/**
    The given string &quot;%1$&quot; is not a valid UID.
*/
#define TIE_invalid_uid           (TIE_error_base + 128)

/**
    The number of inputs received for an Incremental Change Delta export operation was %1$. Please provide a single Item or Item Revision.
*/
#define TIE_ICDelta_export_single_object           (TIE_error_base + 129)

/**
    The Incremental Change Delta export operation cannot be performed in conjunction with a "low level" export.
*/
#define TIE_ICDelta_conflicting_low_level_with_export_options     (TIE_error_base + 130)

/**
    The Incremental Change Delta export operation cannot be performed because the specified transfer option set does not fit for a configured export (the option "opt_cfgbom" needs to be set to "True"). Please specify a transfer option set for "high level" configured BOM export, or contact your system administrator.
*/
#define TIE_ICDelta_configured_export_options     (TIE_error_base + 131)

/**
    Incremental Change Delta export operations to unmanaged sites are not supported. Please verify the target site, or contact your system administrator.
*/
#define TIE_ICDelta_conflicting_unmanaged_site_with_export_options     (TIE_error_base + 132)

/**
    The property &quot;%1$&quot; from the class &quot;%2$&quot; cannot be used to construct the value for the property &quot;POM_stub.object_id&quot;. Please contact your system administrator to remove the property &quot;%1$&quot; from the property set &quot;FT_TIEExportDefaultPS&quot;.
*/
#define TIE_invalid_stub_key           (TIE_error_base + 133)

/**
    The revisable setting for the classes in the TCXML file &quot;%1$&quot; does not match what is defined at the importing site. Please refer to the log file &quot;%2$&quot; for details.
*/
#define TIE_revisable_class_mismatch           (TIE_error_base + 134)

/**
    The current site does not have any revisable class. Please make revisable the classes which are marked as such in the TCXML file &quot;%1$&quot;".
*/

#define TIE_site_not_revisable             (TIE_error_base + 135)

/**
   The class &quot;%1$&quot; is revisable only at the importing site. Please make it revisable at the exporting site.
*/
#define TIE_class_revisable_on_import_site           (TIE_error_base + 136)

/**
   The value supplied through the argument "-input_criteria" is invalid. Please use the following format: "-input_criteria=class-name{attrib1=value1,attrib2=value2,...}".
*/
#define TIE_invalid_input_criteria                      (TIE_error_base + 137)
/**
   The file extension for "Bulk Extract Briefcase Export" must be .bcz.
*/
#define TIE_bulk_extract_invalid_file_extension         (TIE_error_base + 138)
/**
   The operation "Bulk Extract Briefcase Export" with a target site is not allowed. Remove the target site option.
*/
#define TIE_bulk_extract_invalid_targetsite_option      (TIE_error_base + 139)
/**
   Synchronization is not supported by the "Bulk Extract Briefcase Export" operation.
*/
#define TIE_bulk_extract_invalid_sync_option            (TIE_error_base + 140)
/**
   An invalid option set is provided to the "Bulk Extract Briefcase Export" operation. Please ensure that the "opt_bulk_extract_bcz" option is set to "TRUE".
*/
#define TIE_bulk_extract_invalid_export_optionset       (TIE_error_base + 141)
/**
   This site is not configured as a "test environment". "bulk load briefcase import" operations can only be run in "test environment"-configured sites.
*/
#define TIE_bulk_load_not_test_env                      (TIE_error_base + 142)
/**
   An invalid briefcase is provided to the "Bulk Load Briefcase Import" operation. It must have been generated by the "Bulk Extract Briefcase Export" operation.
*/
#define TIE_bulk_load_invalid_bcz                       (TIE_error_base + 143)
/**
   An invalid option set is provided to the "Bulk Load Briefcase Import" operation. Please ensure that the "opt_bulk_load_bcz" option is set to "TRUE".
*/
#define TIE_bulk_load_invalid_import_optionset          (TIE_error_base + 144)
/**
   The Site with ID "%1$" is already registered in the importing database, and as a consequence the import operation with option "force import as local" is not supported. Try again either after removing the Site from the Organization application, or without specifying the "force import as local" option.
*/
#define TIE_bulk_load_POM_imc_registered                (TIE_error_base + 145)

/**
   The import operation with "force update local" option has failed, because some objects detected through the activation of the "infer delete" option are referenced and cannot be deleted. Try again after removing the references.
*/
#define TIE_infer_delete_local_fail                     (TIE_error_base + 147)

/**
   The checksum operation has failed, because the provided migration Site ID "%1$" is invalid.
*/
#define TIE_invalid_migration_site_id                   (TIE_error_base + 148)

/**
   The export operation has failed, because the currently logged-in user does not have read privileges for the following objects: %1$.
*/
#define TIE_no_read_access                              (TIE_error_base + 149)

/**
   An invalid option set is provided to the "Admin Data transfer" operation. Please ensure that the "opt_admin_data_xfer" option is set to "TRUE".
*/
#define TIE_admin_data_xfer_invalid_optionset           (TIE_error_base + 150)

/**
   The associated object of class Fnd0AdminGSIdentity is not found or failed to be created for the object "%1$". Please contact your system administrator.
*/
#define TIE_admin_gsid_missing                          (TIE_error_base + 151)

/**
   No valid candidate key is defined for the type "%1$". Please define it through the Business Modeler IDE.
*/
#define TIE_invalid_candidate_key_definition            (TIE_error_base + 152)

/**
   More than one object found for an administrative object "%1$" in the source XML file. Please contact your system administrator.
*/
#define TIE_admin_object_not_unique                     (TIE_error_base + 153)

/**
   The referenced object "%1$" in the candidate key of the object "%2$" in the source XML file has not been processed yet. Please ensure that the XML file was generated correctly.
*/

#define TIE_admin_object_finding_disorder               (TIE_error_base + 154)

/**
   The attribute "%1$" specified in the candidate key definition of the business object type "%2$" is invalid. Please correct the definition in the Business Modeler IDE.
*/
#define TIE_invalid_attribute_in_candidate_key          (TIE_error_base + 155)

/**
   The value "%1$" in the candidate key definition of the business object type "%2$" is invalid, because it does not start with the prefix "$". Please correct the definition in the Business Modeler IDE.
*/
#define TIE_invalid_field_in_candidate_key              (TIE_error_base + 156)

/**
   The options "-targetsites", "-sync", "-transferownership" or "-incrementalChangeDelta" are not supported when the option "-admin_data_xfer" is specified.
*/
#define TIE_admin_data_export_invalid_options           (TIE_error_base + 157)

/**
   An invalid option set is provided to the "Admin Data Export" operation. Please ensure that the transfer option "opt_admin_data_xfer" is set to "TRUE".
*/
#define TIE_admin_data_invalid_export_optionset         (TIE_error_base + 158)

/**
   The candidate key attribute "%1$" on the administrative object "%2$" has no value. Please modify the object attribute to have a valid value.
*/

#define TIE_candidate_key_attribute_empty_value         (TIE_error_base + 159)


/**
  The input file "%1$", specified through the option "rootObjectCriteriaFile" in the "tcxml_export" command and used for retrieving root administrative objects, is formatted incorrectly.
*/
#define TIE_invalid_input_admin_file                    (TIE_error_base + 161)


/**
   The export operation has failed, because the user "%1$" has marked the object "%2$" for transfer ownership to the anonymous Site with ID "%3$".
*/
#define TIE_invalid_ownxfer_site_when_export_to_anonymous   (TIE_error_base + 163)

/**
   The export operation has failed, because the anonymous Site with ID "%1$" specified in the preference "BC_anonymous_site_id" is not marked as offline.
*/
#define TIE_anonymous_site_not_offline                  (TIE_error_base + 164)

/**
   The input Cparam "%1$" is not supported by POM Revisioning configured exports. Please check the input.
*/
#define TIE_unsupported_cparam                          (TIE_error_base + 165)

/**
   The import operation has failed, because all the revisions of the POM_stub "%1$" in the TCXML file are not found at the target site. Please import the missing revisions first.
*/
#define TIE_revision_of_stub_not_found                  (TIE_error_base + 166)

/**
   The ownership transfer operation has failed, because the user has input minor revision configuration options.
*/
#define TIE_minor_rev_configuration_xfer_conflict       (TIE_error_base + 167)

/**
   A circular reference has been detected in the definition of the Candidate Key "%1$". Please modify the definition for those types through the Business Modeler IDE to break the circular reference.
*/
#define TIE_circular_reference_in_candidate_key         (TIE_error_base + 168)

/**
  An error has occurred during the processing of some objects. Please check the log file "%1$" for more information about the errors.
*/
#define TIE_error_occurred                             (TIE_error_base + 169)

/**
  An invalid TC XML file is provided to the "Administration Data Import" operation. The provided file must be generated through the "Administration Data Export" operation.
*/
#define TIE_admin_data_invalid_file                    (TIE_error_base + 170)

/**
  An administration data TC XML file is provided to non-"Administration Data Import" operation. To import it, use the administration data transfer mode.
*/
#define TIE_admin_file_for_non_admin_import            (TIE_error_base + 171)

/**
  The object with source UID "%1$" and Candidate Key "%2$" has two equivalent objects at the target site: "%3$" and "%4$". Since importing would potentially create duplicates, the import operation has aborted.
*/
#define TIE_admin_data_find_duplicate                  (TIE_error_base + 172)
/**
  Non-administration data is provided to the "Administration Data Export" operation. Please check the export syslog file "%1$" for details on the non-administration data.
*/
#define TIE_admin_data_non_admin_export                (TIE_error_base + 173)

/**
   The object "%1$" is not supported for briefcase ownership transfer, because it is a replica.
*/
#define TIE_replica_object_ownership_xfer_not_supported                  (TIE_error_base + 174)

/**
   The object "%1$" is not supported for briefcase ownership transfer, because it is checked-out.
*/
#define TIE_checked_out_object_ownership_xfer_not_supported                  (TIE_error_base + 175)

/**
  The Saved Search "%1$" specified in the export operation is invalid. Please provide a valid Saved Search.
*/
#define TIE_invalid_saved_search                       (TIE_error_base + 176)
/**
  More than one Shared Saved Search is found for the "-saved_search" option value "%1$" in the export operation. Please ensure that the name of the Shared Saved Search is unique.
*/
#define TIE_duplicate_shared_saved_search              (TIE_error_base + 177)
/**
  The class "%1$" specified by the "-input_criteria" option in the export operation is invalid. Please provide a valid class name.
*/
#define TIE_invalid_class_name                         (TIE_error_base + 178)
/**
  The attribute "%1$" for class "%2$" specified in -input_criteria option in the export operation is invalid. Please provide a valid attribute name.
*/
#define TIE_invlid_attribute_name                      (TIE_error_base + 179)
/**
  The attribute "%1$" in -input_criteria option in the export operation was specified more than once. Please ensure the attribute appears only once.
*/
#define TIE_duplicate_attribute_name                   (TIE_error_base + 180)
/**
  The object "%1$" in the island 0 cannot be found in the database at the target site. Please ensure its existence before importing.
*/
#define TIE_object_in_island_0_not_found               (TIE_error_base + 181)
/**
  The import merge option "%1$" in invalid. Please provide a valid merge option from one of the following: source_everywhere, target_everywhere, source_for_unresolved, target_for_unresolved, latest_by_time_for_unresolved.
*/
#define TIE_import_invalid_merge_option                (TIE_error_base + 182)
/**
  No valid input object exist in current revisable configuration. Please ensure the configuration input is correct.
*/
#define TIE_no_configured_revisable_revision_for_candidates            (TIE_error_base + 183)

/* Please use follwing error code 162, 160, 146, 127, 108, 80, 67, 63, 47, 38, 37, 35, 33, 24
16, 14, 8, 7
*/

/**
  The value "%1$" in the "%2$" parameter is invalid. Please provide a valid value by following the following format: option1:value1,option2:value2,option3:value3...
*/
#define TIE_invalid_session_options                    (TIE_error_base + 184)
/**
  The option "%1$" in the "session_options" parameter is invalid, because the option set "%2$" contains an option of same name defined as read-only.
*/
#define TIE_readonly_session_option                    (TIE_error_base + 185)

/**
  The provided Vendor Contact UID is invalid.
*/
#define TIE_invalid_vendor_contact                     (TIE_error_base + 186)

/**
  The Briefcase "%1$" cannot be imported, because it is marked as "for review purpose".
*/
#define TIE_import_review_only_bcz                     (TIE_error_base + 187)

/**
  The property "%1$" cannot be found in the table for the type "%2$". Please add that property to the Property Set, so that the column can be populated.
*/
#define TIE_property_missing_in_table                  (TIE_error_base + 188)

/**
  The transfer mode "%1$" is not valid for the "%2$" operation. Please use the transfer mode type "%3$".
*/
#define TIE_invalid_tm_for_transfer                    (TIE_error_base + 189)

/**
   No indexed BOM matches the input parameters.
*/
#define TIE_rev_bom_no_indexed_bom                      (TIE_error_base + 190)
/**
   More than one indexed BOM matches the input parameters.
*/
#define TIE_rev_bom_multiple_indexed_boms               (TIE_error_base + 191)
/**
   The provided effectivity is not correct.
*/
#define TIE_rev_bom_wrong_effectivity                   (TIE_error_base + 192)

/**
   Too many effectivites are provided for generating an indexed BOM.
*/
#define TIE_rev_bom_too_many_effectivities              (TIE_error_base + 193)

/**
   The original site information is missing in the XML file "%1$".
*/
#define TIE_missing_original_site                       (TIE_error_base + 194)

/** 
    A problem has occurred while running the utility "%1$". Please check the associated syslog file for more information.
*/
#define TIE_problem_running_import_utility              (TIE_error_base + 195)

/**
     The "TC XML export" operation has failed because no valid root objects are traversed. Please check the syslog file for more information.
*/
#define TIE_no_valid_traverse_root_objects              (TIE_error_base + 196)

/**
   No transformer rule can be found. Please contact your system administrator.
*/
#define TIE_no_xformer_rule                             (TIE_error_base + 197)

/**
  The export operation was blocked because it involved an unmanaged Briefcase and this type of exchange is restricted to the "Briefcase Browser" application.
*/
#define TIE_block_unmnaged_bcz_export                   (TIE_error_base + 198)

/**
  The import operation was blocked because it involved the unmanaged Briefcase "%1$" and this type of exchange is restricted to the "Briefcase Browser" application.
*/
#define TIE_block_unmnaged_bcz_import                   (TIE_error_base + 199)

/**
  The instance class name "%1$" is different from object_class attribute value for element "%2$".
*/
#define TIE_instance_class_and_object_class_mismatch    (TIE_error_base + 200)

/**
  There are multiple elements in the TCXML which have the same PUID as "%1$".
*/
#define TIE_duplicate_puid_in_elements                  (TIE_error_base + 201)

/**
  An error was detected while parsing the user attribute list for the entry "user_attributes[%1$]", which has a value of "%2$".
*/
#define TIE_user_attribute_target_list_error            (TIE_error_base + 202)

/**
  The attribute "object_type" in XML file "%1$" is different from the value in the database "%2$" for element "%3$". Please correct the data and try again.
*/
#define TIE_object_type_mismatch                        (TIE_error_base + 203)

/**
  There is no revision being configured by revision selector option "opt_rev_select" or preference "TC_secondary_revision_selector".
*/
#define TIE_no_revision_being_configured_by_revision_selector   (TIE_error_base + 204)

/**
  Export is not supported for transient revision rule "%1$".
*/
#define TIE_exp_with_transient_revrule_not_sup          (TIE_error_base + 205)

/**
  Object Type not found in the database for "%1$" and UID "%2$".
*/
#define TIE_object_type_not_found                       (TIE_error_base + 206)

/**
  Mismatch for number of columns in input and temp table: "%1$".
*/
#define TIE_temp_table_data_error                       (TIE_error_base + 207)

/**
  The validation failed for rule "%1$".
*/
#define TIE_invalid_rule_string                         (TIE_error_base + 208)

/**
  Failed while processing unmapped objects: cannot get "%1$". 
*/
#define TIE_process_unmapped_obj_error                  (TIE_error_base + 209)

/**
  The save operation failed during the import of object with type-UID as follow: "%1$".
*/
#define TIE_save_object_error                           (TIE_error_base + 210)

/**
  The deferred ownership transfer is supported only on Oracle and PostgreSQL RDBMS Platforms. Please set the option "opt_deferred_ownership" to "false" in the source TCXML to bypass deferred ownership transfer.
*/
#define TIE_invalid_rdbms_platform_for_ot               (TIE_error_base + 211)

/**
  The object cannot be created because the class or type "%1$" of element "%2$" does not exist in the database.
*/
#define TIE_class_type_not_found                        (TIE_error_base + 212)

/**
  A UID must be provided.
*/
#define TIE_empty_UID                                   (TIE_error_base + 213)

/**
  The provided trigger type "%1$" is invalid. The valid trigger types are 1 (for add trigger), 2 (for delete trigger), 3 (for both add and delete triggers).
*/
#define TIE_invalid_trigger_type                        (TIE_error_base + 214)

/**
  The provided table information type "%1$" is invalid. Refer to the documentation of the ITK "TIE__get_diagnostic_info_for_acct_tables" for the valid table information types.
*/
#define TIE_invalid_table_info_type                     (TIE_error_base + 215)

/**
  Target and source traverse rule definitions for the rule string "%1$" either are both empty or have both values.
*/
#define TIE_invalid_src_trg_traverse_rule               (TIE_error_base + 216)

/**
  An error has occurred when retrieving the write tickets for the file "%1$": %2$
*/
#define TIE_write_ticket_failure                        (TIE_error_base + 217)

/**
  The calendar cannot be created with the name "%1$" because the calendar name must contain the user name enclosed by parentheses, i.e. "%2$".
*/
#define TIE_admin_calendar_error                        (TIE_error_base + 218)

/**
  A corruption of the Global Site ID (GSID) has occurred. Please check the syslog for the "DB GSID REPORT SUMMARY" string for more information. 
*/
#define TIE_gsid_corrupted                              (TIE_error_base + 219)

/**
  An error has occurred when validating the TCXML file "%1$". For more information, please check for the "Error Summary" string in the report "%2$".  
*/
#define TIE_validate_tcxml_failure                      (TIE_error_base + 220)

/**
  The BOM window "%1$" is modified but not saved. Please save it and try again. 
*/
#define TIE_bomwindow_not_saved                         (TIE_error_base + 221)

/**
  The following objects cannot be exported because they are invalid: %1$.
*/
#define TIE_exporting_invalid_objects                   (TIE_error_base + 222)

/**
  The Briefcase OT transaction "%1$" was not found in the database.
*/
#define TIE_briefcase_ot_transaction_not_found          (TIE_error_base + 223)

/**
  The current user does not have read privilege to the briefcase OT transaction.
*/
#define TIE_briefcase_ot_transaction_no_read_access     (TIE_error_base + 224)

/**
  The import operation cannot be performed because the specified transfer option set "%1$" is not for "high level" briefcase import. Please specify a transfer option set for "high level" briefcase import.
*/
#define TIE_invalid_optionset_for_hl_import             (TIE_error_base + 225)


/**
 The current user or the preference "Subscription_Table_Notify_Users" has no email address defined.
*/
#define TIE_invalid_subscription_table_notify_user      (TIE_error_base + 226)

/**
    The Consumer license "teamcenter_consumer" is not available for the user to export to the offline site.
*/
#define TIE_bc_export_req_consumer_license              (TIE_error_base + 227)

/**
    The Author license "teamcenter_author" is not available for the user to import to the offline site.
*/
#define TIE_bc_import_req_author_license                (TIE_error_base + 228)

/**
    The following UIDs are invalid: %1$.
*/
#define TIE_invalid_uids                                (TIE_error_base + 229)

/**
    For given input briefcase "%1$", there are either no objects found to recover the ownership or the ownership had already been recovered.
*/
#define TIE_briefcase_ot_not_found                      (TIE_error_base + 230)

/**
    Briefcase export is restricted because the selected target un-managed site is not marked for Briefcase Browser, and non-briefcase option is not provided.
*/
#define TIE_unmanaged_briefcase_export_not_allowed      (TIE_error_base + 231)

/**
   Import is successful, but root object(s) '%1$' insertion into folder '%2$' is failed.
*/
#define TIE_bc_import_folder_insert_failure      (TIE_error_base + 232)

/** @} */

#include <tie/libtie_undef.h>
#endif
