//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, Fnd0VisioDiagram
    Filename:   Fnd0VisioDiagram.hxx
    Module:     Fnd0nweditor
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__FND0VISIODIAGRAM__HXX
#define TEAMCENTER__FND0VISIODIAGRAM__HXX

#include <unidefs.h>
#include <vector>
#include <string>
#include <common/tc_deprecation_macros.h>
#include <Fnd0nweditor/Fnd0Diagram.hxx>

#include <Fnd0nweditor/libfnd0nweditor_exports.h>

namespace Teamcenter
{
    class Fnd0VisioDiagram;
}
namespace Teamcenter
{
    class Fnd0VisioDiagramImpl;
}
namespace Teamcenter
{
    class Fnd0VisioDiagramDelegate;
}
namespace Teamcenter
{
    class Fnd0VisioDiagramDispatch;
}
namespace Teamcenter
{
    class Fnd0VisioDiagramGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  FND0NWEDITOR_API  Teamcenter::Fnd0VisioDiagram
     : public  ::Teamcenter::Fnd0Diagram
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// createDiagram operation allows user to create a new diagram
    /// @version Teamcenter 9
    /// @param selectedObject - Starting object for diagram creation
    /// @param propNames - Vector holding Property names
    /// @param propValues - Vector holding Property values
    /// @param openDiagram - whether diagram should be open after create
    /// @param appDomain - Application Domain of this diagram
    /// @param diagramTemplateFileTickets - Collection structure holding FMS tickets to diagram template files
    /// @param diagMappingFileTicket - FMS ticket to diagram template mapping file
    /// @param diagramRev - Diagram Revision to be opened
    /// @param diagramMembersPrimaryTags - TCObject that should appear on diagram
    /// @param diagramMembersPersistentTags - TCObject that should appear on diagram
    /// @param typeNames - Object type of memeber
    /// @param relationMembersTags - Tags of relations on Diagram
    /// @param relationPrimary - Primary objects
    /// @param relationSecondary - Secondary objects
    /// @return - This function will return Diagram Members and Relations on Diagram
    ///
    int  fnd0CreateDiagram( const tag_t &selectedObject, const std::vector< std::string > &propNames, const std::vector< std::string > &propValues, const bool &openDiagram, std::string &appDomain, std::vector< std::string > &diagramTemplateFileTickets, std::string &diagMappingFileTicket, tag_t &diagramRev, std::vector< tag_t > &diagramMembersPrimaryTags, std::vector< tag_t > &diagramMembersPersistentTags, std::vector< std::string > &typeNames, std::vector< tag_t > &relationMembersTags, std::vector< tag_t > &relationPrimary, std::vector< tag_t > &relationSecondary );

    ///
    /// This function will execute the transfer mode on the root object and will return the result object
    /// @version Teamcenter 9
    /// @param rootObject - The object on which Transfer mode will be executed
    /// @param diagTmplRev - Instance of Diagram Tempalate Revision
    /// @param diagramMembers - Set of objects
    /// @return - Result of Transfer mode execution, which is set of object
    ///
    int  fnd0GetDiagramMembers( const tag_t &rootObject, const tag_t &diagTmplRev, std::vector< tag_t > *diagramMembers );

    ///
    /// This function will return all relations between given input object after applying the rule specified in the Diagram Temaplate
    /// @version Teamcenter 9
    /// @param diagramMembers - Set of objects to get relations between them
    /// @param diagTmplRev - Instance of Diagram Template Revision
    /// @param diagramRelations - Relations between input diagram members
    /// @param relationPrimary - Primary objects
    /// @param relationSecondary - Secondary objects
    /// @return - This function will return all relations between given input object after applying the rule specified in the Diagram Temaplate
    ///
    int  fnd0GetDiagramRelation( const std::vector< tag_t > &diagramMembers, const tag_t &diagTmplRev, std::vector< tag_t > &diagramRelations, std::vector< tag_t > &relationPrimary, std::vector< tag_t > &relationSecondary );

    ///
    /// openDiagram operation allows user to open existing diagram
    /// @version Teamcenter 9
    /// @param selectedObject - The selected object
    /// @param diagram_revision - Diagram to open
    /// @param diagramTemplateFileTickets - Collection structure holding FMS tickets to diagram template files
    /// @param diagramMappingFileTicket - FMS ticket to diagram template mapping file
    /// @param diagramFileTicket - FMS ticket to diagram file to be opened
    /// @param applicationDomain - Application Domain for the Diagram
    /// @param startObject - Starting object for diagram creation
    /// @param objectUIDs - Object UID of the TCobject
    /// @param shapeID - ShapeID of the shape that represent that TCobject on diagram
    /// @param diagramMembersPrimaryTags - Collection of Diagram Members
    /// @param diagramMembersPersistentTags - Collection of DiagramMmember structure
    /// @param typeNames - Type Name of Diagram member
    /// @param shapeRelationsOnMemberTags - Shape Relation for a Diagram Member
    /// @param relationMembers - Collection of RelationOnDigram
    /// @param shapeRelationsOnRelations - Shape Relation on the relatio on Diagram
    /// @param relationPrimary - Primary objects
    /// @param relationSecondary - Secondary objects
    /// @return - This function will return all information needed by client to display the Diagram
    ///
    int  fnd0openDiagram( const tag_t &selectedObject, const tag_t &diagram_revision, std::vector< std::string > &diagramTemplateFileTickets, std::string &diagramMappingFileTicket, std::string &diagramFileTicket, std::string &applicationDomain, tag_t &startObject, std::vector< std::string > &objectUIDs, std::vector< int > &shapeID, std::vector< tag_t > &diagramMembersPrimaryTags, std::vector< tag_t > &diagramMembersPersistentTags, std::vector< std::string > &typeNames, std::vector< tag_t > &shapeRelationsOnMemberTags, std::vector< tag_t > &relationMembers, std::vector< tag_t > &shapeRelationsOnRelations, std::vector< tag_t > &relationPrimary, std::vector< tag_t > &relationSecondary );

    ///
    /// saveDiagram operation uploads the diagram file and its image snap shot to the database
    /// @version Teamcenter 9
    /// @param selectedObject - The selected object
    /// @param diagramRevisionObject - Diagram Revision to be saved
    /// @param diagramFileTicket - FMS ticket to diagram file to be saved
    /// @param diagramImageFileTicket - FMS ticket to diagram image file to be saved
    /// @param resultObjects - This could return any number of Teamcenter objects
    /// @return - SaveDiagramResponse structure contains results of save operation
    ///
    int  fnd0SaveDiagram( const tag_t &selectedObject, const tag_t &diagramRevisionObject, const std::string *diagramFileTicket, const std::string *diagramImageFileTicket, std::vector< tag_t > *resultObjects );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    Fnd0VisioDiagram();

    /**
     * Destructor
     */
    virtual ~Fnd0VisioDiagram();

private:
    //  Getter method for the Implementation Object
    Fnd0VisioDiagramImpl*  getFnd0VisioDiagramImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setFnd0VisioDiagramImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    Fnd0VisioDiagramImpl*  m_fnd0visiodiagramImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param Fnd0VisioDiagram - desc for Fnd0VisioDiagram parameter
     */
    Fnd0VisioDiagram( const Fnd0VisioDiagram& );
    Fnd0VisioDiagram& operator=( const Fnd0VisioDiagram& );

    friend class  Fnd0VisioDiagramDelegate;
    friend class  Fnd0VisioDiagramDispatch;
    friend class  Fnd0VisioDiagramGenImpl;
};

#include <Fnd0nweditor/libfnd0nweditor_undef.h>
#endif //   TEAMCENTER__FND0VISIODIAGRAM__HXX
