//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, Fnd0VisioDiagramDelegate
    Filename:   Fnd0VisioDiagramDelegate.hxx
    Module:     Fnd0nweditor
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__FND0VISIODIAGRAMDELEGATE_HXX
#define TEAMCENTER__FND0VISIODIAGRAMDELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <Fnd0nweditor/Fnd0VisioDiagram.hxx>

#include <Fnd0nweditor/libfnd0nweditor_exports.h>

namespace Teamcenter
{
    class Fnd0VisioDiagramDelegate;
}
namespace Teamcenter
{
    class Fnd0VisioDiagramImpl;
}
namespace Teamcenter
{
    class Fnd0VisioDiagram;
}
namespace Teamcenter
{
    class Fnd0VisioDiagramGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  FND0NWEDITOR_API Teamcenter_alias::Fnd0VisioDiagramDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the Fnd0VisioDiagramDelegate instance
    static Fnd0VisioDiagramDelegate&  getInstance();

    //  Method to create the Fnd0VisioDiagramImpl pointer
    static Fnd0VisioDiagramImpl*  createImpl( Fnd0VisioDiagram&  ifObj );

    //  Method to delete the Fnd0VisioDiagramImpl pointer
    static void deleteImpl( Fnd0VisioDiagramImpl*  impl );


    ///
    /// createDiagram operation allows user to create a new diagram
    /// @version Teamcenter 9
    /// @param selectedObject - Starting object for diagram creation
    /// @param propNames - Vector holding Property names
    /// @param propValues - Vector holding Property values
    /// @param openDiagram - whether diagram should be open after create
    /// @param appDomain - Application Domain of this diagram
    /// @param diagramTemplateFileTickets - Collection structure holding FMS tickets to diagram template files
    /// @param diagMappingFileTicket - FMS ticket to diagram template mapping file
    /// @param diagramRev - Diagram Revision to be opened
    /// @param diagramMembersPrimaryTags - TCObject that should appear on diagram
    /// @param diagramMembersPersistentTags - TCObject that should appear on diagram
    /// @param typeNames - Object type of memeber
    /// @param relationMembersTags - Tags of relations on Diagram
    /// @param relationPrimary - Primary objects
    /// @param relationSecondary - Secondary objects
    /// @return - This function will return Diagram Members and Relations on Diagram
    ///
    int  fnd0CreateDiagramBase(const Fnd0VisioDiagram &ifObj,  const tag_t &selectedObject, const std::vector< std::string > &propNames, const std::vector< std::string > &propValues, const bool &openDiagram, std::string &appDomain, std::vector< std::string > &diagramTemplateFileTickets, std::string &diagMappingFileTicket, tag_t &diagramRev, std::vector< tag_t > &diagramMembersPrimaryTags, std::vector< tag_t > &diagramMembersPersistentTags, std::vector< std::string > &typeNames, std::vector< tag_t > &relationMembersTags, std::vector< tag_t > &relationPrimary, std::vector< tag_t > &relationSecondary );


    ///
    /// This function will execute the transfer mode on the root object and will return the result object
    /// @version Teamcenter 9
    /// @param rootObject - The object on which Transfer mode will be executed
    /// @param diagTmplRev - Instance of Diagram Tempalate Revision
    /// @param diagramMembers - Set of objects
    /// @return - Result of Transfer mode execution, which is set of object
    ///
    int  fnd0GetDiagramMembersBase(const Fnd0VisioDiagram &ifObj,  const tag_t &rootObject, const tag_t &diagTmplRev, std::vector< tag_t > *diagramMembers );


    ///
    /// This function will return all relations between given input object after applying the rule specified in the Diagram Temaplate
    /// @version Teamcenter 9
    /// @param diagramMembers - Set of objects to get relations between them
    /// @param diagTmplRev - Instance of Diagram Template Revision
    /// @param diagramRelations - Relations between input diagram members
    /// @param relationPrimary - Primary objects
    /// @param relationSecondary - Secondary objects
    /// @return - This function will return all relations between given input object after applying the rule specified in the Diagram Temaplate
    ///
    int  fnd0GetDiagramRelationBase(const Fnd0VisioDiagram &ifObj,  const std::vector< tag_t > &diagramMembers, const tag_t &diagTmplRev, std::vector< tag_t > &diagramRelations, std::vector< tag_t > &relationPrimary, std::vector< tag_t > &relationSecondary );


    ///
    /// openDiagram operation allows user to open existing diagram
    /// @version Teamcenter 9
    /// @param selectedObject - The selected object
    /// @param diagram_revision - Diagram to open
    /// @param diagramTemplateFileTickets - Collection structure holding FMS tickets to diagram template files
    /// @param diagramMappingFileTicket - FMS ticket to diagram template mapping file
    /// @param diagramFileTicket - FMS ticket to diagram file to be opened
    /// @param applicationDomain - Application Domain for the Diagram
    /// @param startObject - Starting object for diagram creation
    /// @param objectUIDs - Object UID of the TCobject
    /// @param shapeID - ShapeID of the shape that represent that TCobject on diagram
    /// @param diagramMembersPrimaryTags - Collection of Diagram Members
    /// @param diagramMembersPersistentTags - Collection of DiagramMmember structure
    /// @param typeNames - Type Name of Diagram member
    /// @param shapeRelationsOnMemberTags - Shape Relation for a Diagram Member
    /// @param relationMembers - Collection of RelationOnDigram
    /// @param shapeRelationsOnRelations - Shape Relation on the relatio on Diagram
    /// @param relationPrimary - Primary objects
    /// @param relationSecondary - Secondary objects
    /// @return - This function will return all information needed by client to display the Diagram
    ///
    int  fnd0openDiagramBase(const Fnd0VisioDiagram &ifObj,  const tag_t &selectedObject, const tag_t &diagram_revision, std::vector< std::string > &diagramTemplateFileTickets, std::string &diagramMappingFileTicket, std::string &diagramFileTicket, std::string &applicationDomain, tag_t &startObject, std::vector< std::string > &objectUIDs, std::vector< int > &shapeID, std::vector< tag_t > &diagramMembersPrimaryTags, std::vector< tag_t > &diagramMembersPersistentTags, std::vector< std::string > &typeNames, std::vector< tag_t > &shapeRelationsOnMemberTags, std::vector< tag_t > &relationMembers, std::vector< tag_t > &shapeRelationsOnRelations, std::vector< tag_t > &relationPrimary, std::vector< tag_t > &relationSecondary );


    ///
    /// saveDiagram operation uploads the diagram file and its image snap shot to the database
    /// @version Teamcenter 9
    /// @param selectedObject - The selected object
    /// @param diagramRevisionObject - Diagram Revision to be saved
    /// @param diagramFileTicket - FMS ticket to diagram file to be saved
    /// @param diagramImageFileTicket - FMS ticket to diagram image file to be saved
    /// @param resultObjects - This could return any number of Teamcenter objects
    /// @return - SaveDiagramResponse structure contains results of save operation
    ///
    int  fnd0SaveDiagramBase(const Fnd0VisioDiagram &ifObj,  const tag_t &selectedObject, const tag_t &diagramRevisionObject, const std::string *diagramFileTicket, const std::string *diagramImageFileTicket, std::vector< tag_t > *resultObjects );


    ///
    /// desc for createPost
    /// @version Tc 8
    /// @param creInput - Description for the Create Input
    /// @return - return desc for createPost
    ///
    int  createPostBase(const Fnd0VisioDiagram &ifObj,  ::Teamcenter::CreateInput *creInput );



protected:
    //  Pointer to the instance
    static Fnd0VisioDiagramDelegate*  m_pInstance;

    Fnd0VisioDiagramDelegate();
    virtual ~Fnd0VisioDiagramDelegate();
    static void setInstance( Fnd0VisioDiagramDelegate*  instance );


private:
    friend class  ::Teamcenter::Fnd0VisioDiagramGenImpl;

};

#include <Fnd0nweditor/libfnd0nweditor_undef.h>
#endif  //  TEAMCENTER__FND0VISIODIAGRAMDELEGATE_HXX
