//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, Lis0MediaWriter
    Filename:   Lis0MediaWriter.hxx
    Module:     Lis0lisfmwrk
    @BMIDE autogenerated
==================================================================================================*/

#ifndef LIS0LISFMWRK__LIS0MEDIAWRITER__HXX
#define LIS0LISFMWRK__LIS0MEDIAWRITER__HXX

#include <string>
#include <Lis0lisfmwrk/toolkit/AbstractResource.hxx>
#include <common/tc_deprecation_macros.h>
#include <tccore/POM_object.hxx>

#include <Lis0lisfmwrk/liblis0lisfmwrk_exports.h>

namespace lis0lisfmwrk
{
    class Lis0MediaWriter;
}
namespace lis0lisfmwrk
{
    class Lis0MediaWriterImpl;
}
namespace lis0lisfmwrk
{
    class Lis0MediaWriterDelegate;
}
namespace lis0lisfmwrk
{
    class Lis0MediaWriterDispatch;
}
namespace lis0lisfmwrk
{
    class Lis0MediaWriterGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  LIS0LISFMWRK_API  lis0lisfmwrk::Lis0MediaWriter
     : public  ::Teamcenter::POM_object
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// check if the required media types can be supported when reading
    /// @version Teamcenter 10.1.4
    /// @param requiredMediaType - required media type
    /// @param result - Is readable
    /// @return - Return error codes
    ///
    int  lis0IsReadable( const std::string *requiredMediaType, bool *result ) const;

    ///
    /// check if the required media types can be supported when writting
    /// @version Teamcenter 10.1.4
    /// @param requiredMediaType - required media type
    /// @param result - is writable
    /// @return - Return error codes
    ///
    int  lis0IsWritable( const std::string *requiredMediaType, bool *result ) const;

    ///
    /// read the document
    /// @version Teamcenter 10.1.4
    /// @param mediaType - media type
    /// @param document - document
    /// @param resourceModel - resource model
    /// @return - Return error codes
    ///
    int  lis0ReadFrom( const std::string *mediaType, const std::string *document, lis0lisfmwrk::AbstractResource **resourceModel ) const;

    ///
    /// write the document with the input media type
    /// @version Teamcenter 10.1.4
    /// @param mediaType - media type
    /// @param model - resource model
    /// @param document - writting document
    /// @return - Return error codes
    ///
    int  lis0WriteTo( const std::string *mediaType, const lis0lisfmwrk::AbstractResource *model, std::string *document ) const;
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    Lis0MediaWriter();

    /**
     * Destructor
     */
    virtual ~Lis0MediaWriter();

private:
    //  Getter method for the Implementation Object
    Lis0MediaWriterImpl*  getLis0MediaWriterImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setLis0MediaWriterImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    Lis0MediaWriterImpl*  m_lis0mediawriterImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param Lis0MediaWriter - desc for Lis0MediaWriter parameter
     */
    Lis0MediaWriter( const Lis0MediaWriter& );
    Lis0MediaWriter& operator=( const Lis0MediaWriter& );

    friend class  Lis0MediaWriterDelegate;
    friend class  Lis0MediaWriterDispatch;
    friend class  Lis0MediaWriterGenImpl;
};

#include <Lis0lisfmwrk/liblis0lisfmwrk_undef.h>
#endif //   LIS0LISFMWRK__LIS0MEDIAWRITER__HXX
