//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, Lis0ResourceAttrHelper
    Filename:   Lis0ResourceAttrHelper.hxx
    Module:     Lis0lisfmwrk
    @BMIDE autogenerated
==================================================================================================*/

#ifndef LIS0LISFMWRK__LIS0RESOURCEATTRHELPER__HXX
#define LIS0LISFMWRK__LIS0RESOURCEATTRHELPER__HXX

#include <unidefs.h>
#include <Lis0lisfmwrk/toolkit/Lis0ResourceShapeAttributes.hxx>
#include <string>
#include <Lis0lisfmwrk/toolkit/AbstractResource.hxx>
#include <common/tc_deprecation_macros.h>
#include <tccore/POM_object.hxx>

#include <Lis0lisfmwrk/liblis0lisfmwrk_exports.h>

namespace lis0lisfmwrk
{
    class Lis0ResourceAttrHelper;
}
namespace lis0lisfmwrk
{
    class Lis0ResourceAttrHelperImpl;
}
namespace lis0lisfmwrk
{
    class Lis0ResourceAttrHelperDelegate;
}
namespace lis0lisfmwrk
{
    class Lis0ResourceAttrHelperDispatch;
}
namespace lis0lisfmwrk
{
    class Lis0ResourceAttrHelperGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  LIS0LISFMWRK_API  lis0lisfmwrk::Lis0ResourceAttrHelper
     : public  ::Teamcenter::POM_object
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// collect the attributes of resource shape
    /// @version Teamcenter 10.1.4
    /// @param objTag - BO object
    /// @param boAttrMap - map holds the BO attributes
    /// @param relationMap - holds the relation attributes of Bo
    /// @param statusMap - hold the status of attributes
    /// @param compoundAttrsMap - holds the compund attributes of Bo
    /// @return - integer
    ///
    int  lis0collectAttributes( tag_t objTag, lis0lisfmwrk::Lis0ResourceShapeAttributes **boAttrMap, lis0lisfmwrk::Lis0ResourceShapeAttributes **relationMap, lis0lisfmwrk::Lis0ResourceShapeAttributes **statusMap, lis0lisfmwrk::Lis0ResourceShapeAttributes **compoundAttrsMap ) const;

    ///
    /// Collects the resource shape attributes
    /// @version Teamcenter 11.2.3
    /// @param catalogIdentifier - Catalog Identifier
    /// @param resourceObjectType - Resource Object Type Tag
    /// @param resourceShapeAttributes - Structure that holds resource shape attributes
    /// @param relationMap - holds the relation attributes of Business object
    /// @return - returns ITK_ok on success, respective error on failure
    ///
    int  lis0collectSemanticAttributes( const std::string &catalogIdentifier, const tag_t &resourceObjectType, lis0lisfmwrk::Lis0ResourceShapeAttributes **resourceShapeAttributes, lis0lisfmwrk::Lis0ResourceShapeAttributes **relationMap ) const;

    ///
    /// true/false return depending on the tag supported or not
    /// @version Teamcenter 10.1.4
    /// @param typeTag - checks the tag is in supported list or not
    /// @param isSupported - check the supported type is in supportes list or not
    /// @return - integer
    ///
    int  lis0isSuppportedType( tag_t typeTag, bool *isSupported ) const;

    ///
    /// update
    /// @version Teamcenter 10.1.4
    /// @param objTag - holds the object
    /// @param boAttrMap - BOattributes
    /// @param resourceModel - abstractResourceModel
    /// @return - integer
    ///
    int  lis0updateBOAttributes( tag_t objTag, lis0lisfmwrk::Lis0ResourceShapeAttributes *boAttrMap, lis0lisfmwrk::AbstractResource *resourceModel ) const;

    ///
    /// compoundAttributes
    /// @version Teamcenter 10.1.4
    /// @param objTag - Bo object
    /// @param compoundAttributesMap - holds the compund attributes of BO
    /// @param resourceModel - attribute of BO object
    /// @return - integer
    ///
    int  lis0updateCompundAttributes( tag_t objTag, lis0lisfmwrk::Lis0ResourceShapeAttributes *compoundAttributesMap, lis0lisfmwrk::AbstractResource *resourceModel ) const;

    ///
    /// Relation
    /// @version Teamcenter 10.1.4
    /// @param objTag - BO object
    /// @param relationMap - holds the relation attribute
    /// @param resourceModel - BO Attribute
    /// @return - integer
    ///
    int  lis0updateRelations( tag_t objTag, lis0lisfmwrk::Lis0ResourceShapeAttributes *relationMap, lis0lisfmwrk::AbstractResource *resourceModel ) const;

    ///
    /// status
    /// @version Teamcenter 10.1.4
    /// @param objTag - BO object
    /// @param statusMap - holds the updated status
    /// @param resourceModel - holds the resource model attribute
    /// @return - integer
    ///
    int  lis0updateStatus( tag_t objTag, lis0lisfmwrk::Lis0ResourceShapeAttributes *statusMap, lis0lisfmwrk::AbstractResource *resourceModel ) const;
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    Lis0ResourceAttrHelper();

    /**
     * Destructor
     */
    virtual ~Lis0ResourceAttrHelper();

private:
    //  Getter method for the Implementation Object
    Lis0ResourceAttrHelperImpl*  getLis0ResourceAttrHelperImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setLis0ResourceAttrHelperImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    Lis0ResourceAttrHelperImpl*  m_lis0resourceattrhelperImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param Lis0ResourceAttrHelper - desc for Lis0ResourceAttrHelper parameter
     */
    Lis0ResourceAttrHelper( const Lis0ResourceAttrHelper& );
    Lis0ResourceAttrHelper& operator=( const Lis0ResourceAttrHelper& );

    friend class  Lis0ResourceAttrHelperDelegate;
    friend class  Lis0ResourceAttrHelperDispatch;
    friend class  Lis0ResourceAttrHelperGenImpl;
};

#include <Lis0lisfmwrk/liblis0lisfmwrk_undef.h>
#endif //   LIS0LISFMWRK__LIS0RESOURCEATTRHELPER__HXX
