//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, Ccd0ParmFile
    Filename:   Ccd0ParmFile.hxx
    Module:     ccdm
    @BMIDE autogenerated
==================================================================================================*/

#ifndef CCDM__CCD0PARMFILE__HXX
#define CCDM__CCD0PARMFILE__HXX

#include <ccdm/Ccd0ExpImp.h>
#include <string>
#include <vector>
#include <common/tc_deprecation_macros.h>
#include <ae/Dataset.hxx>

#include <ccdm/libccdm_exports.h>

namespace ccdm
{
    class Ccd0ParmFile;
}
namespace ccdm
{
    class Ccd0ParmFileImpl;
}
namespace ccdm
{
    class Ccd0ParmFileDelegate;
}
namespace ccdm
{
    class Ccd0ParmFileDispatch;
}
namespace ccdm
{
    class Ccd0ParmFileGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  CCDM_API  ccdm::Ccd0ParmFile
     : public  ::Teamcenter::Dataset
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// Generates file for Dictionary sharing
    /// @version Teamcenter 9.1
    /// @param parmDictionaryData - Input data for Dictionary sharing
    /// @param fileNamePrefix - Returns status as int
    /// @param exportFileOutput - Output of generate file
    /// @return - Returns status as int
    ///
    int  ccd0generateFile( ParmDictionaySharingExpData *parmDictionaryData, std::string *fileNamePrefix, ExportFileOutput *exportFileOutput );

    ///
    /// Generates flash file
    /// @version Teamcenter 9.1
    /// @param parmFlashData - Data for flash file generation
    /// @param fileNamePrefix - File name prefix
    /// @param exportFileOutput - Output of generate file
    /// @return - Returns status as int
    ///
    int  ccd0generateFile( ParmFlashGenerationExpData *parmFlashData, std::string *fileNamePrefix, ExportFileOutput *exportFileOutput );

    ///
    /// Generates file for value sharing
    /// @version Teamcenter 9.1
    /// @param parmValueData - Input data for Value sharing
    /// @param fileNamePrefix - File name prefix
    /// @param exportFileOutput - Output of generate file
    /// @return - Returns status as int
    ///
    int  ccd0generateFile( ParmValueSharingExpData *parmValueData, std::string *fileNamePrefix, ExportFileOutput *exportFileOutput );

    ///
    /// Method to parse the specified parameter data file (A2L, CDF etc).
    /// @version Teamcenter 9.1
    /// @param vecFilesToParse - Vector of input files to parse
    /// @param importOutput - Output of the parsed files along with the errors if any.
    /// @return - Status code
    ///
    int  ccd0Parse( std::vector< std::string > *vecFilesToParse, DictionaryParseOutput *importOutput );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    Ccd0ParmFile();

    /**
     * Destructor
     */
    virtual ~Ccd0ParmFile();

private:
    //  Getter method for the Implementation Object
    Ccd0ParmFileImpl*  getCcd0ParmFileImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setCcd0ParmFileImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    Ccd0ParmFileImpl*  m_ccd0parmfileImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param Ccd0ParmFile - desc for Ccd0ParmFile parameter
     */
    Ccd0ParmFile( const Ccd0ParmFile& );
    Ccd0ParmFile& operator=( const Ccd0ParmFile& );

    friend class  Ccd0ParmFileDelegate;
    friend class  Ccd0ParmFileDispatch;
    friend class  Ccd0ParmFileGenImpl;
};

#include <ccdm/libccdm_undef.h>
#endif //   CCDM__CCD0PARMFILE__HXX
