//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, Fnd0ConditionHelper
    Filename:   Fnd0ConditionHelper.hxx
    Module:     ce
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__FND0CONDITIONHELPER__HXX
#define TEAMCENTER__FND0CONDITIONHELPER__HXX

#include <unidefs.h>
#include <string>
#include <common/tc_deprecation_macros.h>
#include <metaframework/RuntimeBusinessObject.hxx>

#include <ce/libce_exports.h>

namespace Teamcenter
{
    class Fnd0ConditionHelper;
}
namespace Teamcenter
{
    class Fnd0ConditionHelperImpl;
}
namespace Teamcenter
{
    class Fnd0ConditionHelperDelegate;
}
namespace Teamcenter
{
    class Fnd0ConditionHelperDispatch;
}
namespace Teamcenter
{
    class Fnd0ConditionHelperGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  CE_API  Teamcenter::Fnd0ConditionHelper
     : public  ::Teamcenter::RuntimeBusinessObject
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// 
    /// @version Teamcenter 12.4
    /// @param object - Selected object
    /// @param refPropName - TypeRef Property Name
    /// @param refPropName2 - Property name on the TypeRef object whose value is to be retrieved
    /// @param refPropValue - Property Value on the type ref object corresponding to refPropName2
    /// @return - 
    ///
    int  fnd0getPropValueOnRefObj( tag_t object, std::string &refPropName, std::string &refPropName2, std::string &refPropValue );

    ///
    /// Is the date null?
    /// @version Teamcenter 9.1
    /// @param date - The date to check
    /// @param isNull - Is the date null?
    /// @return - ITK_OK
    ///
    int  fnd0isNullDate( const date_t date, bool *isNull );

    ///
    /// Operation to verify whether a group is a sub-group of another Group.
    /// @version Teamcenter 11.2
    /// @param group - group object
    /// @param parentGroupName - The parent group name.
    /// @param result - True if the group is the sub group of a group identified by parentGroupName
    /// @return - ITK_ok if no error else error code
    ///
    int  fnd0isSubGroupOf( const tag_t group, const std::string &parentGroupName, bool *result );

    ///
    /// Operation to verify if an object type matches another type or its subtypes.
    /// @version Teamcenter 11.2
    /// @param target - Input object Tag. It can be either WorkspaceObject Tag or its Type Tag.
    /// @param parentTypeName - The parent type name.
    /// @param result - True if the type of target is same as or subtype of type identified by parentTypeName.
    /// @return - ITK_ok if no error else error code.
    ///
    int  fnd0isSubTypeOf( tag_t target, const std::string &parentTypeName, bool *result );

    ///
    /// checks if input value is present in the given preference.
    /// @version Teamcenter 10.1
    /// @param prefName - Preference name
    /// @param prefValue - preference value
    /// @param isMatched - True, If input values matches with preference value.
    /// @return - ITK_OK
    ///
    int  fnd0isValuePresentInPref( std::string &prefName, std::string &prefValue, bool *isMatched );

    ///
    /// Sets the date to the current date and time
    /// @version Teamcenter 9.1
    /// @param now - The current date time
    /// @return - ITK_OK
    ///
    int  fnd0Now( date_t *now );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    Fnd0ConditionHelper();

    /**
     * Destructor
     */
    virtual ~Fnd0ConditionHelper();

private:
    //  Getter method for the Implementation Object
    Fnd0ConditionHelperImpl*  getFnd0ConditionHelperImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setFnd0ConditionHelperImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    Fnd0ConditionHelperImpl*  m_fnd0conditionhelperImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param Fnd0ConditionHelper - desc for Fnd0ConditionHelper parameter
     */
    Fnd0ConditionHelper( const Fnd0ConditionHelper& );
    Fnd0ConditionHelper& operator=( const Fnd0ConditionHelper& );

    friend class  Fnd0ConditionHelperDelegate;
    friend class  Fnd0ConditionHelperDispatch;
    friend class  Fnd0ConditionHelperGenImpl;
};

#include <ce/libce_undef.h>
#endif //   TEAMCENTER__FND0CONDITIONHELPER__HXX
