//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, UserSession
    Filename:   UserSession.hxx
    Module:     ce
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__USERSESSION__HXX
#define TEAMCENTER__USERSESSION__HXX

#include <string>
#include <unidefs.h>
#include <vector>
#include <common/tc_deprecation_macros.h>
#include <metaframework/RuntimeBusinessObject.hxx>

#include <ce/libce_exports.h>

namespace Teamcenter
{
    class UserSession;
}
namespace Teamcenter
{
    class UserSessionImpl;
}
namespace Teamcenter
{
    class UserSessionDelegate;
}
namespace Teamcenter
{
    class UserSessionDispatch;
}
namespace Teamcenter
{
    class UserSessionGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  CE_API  Teamcenter::UserSession
     : public  ::Teamcenter::RuntimeBusinessObject
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// Getter for a Boolean Property
    /// @version Teamcenter 9
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0bypassflag( bool &value, bool &isNull ) const;

    ///
    /// Getter for a string Property
    /// @version Teamcenter 9
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0displayrule( std::string &value, bool &isNull ) const;

    ///
    /// Getter for an String Array Property
    /// @version Teamcenter 9
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0displayTypes( std::vector< std::string > &values, std::vector< int > &isNull ) const;

    ///
    /// Getter for a Tag Property
    /// @version Teamcenter 9
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0groupmember( tag_t &value, bool &isNull ) const;

    ///
    /// Getter for an String Array Property
    /// @version Teamcenter 9
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0isTrueConditions( std::vector< std::string > &values, std::vector< int > &isNull ) const;

    ///
    /// Getter for a string Property
    /// @version Teamcenter 9
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0locale( std::string &value, bool &isNull ) const;

    ///
    /// Getter for a Tag Property
    /// @version Teamcenter 9.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0LocalVolume( tag_t &value, bool &isNull ) const;

    ///
    /// Getter for a string Property
    /// @version Teamcenter 11.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0LocationCode( std::string &value, bool &isNull ) const;

    ///
    /// Getter for a Tag Property
    /// @version Teamcenter 9
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0organization( tag_t &value, bool &isNull ) const;

    ///
    /// Getter for a Boolean Property
    /// @version Teamcenter 11.6
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0ShowGDPR( bool &value, bool &isNull ) const;

    ///
    /// The operation returns classic multisite active session status.
    /// @version Teamcenter 10
    /// @param isActive - Returns an integer based classic multisite session status.
    /// @return - Returns an integer based classic multisite session status.
    ///
    int  fnd0getClassMultisiteSessionStatus( int *isActive );

    ///
    /// This operation returns the full group name of the current login user, including all the sub-groups.
    /// @version Teamcenter 8.2
    /// @param gname - A string representing the group name
    /// @return - Return a string representing the group name
    ///
    int  fnd0getGroupName( std::string &gname );

    ///
    /// The operation returns PIE active session status.
    /// @version Teamcenter 10
    /// @param isActive - An integer representing PIE session
    /// @return - Returns an integer based PIE session status.
    ///
    int  fnd0getPIESessionStatus( int *isActive );

    ///
    /// isInProjListORSessionProject
    /// @version Teamcenter 9
    /// @param object - object
    /// @param projectName - ProjectName
    /// @param output - output
    /// @return - int
    ///
    int  fnd0isInProjListORSessionProject( const tag_t &object, std::string &projectName, bool *output );

    ///
    /// isOwningORSessionProject
    /// @version Teamcenter 9
    /// @param object - object
    /// @param projectName - ProjectName
    /// @param output - output
    /// @return - int
    ///
    int  fnd0isOwningORSessionProject( const tag_t &object, std::string &projectName, bool *output );

    ///
    /// The operation returns the license level of the login user.
    /// @version Teamcenter 8.0.1
    /// @param level - An integer representing the license level
    /// @return - Returns an integer representing the license level.
    ///
    int  getLicenseLevel( int *level );

    ///
    /// The operation returns TIE active session status.
    /// @version Teamcenter 8.1
    /// @param isActive - An integer representing TIE session
    /// @return - Returns an integer based TIE session status.
    ///
    int  getTIESessionStatus( int *isActive );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    UserSession();

    /**
     * Destructor
     */
    virtual ~UserSession();

private:
    //  Getter method for the Implementation Object
    UserSessionImpl*  getUserSessionImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setUserSessionImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    UserSessionImpl*  m_usersessionImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param UserSession - desc for UserSession parameter
     */
    UserSession( const UserSession& );
    UserSession& operator=( const UserSession& );

    friend class  UserSessionDelegate;
    friend class  UserSessionDispatch;
    friend class  UserSessionGenImpl;
};

#include <ce/libce_undef.h>
#endif //   TEAMCENTER__USERSESSION__HXX
