//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, EPMHandler
    Filename:   EPMHandler.hxx
    Module:     epm
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__EPMHANDLER__HXX
#define TEAMCENTER__EPMHANDLER__HXX

#include <vector>
#include <string>
#include <unidefs.h>
#include <common/tc_deprecation_macros.h>
#include <tccore/POM_object.hxx>

#include <epm/libepm_exports.h>

namespace Teamcenter
{
    class EPMHandler;
}
namespace Teamcenter
{
    class EPMHandlerImpl;
}
namespace Teamcenter
{
    class EPMHandlerDelegate;
}
namespace Teamcenter
{
    class EPMHandlerDispatch;
}
namespace Teamcenter
{
    class EPMHandlerGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  EPM_API  Teamcenter::EPMHandler
     : public  ::Teamcenter::POM_object
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// Getter for an String Array Property
    /// @version Teamcenter 10.1
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getHandler_arguments( std::vector< std::string > &values, std::vector< int > &isNull ) const;

    ///
    /// Getter for a string Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getHandler_name( std::string &value, bool &isNull ) const;

    ///
    /// Getter for an Integer Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getHandler_type( int &value, bool &isNull ) const;

    ///
    /// Getter for an Integer Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getNumber_of_arguments( int &value, bool &isNull ) const;

    ///
    /// Getter for a string Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getObject_name( std::string &value, bool &isNull ) const;

    ///
    /// Getter for a Tag Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getParent_action( tag_t &value, bool &isNull ) const;

    ///
    /// Getter for an Integer Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getParent_action_type( int &value, bool &isNull ) const;

    ///
    /// Getter for a Tag Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getParent_task_template( tag_t &value, bool &isNull ) const;

    ///
    /// Setter for an string Array Property
    /// @version Teamcenter 10.1
    /// @param values - Values to be set for the parameter
    /// @param isNull - If array element is true, set the parameter value at that location as null
    /// @return - Status. 0 if successful
    ///
    int  setHandler_arguments( const std::vector< std::string > &values, const std::vector< int > *isNull=0 );

    ///
    /// Setter for a string Property
    /// @version Teamcenter 10.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setHandler_name( const std::string &value, bool isNull=false );

    ///
    /// Setter for an Integer Property
    /// @version Teamcenter 10.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setNumber_of_arguments( int value, bool isNull=false );

    ///
    /// Setter for a string Property
    /// @version Teamcenter 10.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setObject_name( const std::string &value, bool isNull=false );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    EPMHandler();

    /**
     * Destructor
     */
    virtual ~EPMHandler();

private:
    //  Getter method for the Implementation Object
    EPMHandlerImpl*  getEPMHandlerImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setEPMHandlerImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    EPMHandlerImpl*  m_epmhandlerImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param EPMHandler - desc for EPMHandler parameter
     */
    EPMHandler( const EPMHandler& );
    EPMHandler& operator=( const EPMHandler& );

    friend class  EPMHandlerDelegate;
    friend class  EPMHandlerDispatch;
    friend class  EPMHandlerGenImpl;
};

#include <epm/libepm_undef.h>
#endif //   TEAMCENTER__EPMHANDLER__HXX
