//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, Participant
    Filename:   Participant.hxx
    Module:     epm
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__PARTICIPANT__HXX
#define TEAMCENTER__PARTICIPANT__HXX

#include <unidefs.h>
#include <vector>
#include <string>
#include <common/tc_deprecation_macros.h>
#include <tccore/POM_object.hxx>

#include <epm/libepm_exports.h>

namespace Teamcenter
{
    class Participant;
}
namespace Teamcenter
{
    class ParticipantImpl;
}
namespace Teamcenter
{
    class ParticipantDelegate;
}
namespace Teamcenter
{
    class ParticipantDispatch;
}
namespace Teamcenter
{
    class ParticipantGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  EPM_API  Teamcenter::Participant
     : public  ::Teamcenter::POM_object
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// Getter for a Tag Property
    /// @version Tc 8
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getAssignee( tag_t &value, bool &isNull ) const;

    ///
    /// Getter for a Tag Property
    /// @version Teamcenter 11.2
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0AssigneeGroup( tag_t &value, bool &isNull ) const;

    ///
    /// Getter for Property Display Value
    /// @version Teamcenter 11.2
    /// @param values - Parameter value
    /// @return - Status. 0 if successful
    ///
    int  getFnd0AssigneeGroupDisplayableValues( std::vector< std::string > &values );

    ///
    /// Getter for a string Property
    /// @version Teamcenter 11.2
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0AssigneeGroupRole( std::string &value, bool &isNull ) const;

    ///
    /// Getter for a Tag Property
    /// @version Teamcenter 11.2
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0AssigneeRole( tag_t &value, bool &isNull ) const;

    ///
    /// Getter for Property Display Value
    /// @version Teamcenter 11.2
    /// @param values - Parameter value
    /// @return - Status. 0 if successful
    ///
    int  getFnd0AssigneeRoleDisplayableValues( std::vector< std::string > &values );

    ///
    /// Setter for a Tag Property
    /// @version Tc 8
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setAssignee( const tag_t &value, bool isNull=false );

    ///
    /// This operation determines if the participant is assignable.
    /// @version Tc 8
    /// @param user - A user tag
    /// @param object - An object tag
    /// @param assignable - A pointer to a boolean whose value, when returned, is the result of the evaluation
    /// @return - An ifail integer
    ///
    int  isAssignable( tag_t user, tag_t object, bool *assignable );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    Participant();

    /**
     * Destructor
     */
    virtual ~Participant();

private:
    //  Getter method for the Implementation Object
    ParticipantImpl*  getParticipantImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setParticipantImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    ParticipantImpl*  m_participantImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param Participant - desc for Participant parameter
     */
    Participant( const Participant& );
    Participant& operator=( const Participant& );

    friend class  ParticipantDelegate;
    friend class  ParticipantDispatch;
    friend class  ParticipantGenImpl;
    friend class  ParticipantImpl;
};

#include <epm/libepm_undef.h>
#endif //   TEAMCENTER__PARTICIPANT__HXX
