//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, User_Inbox
    Filename:   User_Inbox.hxx
    Module:     epm
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__USER_INBOX__HXX
#define TEAMCENTER__USER_INBOX__HXX

#include <unidefs.h>
#include <vector>
#include <common/tc_deprecation_macros.h>
#include <tc/Folder.hxx>

#include <epm/libepm_exports.h>

namespace Teamcenter
{
    class User_Inbox;
}
namespace Teamcenter
{
    class User_InboxImpl;
}
namespace Teamcenter
{
    class User_InboxDelegate;
}
namespace Teamcenter
{
    class User_InboxDispatch;
}
namespace Teamcenter
{
    class User_InboxGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  EPM_API  Teamcenter::User_Inbox
     : public  ::Teamcenter::Folder
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// Getter for a Date Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getEnd_date( date_t &value, bool &isNull ) const;

    ///
    /// Getter for a Tag Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getInbox_delegate( tag_t &value, bool &isNull ) const;

    ///
    /// Getter for a Boolean Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getIs_out_of_office( bool &value, bool &isNull ) const;

    ///
    /// Getter for a Boolean Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getIs_valid_surrogate( bool &value, bool &isNull ) const;

    ///
    /// Getter for an Integer Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getNew_tasks( int &value, bool &isNull ) const;

    ///
    /// Getter for a Date Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getStart_date( date_t &value, bool &isNull ) const;

    ///
    /// Getter for a Date Array Property
    /// @version Teamcenter 10.1
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getSurrogate_end_dates( std::vector< date_t > &values, std::vector< int > &isNull ) const;

    ///
    /// Getter for a Tag Array Property
    /// @version Teamcenter 10.1
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getSurrogate_list( std::vector< tag_t > &values, std::vector< int > &isNull ) const;

    ///
    /// Getter for a Date Array Property
    /// @version Teamcenter 10.1
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getSurrogate_st_dates( std::vector< date_t > &values, std::vector< int > &isNull ) const;

    ///
    /// Setter for a Date Property
    /// @version Teamcenter 10.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setEnd_date( const date_t &value, bool isNull=false );

    ///
    /// Setter for a Tag Property
    /// @version Teamcenter 10.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setInbox_delegate( const tag_t &value, bool isNull=false );

    ///
    /// Setter for an Integer Property
    /// @version Teamcenter 10.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setNew_tasks( int value, bool isNull=false );

    ///
    /// Setter for a Date Property
    /// @version Teamcenter 10.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setStart_date( const date_t &value, bool isNull=false );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    User_Inbox();

    /**
     * Destructor
     */
    virtual ~User_Inbox();

private:
    //  Getter method for the Implementation Object
    User_InboxImpl*  getUser_InboxImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setUser_InboxImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    User_InboxImpl*  m_user_inboxImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param User_Inbox - desc for User_Inbox parameter
     */
    User_Inbox( const User_Inbox& );
    User_Inbox& operator=( const User_Inbox& );

    friend class  User_InboxDelegate;
    friend class  User_InboxDispatch;
    friend class  User_InboxGenImpl;
};

#include <epm/libepm_undef.h>
#endif //   TEAMCENTER__USER_INBOX__HXX
