//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, FunctionalityRule
    Filename:   FunctionalityRule.hxx
    Module:     functionality
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__FUNCTIONALITYRULE__HXX
#define TEAMCENTER__FUNCTIONALITYRULE__HXX

#include <vector>
#include <string>
#include <common/tc_deprecation_macros.h>
#include <rbf/BusinessElement.hxx>

#include <functionality/libfunctionality_exports.h>

namespace Teamcenter
{
    class FunctionalityRule;
}
namespace Teamcenter
{
    class FunctionalityRuleImpl;
}
namespace Teamcenter
{
    class FunctionalityRuleDelegate;
}
namespace Teamcenter
{
    class FunctionalityRuleDispatch;
}
namespace Teamcenter
{
    class FunctionalityRuleGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  FUNCTIONALITY_API  Teamcenter::FunctionalityRule
     : public  ::Teamcenter::BusinessElement
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// Getter for a Tag Array Property
    /// @version Teamcenter 8.1
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getCondition_signatures( std::vector< tag_t > &values, std::vector< int > &isNull ) const;

    ///
    /// Getter for a string Property
    /// @version Teamcenter 8.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getDisplay_name( std::string &value, bool &isNull ) const;

    ///
    /// Getter for a Boolean Property
    /// @version Teamcenter 8.1
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getEnabledForVerificationRules( bool &value, bool &isNull ) const;

    ///
    /// Getter for a string Property
    /// @version Teamcenter 8.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getSubGroupLOV( std::string &value, bool &isNull ) const;

    ///
    /// Getter for an String Array Property
    /// @version Teamcenter 8.1
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getType_scope( std::vector< std::string > &values, std::vector< int > &isNull ) const;

    ///
    /// Setter for a Tag Array Property
    /// @version Teamcenter 8.1
    /// @param values - Values to be set for the parameter
    /// @param isNull - If array element is true, set the parameter value at that location as null
    /// @return - Status. 0 if successful
    ///
    int  setCondition_signatures( const std::vector< tag_t > &values, const std::vector< int > *isNull=0 );

    ///
    /// Setter for a string Property
    /// @version Teamcenter 8.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setDisplay_name( const std::string &value, bool isNull=false );

    ///
    /// Setter for a Boolean Property
    /// @version Teamcenter 8.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setEnabledForVerificationRules( bool value, bool isNull=false );

    ///
    /// Setter for a string Property
    /// @version Teamcenter 8.1
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setSubGroupLOV( const std::string &value, bool isNull=false );

    ///
    /// Setter for an string Array Property
    /// @version Teamcenter 8.1
    /// @param values - Values to be set for the parameter
    /// @param isNull - If array element is true, set the parameter value at that location as null
    /// @return - Status. 0 if successful
    ///
    int  setType_scope( const std::vector< std::string > &values, const std::vector< int > *isNull=0 );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    FunctionalityRule();

    /**
     * Destructor
     */
    virtual ~FunctionalityRule();

private:
    //  Getter method for the Implementation Object
    FunctionalityRuleImpl*  getFunctionalityRuleImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setFunctionalityRuleImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    FunctionalityRuleImpl*  m_functionalityruleImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param FunctionalityRule - desc for FunctionalityRule parameter
     */
    FunctionalityRule( const FunctionalityRule& );
    FunctionalityRule& operator=( const FunctionalityRule& );

    friend class  FunctionalityRuleDelegate;
    friend class  FunctionalityRuleDispatch;
    friend class  FunctionalityRuleGenImpl;
};

#include <functionality/libfunctionality_undef.h>
#endif //   TEAMCENTER__FUNCTIONALITYRULE__HXX
