//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, Fnd0ListOfValuesDynamic
    Filename:   Fnd0ListOfValuesDynamic.hxx
    Module:     lov
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__FND0LISTOFVALUESDYNAMIC__HXX
#define TEAMCENTER__FND0LISTOFVALUESDYNAMIC__HXX

#include <unidefs.h>
#include <string>
#include <vector>
#include <common/tc_deprecation_macros.h>
#include <lov/ListOfValues.hxx>

#include <lov/liblov_exports.h>

namespace Teamcenter
{
    class Fnd0ListOfValuesDynamic;
}
namespace Teamcenter
{
    class Fnd0ListOfValuesDynamicImpl;
}
namespace Teamcenter
{
    class Fnd0ListOfValuesDynamicDelegate;
}
namespace Teamcenter
{
    class Fnd0ListOfValuesDynamicDispatch;
}
namespace Teamcenter
{
    class Fnd0ListOfValuesDynamicGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  LOV_API  Teamcenter::Fnd0ListOfValuesDynamic
     : public  ::Teamcenter::ListOfValues
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// Getter for an String Array Property
    /// @version Teamcenter 10
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0query_clause( std::vector< std::string > &values, std::vector< int > &isNull ) const;

    ///
    /// Returns List Of Values based on Dynamic LOV definition and user search criteria.
    /// @version Teamcenter 10
    /// @param operationInputTag - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param searchString - User entered search string.
    /// @param sortByProp - Property to use for sorting.
    /// @param sortOrder - order for sorting (0=Ascending, 1=Descending).
    /// @param nResults - Number of returned results.
    /// @param results - Returned Values for LOV.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0askLOVValues( const tag_t operationInputTag, const std::string *propertyName, const std::string *searchString, const char *sortByProp, const int sortOrder, int *nResults, tag_t **results ) const;

    ///
    /// For extraction of Dynamic LOV definition.
    /// @version Teamcenter 10
    /// @param queryType - The name of the Business Object on which Query is written.
    /// @param queryClause - The query clauses.
    /// @param filterAttributes - Additional searchable attributes by user.
    /// @param lovValue - User specified property which will be shown as LOV value.
    /// @param lovValDescription - User specified property which will be shown as LOV value description. Can be null.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0getDynamicLOVData( std::string *queryType, std::string *queryClause, std::vector< std::string > *filterAttributes, std::string *lovValue, std::string *lovValDescription ) const;

    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInput - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValid( const tag_t operationInput, const std::string *propertyName, const date_t value, bool *verdict ) const;

    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInput - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValid( const tag_t operationInput, const std::string *propertyName, const double value, bool *verdict ) const;

    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInput - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValid( const tag_t operationInput, const std::string *propertyName, const int value, bool *verdict ) const;

    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInputTag - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValid( const tag_t operationInputTag, const std::string *propertyName, const std::string *value, bool *verdict ) const;

    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInput - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValid( const tag_t operationInput, const std::string *propertyName, const tag_t value, bool *verdict ) const;

    ///
    /// Set the LOV data for query.
    /// @version Teamcenter 10
    /// @param queryType - The name of the Business Object on which Query is written.
    /// @param queryClause - The query clauses for the search.
    /// @param filterAttributes - Additional searchable attributes by user.
    /// @param lovValue - User specified property which will be shown as LOV value.
    /// @param lovValDescription - User specified property which will be shown as LOV value description. Can be null.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0setDynamicLOVData( const std::string *queryType, const std::string *queryClause, const std::vector< std::string > *filterAttributes, const std::string *lovValue, std::string *lovValDescription );

    ///
    /// Set the Filter Attributes to be used in the query.
    /// @version Teamcenter 10
    /// @param filterAttributes - Additional searchable attributes by user.  Can be null.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0setDynamicLOVFilters( const std::vector< std::string > *filterAttributes );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    Fnd0ListOfValuesDynamic();

    /**
     * Destructor
     */
    virtual ~Fnd0ListOfValuesDynamic();

private:
    //  Getter method for the Implementation Object
    Fnd0ListOfValuesDynamicImpl*  getFnd0ListOfValuesDynamicImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setFnd0ListOfValuesDynamicImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    Fnd0ListOfValuesDynamicImpl*  m_fnd0listofvaluesdynamicImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param Fnd0ListOfValuesDynamic - desc for Fnd0ListOfValuesDynamic parameter
     */
    Fnd0ListOfValuesDynamic( const Fnd0ListOfValuesDynamic& );
    Fnd0ListOfValuesDynamic& operator=( const Fnd0ListOfValuesDynamic& );

    friend class  Fnd0ListOfValuesDynamicDelegate;
    friend class  Fnd0ListOfValuesDynamicDispatch;
    friend class  Fnd0ListOfValuesDynamicGenImpl;
};

#include <lov/liblov_undef.h>
#endif //   TEAMCENTER__FND0LISTOFVALUESDYNAMIC__HXX
