//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, Fnd0ListOfValuesDynamicDelegate
    Filename:   Fnd0ListOfValuesDynamicDelegate.hxx
    Module:     lov
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__FND0LISTOFVALUESDYNAMICDELEGATE_HXX
#define TEAMCENTER__FND0LISTOFVALUESDYNAMICDELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <lov/Fnd0ListOfValuesDynamic.hxx>

#include <lov/liblov_exports.h>

namespace Teamcenter
{
    class Fnd0ListOfValuesDynamicDelegate;
}
namespace Teamcenter
{
    class Fnd0ListOfValuesDynamicImpl;
}
namespace Teamcenter
{
    class Fnd0ListOfValuesDynamic;
}
namespace Teamcenter
{
    class Fnd0ListOfValuesDynamicGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  LOV_API Teamcenter_alias::Fnd0ListOfValuesDynamicDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the Fnd0ListOfValuesDynamicDelegate instance
    static Fnd0ListOfValuesDynamicDelegate&  getInstance();

    //  Method to create the Fnd0ListOfValuesDynamicImpl pointer
    static Fnd0ListOfValuesDynamicImpl*  createImpl( Fnd0ListOfValuesDynamic&  ifObj );

    //  Method to delete the Fnd0ListOfValuesDynamicImpl pointer
    static void deleteImpl( Fnd0ListOfValuesDynamicImpl*  impl );


    ///
    /// Getter for an String Array Property
    /// @version Teamcenter 10
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0query_clauseBase(const Fnd0ListOfValuesDynamic &ifObj,  std::vector< std::string > &values, std::vector< int > &isNull ) const;


    ///
    /// Returns List Of Values based on Dynamic LOV definition and user search criteria.
    /// @version Teamcenter 10
    /// @param operationInputTag - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param searchString - User entered search string.
    /// @param sortByProp - Property to use for sorting.
    /// @param sortOrder - order for sorting (0=Ascending, 1=Descending).
    /// @param nResults - Number of returned results.
    /// @param results - Returned Values for LOV.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0askLOVValuesBase(const Fnd0ListOfValuesDynamic &ifObj,  const tag_t operationInputTag, const std::string *propertyName, const std::string *searchString, const char *sortByProp, const int sortOrder, int *nResults, tag_t **results ) const;


    ///
    /// For extraction of Dynamic LOV definition.
    /// @version Teamcenter 10
    /// @param queryType - The name of the Business Object on which Query is written.
    /// @param queryClause - The query clauses.
    /// @param filterAttributes - Additional searchable attributes by user.
    /// @param lovValue - User specified property which will be shown as LOV value.
    /// @param lovValDescription - User specified property which will be shown as LOV value description. Can be null.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0getDynamicLOVDataBase(const Fnd0ListOfValuesDynamic &ifObj,  std::string *queryType, std::string *queryClause, std::vector< std::string > *filterAttributes, std::string *lovValue, std::string *lovValDescription ) const;


    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInput - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValidBase(const Fnd0ListOfValuesDynamic &ifObj,  const tag_t operationInput, const std::string *propertyName, const date_t value, bool *verdict ) const;


    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInput - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValidBase(const Fnd0ListOfValuesDynamic &ifObj,  const tag_t operationInput, const std::string *propertyName, const double value, bool *verdict ) const;


    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInput - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValidBase(const Fnd0ListOfValuesDynamic &ifObj,  const tag_t operationInput, const std::string *propertyName, const int value, bool *verdict ) const;


    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInputTag - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValidBase(const Fnd0ListOfValuesDynamic &ifObj,  const tag_t operationInputTag, const std::string *propertyName, const std::string *value, bool *verdict ) const;


    ///
    /// Returns true if the input value is valid for the Dynamic LOV.
    /// @version Teamcenter 10
    /// @param operationInput - Operation Input containing the modified values.
    /// @param propertyName - Name of the selected property.
    /// @param value - Value to validate.
    /// @param verdict - true if value is valid.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0isValueValidBase(const Fnd0ListOfValuesDynamic &ifObj,  const tag_t operationInput, const std::string *propertyName, const tag_t value, bool *verdict ) const;


    ///
    /// Set the LOV data for query.
    /// @version Teamcenter 10
    /// @param queryType - The name of the Business Object on which Query is written.
    /// @param queryClause - The query clauses for the search.
    /// @param filterAttributes - Additional searchable attributes by user.
    /// @param lovValue - User specified property which will be shown as LOV value.
    /// @param lovValDescription - User specified property which will be shown as LOV value description. Can be null.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0setDynamicLOVDataBase(const Fnd0ListOfValuesDynamic &ifObj,  const std::string *queryType, const std::string *queryClause, const std::vector< std::string > *filterAttributes, const std::string *lovValue, std::string *lovValDescription );


    ///
    /// Set the Filter Attributes to be used in the query.
    /// @version Teamcenter 10
    /// @param filterAttributes - Additional searchable attributes by user.  Can be null.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0setDynamicLOVFiltersBase(const Fnd0ListOfValuesDynamic &ifObj,  const std::vector< std::string > *filterAttributes );



protected:
    //  Pointer to the instance
    static Fnd0ListOfValuesDynamicDelegate*  m_pInstance;

    Fnd0ListOfValuesDynamicDelegate();
    virtual ~Fnd0ListOfValuesDynamicDelegate();
    static void setInstance( Fnd0ListOfValuesDynamicDelegate*  instance );


private:
    friend class  ::Teamcenter::Fnd0ListOfValuesDynamicGenImpl;

};

#include <lov/liblov_undef.h>
#endif  //  TEAMCENTER__FND0LISTOFVALUESDYNAMICDELEGATE_HXX
