//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, AllocationDelegate
    Filename:   AllocationDelegate.hxx
    Module:     mechatronics
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__ALLOCATIONDELEGATE_HXX
#define TEAMCENTER__ALLOCATIONDELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <mechatronics/Allocation.hxx>

#include <mechatronics/libmechatronics_exports.h>

namespace Teamcenter
{
    class AllocationDelegate;
}
namespace Teamcenter
{
    class AllocationImpl;
}
namespace Teamcenter
{
    class Allocation;
}
namespace Teamcenter
{
    class AllocationGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  MECHATRONICS_API Teamcenter_alias::AllocationDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the AllocationDelegate instance
    static AllocationDelegate&  getInstance();

    //  Method to create the AllocationImpl pointer
    static AllocationImpl*  createImpl( Allocation&  ifObj );

    //  Method to delete the AllocationImpl pointer
    static void deleteImpl( AllocationImpl*  impl );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @param isLockForDelete - A boolean to indicate if object(s) are to be locked for deletion
    /// @param allowRelock - A boolean to indicate if object(s) can be relocked, which will discard all unsaved changes, if already locked by the same user
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0LockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd, const bool isLockForDelete, const bool allowRelock );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0RefreshBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0SaveBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0UnlockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// Description for the Finalize Create Input
    /// @version Tc 8
    /// @param creInput - desc for  creInput parameter
    /// @return - Return desc for Initialize for Create
    ///
    int  finalizeCreateInputBase(const Allocation &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// desc for setPropertiesFromCreateInpu
    /// @version Tc 8
    /// @param creInput - Description for CreateInput
    /// @return - return desc for setPropertiesFromCreateInput
    ///
    int  setPropertiesFromCreateInputBase(const Allocation &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// desc for validate for create
    /// @version Tc 8
    /// @param creInput - desc for creInput parameter
    /// @return - ret desc for validate for create
    ///
    int  validateCreateInputBase(const Allocation &ifObj,  ::Teamcenter::CreateInput *creInput );



protected:
    //  Pointer to the instance
    static AllocationDelegate*  m_pInstance;

    AllocationDelegate();
    virtual ~AllocationDelegate();
    static void setInstance( AllocationDelegate*  instance );


private:
    friend class  ::Teamcenter::AllocationGenImpl;

};

#include <mechatronics/libmechatronics_undef.h>
#endif  //  TEAMCENTER__ALLOCATIONDELEGATE_HXX
