//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, BulkDataDelegate
    Filename:   BulkDataDelegate.hxx
    Module:     metaframework
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__BULKDATADELEGATE_HXX
#define TEAMCENTER__BULKDATADELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <metaframework/BulkData.hxx>

#include <metaframework/libmetaframework_exports.h>

namespace Teamcenter
{
    class BulkDataDelegate;
}
namespace Teamcenter
{
    class BulkDataImpl;
}
namespace Teamcenter
{
    class BulkData;
}
namespace Teamcenter
{
    class BulkDataGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  METAFRAMEWORK_API Teamcenter_alias::BulkDataDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the BulkDataDelegate instance
    static BulkDataDelegate&  getInstance();

    //  Method to create the BulkDataImpl pointer
    static BulkDataImpl*  createImpl( BulkData&  ifObj );

    //  Method to delete the BulkDataImpl pointer
    static void deleteImpl( BulkDataImpl*  impl );


    ///
    /// This operation bulk up objects to delete them in bulk. It should be used only in pre action and base action implementation of the set-based operations. Bulk operation framework will delete the bulked up objects after base action completion. It should not be used in the post action implementation of set based operations. To delete objects in the post action, delete operation needs to be invoked explicitly.
    /// @version Teamcenter 11.2.2
    /// @param deleteObjects - Bulk up objects for delete in set-based operations pre action and base action implementation.
    /// @return - ITK_ok always.
    ///
    int  fnd0AddDeleteObjectsBase(const BulkData &ifObj,  std::vector< tag_t > *deleteObjects );


    ///
    /// This operation bulk up objects to save them in bulk. It should be used only in pre action and base action implementation of the set-based operations. Bulk operation framework will save the bulked up objects after base action completion. It should not be used in the post action implementation of set based operations. To save objects in the post action, fnd0Save operation needs to be invoked explicitly.
    /// @version Teamcenter 11.2.2
    /// @param saveObjects - Bulk up objects for save in set-based operations pre action and base action implementation.
    /// @return - ITK_ok always.
    ///
    int  fnd0AddSaveObjectsBase(const BulkData &ifObj,  std::vector< tag_t > *saveObjects );


    ///
    /// This operation bulk up objects to unlock them in bulk. It should be used only in pre action and base action implementation of the set-based operations. Bulk operation framework will unlock the bulked up objects after base action completion. It should not be used in the post action implementation of set based operations. To unlock objects in the post action, fnd0Unlock operation needs to be invoked explicitly.
    /// @version Teamcenter 11.2.2
    /// @param unlockObjects - Bulk up objects for unlock in set-based operations pre action and base action implementation.
    /// @return - ITK_ok always.
    ///
    int  fnd0AddUnlockObjectsBase(const BulkData &ifObj,  std::vector< tag_t > *unlockObjects );



protected:
    //  Pointer to the instance
    static BulkDataDelegate*  m_pInstance;

    BulkDataDelegate();
    virtual ~BulkDataDelegate();
    static void setInstance( BulkDataDelegate*  instance );


private:
    friend class  ::Teamcenter::BulkDataGenImpl;

};

#include <metaframework/libmetaframework_undef.h>
#endif  //  TEAMCENTER__BULKDATADELEGATE_HXX
