//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, BusinessObject
    Filename:   BusinessObject.hxx
    Module:     metaframework
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__BUSINESSOBJECT__HXX
#define TEAMCENTER__BUSINESSOBJECT__HXX

#include <string>
#include <metaframework/BulkInput.hxx>
#include <metaframework/BulkData.hxx>
#include <vector>
#include <unidefs.h>
#include <metaframework/DeepCopyData.hxx>
#include <metaframework/OperationInput.hxx>
#include <metaframework/CreateInput.hxx>
#include <metaframework/SaveAsInput.hxx>
#include <common/tc_deprecation_macros.h>
#include <metaframework/RootObject.hxx>

#include <metaframework/libmetaframework_exports.h>

namespace Teamcenter
{
    class BusinessObject;
}
namespace Teamcenter
{
    class BusinessObjectImpl;
}
namespace Teamcenter
{
    class BusinessObjectDelegate;
}
namespace Teamcenter
{
    class BusinessObjectDispatch;
}
namespace Teamcenter
{
    class BusinessObjectGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  METAFRAMEWORK_API  Teamcenter::BusinessObject
     : public  ::Teamcenter::RootObject
{
public:

    using ::Teamcenter::RootObject::getTag;
    using ::Teamcenter::RootObject::setTag;

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// Getter for a string Property
    /// @version Teamcenter 10
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getObject_string( std::string &value, bool &isNull ) const;

    ///
    /// This is the getter for retrieving the recipe/permanent ID if its been created (and cached on the instance). Every Business Object should implement this operation.
    /// @version Teamcenter 11.1
    /// @param uid - Recipe/permanent ID
    /// @param isFirstTime - If Session Recovery Uid is yet to be set or does the object need to be serialized again?
    /// @return - Failure code
    ///
    int  fnd0AskSRUid( std::string *uid, bool *isFirstTime ) const;

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be created
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0Create( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0CreatePost( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be created
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0FinalizeCreateInput( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0FinalizeSaveAsInput( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// Generates permanent ID/recipe. Every Business Object should implement this operation.
    /// @version Teamcenter 11.1
    /// @param recipe - Permanent ID/recipe
    /// @return - Failure code.
    ///
    int  fnd0GenerateRecipe( std::string *recipe );

    ///
    /// This operation returns the children to be displayed when expanding this object.
    /// @version Teamcenter 10
    /// @param propertyNames - The list of propertyNames to expand.  If empty, then the properties defined in <TYPE>_DefaultChildProperties and <TYPE>_DefaultPseudoFolder are returned.
    /// @param childTags - Tags of children.
    /// @param childContextPropertyNames - The propertyName in which this child exists in the parent.
    /// @return - status
    ///
    int  fnd0GetChildren( const std::vector< std::string > *propertyNames, std::vector< tag_t > *childTags, std::vector< std::string > *childContextPropertyNames );

    ///
    /// 
    /// @version Teamcenter 11.4
    /// @param getDeepCopydata - This is the object to hold input information.
    /// @param bd - This is the bulkData
    /// @return - 
    ///
    static int  fnd0GetDeepCopyData( std::vector<  ::Teamcenter::BulkInput* > *getDeepCopydata, ::Teamcenter::BulkData *bd );

    ///
    /// Gets the current POM serialization state. Runtime Business Object does not need to implement this operation. 
    /// @version Teamcenter 11.1
    /// @param currentState - Gets the current POM serialization state.
    /// @return - Failure code
    ///
    int  fnd0GetSerializationState( bool *currentState ) const;

    ///
    /// If Business Object supports recoverable ID. Every Business Object should implement this operation.
    /// @version Teamcenter 11.1
    /// @param isPersistedRecipe - isPersistedRecipe param should be set to true if the recipe is limited to the user session and should be serialized to the database
    /// @param isRecoverableIDSupported - Returning true indicates support for recoverability/permanent IDs
    /// @return - Failure code.
    ///
    int  fnd0IsRecoverable( bool *isPersistedRecipe, bool *isRecoverableIDSupported ) const;

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0PerformDeepCopy( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0SaveAs( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0SaveAsPost( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be created
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0SetPropertiesFromCreateInput( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0SetPropertiesFromSaveAsInput( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// Sets the current POM serialization state. Runtime Business Object does not need to implement this operation. 
    /// @version Teamcenter 11.1
    /// @param newState - true marks the POM serialization recipe as out-of-date, false marks it as up-to-date.
    /// @param stateChanged - true if the state has changed.
    /// @return - Failure code
    ///
    int  fnd0SetSerializationState( bool newState, bool *stateChanged );

    ///
    /// This is the setter for the recipe/permanent ID when it is created (to be cached on the instance). Every Business Object should implement this operation.
    /// @version Teamcenter 11.1
    /// @param uid - Rrecipe/permanent ID
    /// @return - Failure code.
    ///
    int  fnd0SetSRUid( const std::string *uid );

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be created
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0ValidateCreateInput( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    static int  fnd0ValidateSaveAsInput( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );

    ///
    /// To Return the Character
    /// @version Tc 8
    /// @param charName - To return the character Name
    /// @param charRetValue - The value of the Character
    /// @param isNull - Is the Value Null
    /// @return - Returns the status as Integer
    ///
    int  getChar( const std::string &charName, char &charRetValue, bool &isNull );

    ///
    /// The array of Character
    /// @version Tc 8
    /// @param charArrayName - The Char array Name
    /// @param vectorCharVals - vector of char values
    /// @param vectorIsNullVals - Is the Values Null
    /// @return - Returns the Status as Integer
    ///
    int  getCharArray( const std::string &charArrayName, std::vector< char > &vectorCharVals, std::vector< int > &vectorIsNullVals );

    ///
    /// get date value
    /// @version Tc 8
    /// @param dateName - Name of the date property
    /// @param dateRetValue - Value of the date property
    /// @param isNull - is value Null
    /// @return - status
    ///
    int  getDate( const std::string &dateName, date_t &dateRetValue, bool &isNull );

    ///
    /// get array of Date Values for a property
    /// @version Tc 8
    /// @param dateArrayName - Name of the date array property
    /// @param dateArrayRetValue - Value of the date array
    /// @param isNull - is null values
    /// @return - status
    ///
    int  getDateArray( const std::string &dateArrayName, std::vector< date_t > &dateArrayRetValue, std::vector< int > &isNull );

    ///
    /// gets deep copy data
    /// @version Teamcenter 9
    /// @param operation - operation desc
    /// @param deepCopyDatas - desc
    /// @return - returns an int
    ///
    int  getDeepCopyData( const std::string *operation, std::vector<  ::Teamcenter::DeepCopyData* > *deepCopyDatas );

    ///
    /// To get the double value
    /// @version Tc 8
    /// @param doubleName - The name of the double variable
    /// @param doubleRetValue - The value of the double variable
    /// @param isNull - Is the value Null
    /// @return - Returns the status as Integer
    ///
    int  getDouble( const std::string &doubleName, double &doubleRetValue, bool &isNull );

    ///
    /// Array of Doubles
    /// @version Tc 8
    /// @param doubleArrayName - The Array Name
    /// @param vectorDoubleVals - Array of Doubles
    /// @param vectorIsNullVals - Is the Value Null
    /// @return - Return the status as Integer
    ///
    int  getDoubleArray( const std::string &doubleArrayName, std::vector< double > &vectorDoubleVals, std::vector< int > &vectorIsNullVals );

    ///
    /// To get the Integer
    /// @version Tc 8
    /// @param intName - The name of the Integer
    /// @param intRetValue - The value of the Integer
    /// @param isNull - Is the value null
    /// @return - Returns the status as Integer
    ///
    int  getInt( const std::string &intName, int &intRetValue, bool &isNull );

    ///
    /// Array of Integers
    /// @version Tc 8
    /// @param intArrayName - The array name of integers
    /// @param vectorIntVals - The Vector of Integer values
    /// @param vectorIsNullVals - are the Values Null
    /// @return - Returns the status as Integers
    ///
    int  getIntArray( const std::string &intArrayName, std::vector< int > &vectorIntVals, std::vector< int > &vectorIsNullVals );

    ///
    /// To get the Logical Value
    /// @version Tc 8
    /// @param logicalName - The name of the Logical Variable
    /// @param boolRetValue - The logical value
    /// @param isNull - Is the value null
    /// @return - Returns the status as Integer
    ///
    int  getLogical( const std::string &logicalName, bool &boolRetValue, bool &isNull );

    ///
    /// Array of Logical Values
    /// @version Tc 8
    /// @param logicalArrayName - Array of Logical Names
    /// @param vectorLogicalVals - Vector of Logical Values
    /// @param vectorIsNullVals - are the Value Null
    /// @return - Returns the status as Integer
    ///
    int  getLogicalArray( const std::string &logicalArrayName, std::vector< int > &vectorLogicalVals, std::vector< int > &vectorIsNullVals );

    ///
    /// Returns the String
    /// @version Tc 8
    /// @param stringName - The name of the String
    /// @param stringRetValue - The value of the string
    /// @param isNull - Is the String Null
    /// @return - Returns the status as Integer
    ///
    int  getString( const std::string &stringName, std::string &stringRetValue, bool &isNull );

    ///
    /// To get the StringArray
    /// @version Tc 8
    /// @param stringArrayName - The String name
    /// @param vectorStringVals - Vector of Strings
    /// @param vectorIsNullVals - vector of booleans
    /// @return - Returns the status as Integer
    ///
    int  getStringArray( const std::string &stringArrayName, std::vector< std::string > &vectorStringVals, std::vector< int > &vectorIsNullVals );

    ///
    /// Returns the Tag
    /// @version Tc 8
    /// @param tagName - The name of the Tag
    /// @param tagRetValue - The value of the Tag
    /// @param isNull - Is the Value Null
    /// @return - Returns the status as Integer
    ///
    int  getTag( const std::string &tagName, tag_t &tagRetValue, bool &isNull );

    ///
    /// Array of Tags
    /// @version Tc 8
    /// @param tagArrayName - Nameof the Tag Array
    /// @param vectorTagVals - Vector of Tags
    /// @param vectorIsNullVals - are the Value Null
    /// @return - Returns the status as Integer
    ///
    int  getTagArray( const std::string &tagArrayName, std::vector< tag_t > &vectorTagVals, std::vector< int > &vectorIsNullVals );

    ///
    /// perform deep copy
    /// @version Teamcenter 9
    /// @param pOperationInput - desc
    /// @param vecDeepCopyData - deep copy data
    /// @return - returns an int
    ///
    int  performDeepCopy( ::Teamcenter::OperationInput *pOperationInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );

    ///
    /// To set the character
    /// @version Tc 8
    /// @param charName - The Name
    /// @param charValue - The Character Value
    /// @param isNull - Is the Value Null
    /// @return - Returns an Integer
    ///
    int  setChar( const std::string &charName, const char &charValue, bool isNull );

    ///
    /// To set the character array
    /// @version Tc 8
    /// @param charArrayName - charArrayName
    /// @param vectorCharVals - vectorCharVals
    /// @param vectorIsNullVals - vectorIsNullVals
    /// @return - Returns an Integer
    ///
    int  setCharArray( const std::string &charArrayName, const std::vector< char > &vectorCharVals, const std::vector< int > *vectorIsNullVals );

    ///
    /// To set the Date
    /// @version Tc 8
    /// @param dateName - dateName
    /// @param dateValue - dateValue
    /// @param isNull - isNull
    /// @return - Returns an Integer
    ///
    int  setDate( const std::string &dateName, const date_t &dateValue, bool isNull );

    ///
    /// To set the Date Array
    /// @version Tc 8
    /// @param dateArrayName - dateArrayName
    /// @param vectorDateVals - vectorDateVals
    /// @param vectorIsNullVals - vectorIsNullVals
    /// @return - Returns an Integer
    ///
    int  setDateArray( const std::string &dateArrayName, const std::vector< date_t > &vectorDateVals, const std::vector< int > *vectorIsNullVals );

    ///
    /// To set the Double Value
    /// @version Tc 8
    /// @param doubleName - doubleName
    /// @param doubleValue - doubleValue
    /// @param isNull - isNull
    /// @return - Returns an Integer
    ///
    int  setDouble( const std::string &doubleName, const double &doubleValue, bool isNull );

    ///
    /// To set the double array
    /// @version Tc 8
    /// @param doubleArrayName - doubleArrayName
    /// @param vectorDoubleVals - vectorDoubleVals
    /// @param vectorIsNullVals - vectorIsNullVals
    /// @return - Returns an Integer
    ///
    int  setDoubleArray( const std::string &doubleArrayName, const std::vector< double > &vectorDoubleVals, const std::vector< int > *vectorIsNullVals );

    ///
    /// To set an Integer
    /// @version Tc 8
    /// @param intName - The name of the integer
    /// @param intValue - The Integer Value
    /// @param isNull - Is the value Null
    /// @return - Returns status as Integer
    ///
    int  setInt( const std::string &intName, const int &intValue, bool isNull );

    ///
    /// To the the Array of Integer type data on BusinessObject
    /// @version Tc 8
    /// @param intArrayName - name of the integer array
    /// @param vectorIntVals - vector or array of integer values
    /// @param vectorIsNullVals - vector of isNulls
    /// @return - success or failure
    ///
    int  setIntArray( const std::string &intArrayName, const std::vector< int > &vectorIntVals, const std::vector< int > *vectorIsNullVals );

    ///
    /// To set the Logical Value
    /// @version Tc 8
    /// @param logicalName - logicalName
    /// @param logicalValue - logicalValue
    /// @param isNull - isNull
    /// @return - Returns an Integer
    ///
    int  setLogical( const std::string &logicalName, const bool logicalValue, bool isNull );

    ///
    /// To set Logical Array
    /// @version Tc 8
    /// @param boolArrayName - boolArrayName
    /// @param vectorboolVals - vectorboolVals
    /// @param vectorIsNullVals - vectorIsNullVals
    /// @return - Returns an Integer
    ///
    int  setLogicalArray( const std::string &boolArrayName, const std::vector< int > &vectorboolVals, const std::vector< int > *vectorIsNullVals );

    ///
    /// To set the String
    /// @version Tc 8
    /// @param stringName - stringName
    /// @param stringValue - stringValue
    /// @param isNull - isNull
    /// @return - Returns an Integer
    ///
    int  setString( const std::string &stringName, const std::string &stringValue, bool isNull );

    ///
    /// To set the string array
    /// @version Tc 8
    /// @param stringArrayName - stringArrayName
    /// @param vectorStringVals - vectorStringVals
    /// @param vectorIsNullVals - vectorIsNullVals
    /// @return - Returns an integer
    ///
    int  setStringArray( const std::string &stringArrayName, const std::vector< std::string > &vectorStringVals, const std::vector< int > *vectorIsNullVals );

    ///
    /// To set the tag
    /// @version Tc 8
    /// @param tagName - tagName
    /// @param tagValue - tagValue
    /// @param isNull - isNull
    /// @return - Returns an Integer
    ///
    int  setTag( const std::string &tagName, const tag_t &tagValue, bool isNull );

    ///
    /// To set the Tag Array
    /// @version Tc 8
    /// @param tagArrayName - tagArrayName
    /// @param vectorTagVals - vectorTagVals
    /// @param vectorIsNullVals - vectorIsNullVals
    /// @return - Returns an Integer
    ///
    int  setTagArray( const std::string &tagArrayName, const std::vector< tag_t > &vectorTagVals, const std::vector< int > *vectorIsNullVals );

    ///
    /// desc for validate for create
    /// @version Tc 8
    /// @param creInput - desc for creInput parameter
    /// @return - ret desc for validate for create
    ///
    int  create( ::Teamcenter::CreateInput *creInput );

    ///
    /// desc for createPost
    /// @version Tc 8
    /// @param creInput - Description for the Create Input
    /// @return - return desc for createPost
    ///
    int  createPost( ::Teamcenter::CreateInput *creInput );

    ///
    /// Description for the Finalize Create Input
    /// @version Tc 8
    /// @param creInput - desc for  creInput parameter
    /// @return - Return desc for Initialize for Create
    ///
    int  finalizeCreateInput( ::Teamcenter::CreateInput *creInput );

    ///
    /// finalize operation input
    /// @version Teamcenter 9
    /// @param pSavAsInput - desc
    /// @param vecDeepCopyData - desc
    /// @return - returns an int
    ///
    int  finalizeSaveAsInput( ::Teamcenter::SaveAsInput *pSavAsInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );

    ///
    /// save as operation
    /// @version Teamcenter 9
    /// @param pSavAsInput - save as input
    /// @param vecDeepCopyData - vector deepcopy data
    /// @param newObjTag - new object tag
    /// @return - returns an int
    ///
    int  saveAs( ::Teamcenter::SaveAsInput *pSavAsInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData, tag_t *newObjTag );

    ///
    /// Generic saveAsPost operation.
    /// @version Teamcenter 8.1
    /// @param pSavAsInput - Input argument as SaveAsInput object.
    /// @param vecDeepCopyData - vector deepcopy data
    /// @return - Return integer value.
    ///
    int  saveAsPost( ::Teamcenter::SaveAsInput *pSavAsInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );

    ///
    /// desc for setPropertiesFromCreateInpu
    /// @version Tc 8
    /// @param creInput - Description for CreateInput
    /// @return - return desc for setPropertiesFromCreateInput
    ///
    int  setPropertiesFromCreateInput( ::Teamcenter::CreateInput *creInput );

    ///
    /// setproperties from saveas input
    /// @version Teamcenter 9
    /// @param pSavAsInput - desc
    /// @return - returns an int
    ///
    int  setPropertiesFromSaveAsInput( ::Teamcenter::SaveAsInput *pSavAsInput );

    ///
    /// desc for validate for create
    /// @version Tc 8
    /// @param creInput - desc for creInput parameter
    /// @return - ret desc for validate for create
    ///
    int  validateCreateInput( ::Teamcenter::CreateInput *creInput );

    ///
    /// validate saveas input
    /// @version Teamcenter 9
    /// @param pSavAsInput - desc
    /// @param vecDeepCopyData - desc
    /// @return - returns an int
    ///
    int  validateSaveAsInput( ::Teamcenter::SaveAsInput *pSavAsInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    BusinessObject();

    /**
     * Destructor
     */
    virtual ~BusinessObject();

private:
    //  Getter method for the Implementation Object
    BusinessObjectImpl*  getBusinessObjectImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setBusinessObjectImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    BusinessObjectImpl*  m_businessobjectImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param BusinessObject - desc for BusinessObject parameter
     */
    BusinessObject( const BusinessObject& );
    BusinessObject& operator=( const BusinessObject& );

    friend class  BusinessObjectDelegate;
    friend class  BusinessObjectDispatch;
    friend class  BusinessObjectGenImpl;
};

#include <metaframework/libmetaframework_undef.h>
#endif //   TEAMCENTER__BUSINESSOBJECT__HXX
