// ==================================================
// Copyright 2014.
// Siemens Product Lifecycle Management Software Inc.
// All Rights Reserved.
// ==================================================

/**
    @file

    This file contains the declaration for the abstract class BusinessObjectExtenderDispatch.
*/

/*  */

#ifndef TEAMCENTER_BUSINESSOBJECTEXTENDERDISPATCH_HXX
#define TEAMCENTER_BUSINESSOBJECTEXTENDERDISPATCH_HXX

#include <extensionframework/OperationDispatcher.hxx>
#include <metaframework/BusinessObjectExtender.hxx>
#include <metaframework/libmetaframework_exports.h>

/**
    @ingroup BO
    @{
*/

namespace Teamcenter
{
    class BusinessObjectExtenderDispatch;
    class BusinessObjectExtenderImpl;
}

/**
    @brief BusinessObjectExtenderDispatch

    This is the top class of the business object Extender dispatch class. All the virtual methods defined
    in BusinessObjectExtenderDispatch must be implemented in this class. Object is the parent class of the class
    to ensure all the instances of dreived dispatch classes (from auto-generation) are managed by
    Teamcenter memory utility (new/delete).

*/
class METAFRAMEWORK_API Teamcenter::BusinessObjectExtenderDispatch :
    virtual public Teamcenter::BusinessObjectExtender
{
public:

    /**
        Constructor for BusinessObjectExtenderDispatch
    */
    BusinessObjectExtenderDispatch();

    /**
        Destructor for BusinessObjectExtenderDispatch
    */
    virtual ~BusinessObjectExtenderDispatch() = 0;

    /**
        Initialize the Class
    */
    static int initializeClass();

    /**
        Initialization for object instantiation
    */
    virtual void initialize(RootObjectImpl * impl = 0);

private:
    /**
        Private copy constructor.
    */
    BusinessObjectExtenderDispatch( const BusinessObjectExtenderDispatch& );

    /**
    Private copy assignment operator.
    */
    BusinessObjectExtenderDispatch& operator=( const BusinessObjectExtenderDispatch& );

};

/** @} */

#include <metaframework/libmetaframework_undef.h>
#endif //TEAMCENTER_BUSINESSOBJECTEXTENDERDISPATCH_HXX
