//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, CreateInput
    Filename:   CreateInput.hxx
    Module:     metaframework
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__CREATEINPUT__HXX
#define TEAMCENTER__CREATEINPUT__HXX

#include <string>
#include <vector>
#include <unidefs.h>
#include <common/tc_deprecation_macros.h>
#include <metaframework/OperationInput.hxx>

#include <metaframework/libmetaframework_exports.h>

namespace Teamcenter
{
    class CreateInput;
}
namespace Teamcenter
{
    class CreateInputImpl;
}
namespace Teamcenter
{
    class CreateInputDelegate;
}
namespace Teamcenter
{
    class CreateInputDispatch;
}
namespace Teamcenter
{
    class CreateInputGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  METAFRAMEWORK_API  Teamcenter::CreateInput
     : public  ::Teamcenter::OperationInput
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// gets the compound object tags
    /// @version Teamcenter 10
    /// @param compoundObjectName - compound object's name
    /// @param compoundObjectTags - compound object tags
    /// @return - exit status
    ///
    int  getCompoundObjectArrayTags( std::string &compoundObjectName, std::vector< tag_t > &compoundObjectTags );

    ///
    /// The method getCompoundObjectTag is used retrieve the tag of any newly-created object listed as a Compound property on the CreateInput Descriptor. Please note: the "revision" property of Item is treated as a compound property by the system despite the Compound column not appearing checked in BMIDE.
    /// @version Tc 8
    /// @param compoundObjectName - compound object's name
    /// @param compoundObjectTag - compound objects tag
    /// @return - exit status
    ///
    int  getCompoundObjectTag( std::string &compoundObjectName, tag_t &compoundObjectTag );

    ///
    /// The method getCompoundObjectTags is used to retrieve all the child objects tags created during the creation of the main object. For example, this function will return tags of ItemRevision, Item Master Form, ItemRevision Master Form for the newly-created Item.
    /// @version Tc 8
    /// @param compoundObjectTags - vector of compound object tag_ts
    /// @return - exit status
    ///
    int  getCompoundObjectTags( std::vector< tag_t > &compoundObjectTags );

    ///
    /// sets the compound object tags on the map with CreateInput
    /// @version Teamcenter 10
    /// @param compoundObjectName - Name of the compound object
    /// @param compoundObjectTags - compound object tags
    /// @return - exit status
    ///
    int  setCompoundObjectArrayTags( std::string &compoundObjectName, std::vector< tag_t > &compoundObjectTags );

    ///
    /// sets the compound object tag on the map with CreateInput
    /// @version Tc 8
    /// @param compoundObjectName - Name of the compound object
    /// @param compoundObjectTag - compound object's tag
    /// @return - exit status
    ///
    int  setCompoundObjectTag( std::string &compoundObjectName, tag_t compoundObjectTag );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    CreateInput();

    /**
     * Destructor
     */
    virtual ~CreateInput();

private:
    //  Getter method for the Implementation Object
    CreateInputImpl*  getCreateInputImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setCreateInputImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    CreateInputImpl*  m_createinputImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param CreateInput - desc for CreateInput parameter
     */
    CreateInput( const CreateInput& );
    CreateInput& operator=( const CreateInput& );

    friend class  CreateInputDelegate;
    friend class  CreateInputDispatch;
    friend class  CreateInputGenImpl;
};

#include <metaframework/libmetaframework_undef.h>
#endif //   TEAMCENTER__CREATEINPUT__HXX
