//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, VariantRuleDelegate
    Filename:   VariantRuleDelegate.hxx
    Module:     ps
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__VARIANTRULEDELEGATE_HXX
#define TEAMCENTER__VARIANTRULEDELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <ps/VariantRule.hxx>

#include <ps/libps_exports.h>

namespace Teamcenter
{
    class VariantRuleDelegate;
}
namespace Teamcenter
{
    class VariantRuleImpl;
}
namespace Teamcenter
{
    class VariantRule;
}
namespace Teamcenter
{
    class VariantRuleGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  PS_API Teamcenter_alias::VariantRuleDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the VariantRuleDelegate instance
    static VariantRuleDelegate&  getInstance();

    //  Method to create the VariantRuleImpl pointer
    static VariantRuleImpl*  createImpl( VariantRule&  ifObj );

    //  Method to delete the VariantRuleImpl pointer
    static void deleteImpl( VariantRuleImpl*  impl );


    ///
    /// This is the getter for retrieving the recipe/permanent ID if its been created (and cached on the instance). Every Business Object should implement this operation.
    /// @version Teamcenter 11.1
    /// @param uid - Recipe/permanent ID
    /// @param isFirstTime - If Session Recovery Uid is yet to be set or does the object need to be serialized again?
    /// @return - Failure code
    ///
    int  fnd0AskSRUidBase(const VariantRule &ifObj,  std::string *uid, bool *isFirstTime ) const;


    ///
    /// Generates permanent ID/recipe. Every Business Object should implement this operation.
    /// @version Teamcenter 11.1
    /// @param recipe - Permanent ID/recipe
    /// @return - Failure code.
    ///
    int  fnd0GenerateRecipeBase(const VariantRule &ifObj,  std::string *recipe );


    ///
    /// Gets the current POM serialization state. Runtime Business Object does not need to implement this operation. 
    /// @version Teamcenter 11.1
    /// @param currentState - Gets the current POM serialization state.
    /// @return - Failure code
    ///
    int  fnd0GetSerializationStateBase(const VariantRule &ifObj,  bool *currentState ) const;


    ///
    /// If Business Object supports recoverable ID. Every Business Object should implement this operation.
    /// @version Teamcenter 11.1
    /// @param isPersistedRecipe - isPersistedRecipe param should be set to true if the recipe is limited to the user session and should be serialized to the database
    /// @param isRecoverableIDSupported - Returning true indicates support for recoverability/permanent IDs
    /// @return - Failure code.
    ///
    int  fnd0IsRecoverableBase(const VariantRule &ifObj,  bool *isPersistedRecipe, bool *isRecoverableIDSupported ) const;


    ///
    /// Sets the current POM serialization state. Runtime Business Object does not need to implement this operation. 
    /// @version Teamcenter 11.1
    /// @param newState - true marks the POM serialization recipe as out-of-date, false marks it as up-to-date.
    /// @param stateChanged - true if the state has changed.
    /// @return - Failure code
    ///
    int  fnd0SetSerializationStateBase(const VariantRule &ifObj,  bool newState, bool *stateChanged );


    ///
    /// This is the setter for the recipe/permanent ID when it is created (to be cached on the instance). Every Business Object should implement this operation.
    /// @version Teamcenter 11.1
    /// @param uid - Rrecipe/permanent ID
    /// @return - Failure code.
    ///
    int  fnd0SetSRUidBase(const VariantRule &ifObj,  const std::string *uid );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @param isLockForDelete - A boolean to indicate if object(s) are to be locked for deletion
    /// @param allowRelock - A boolean to indicate if object(s) can be relocked, which will discard all unsaved changes, if already locked by the same user
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0LockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd, const bool isLockForDelete, const bool allowRelock );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0RefreshBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0SaveBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0UnlockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// desc for setPropertiesFromCreateInpu
    /// @version Tc 8
    /// @param creInput - Description for CreateInput
    /// @return - return desc for setPropertiesFromCreateInput
    ///
    int  setPropertiesFromCreateInputBase(const VariantRule &ifObj,  ::Teamcenter::CreateInput *creInput );



protected:
    //  Pointer to the instance
    static VariantRuleDelegate*  m_pInstance;

    VariantRuleDelegate();
    virtual ~VariantRuleDelegate();
    static void setInstance( VariantRuleDelegate*  instance );


private:
    friend class  ::Teamcenter::VariantRuleGenImpl;

};

#include <ps/libps_undef.h>
#endif  //  TEAMCENTER__VARIANTRULEDELEGATE_HXX
