//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, FolderDelegate
    Filename:   FolderDelegate.hxx
    Module:     tc
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__FOLDERDELEGATE_HXX
#define TEAMCENTER__FOLDERDELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <tc/Folder.hxx>

#include <tc/libtc_exports.h>

namespace Teamcenter
{
    class FolderDelegate;
}
namespace Teamcenter
{
    class FolderImpl;
}
namespace Teamcenter
{
    class Folder;
}
namespace Teamcenter
{
    class FolderGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  TC_API Teamcenter_alias::FolderDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the FolderDelegate instance
    static FolderDelegate&  getInstance();

    //  Method to create the FolderImpl pointer
    static FolderImpl*  createImpl( Folder&  ifObj );

    //  Method to delete the FolderImpl pointer
    static void deleteImpl( FolderImpl*  impl );


    ///
    /// Getter for a Tag Array Property
    /// @version Teamcenter 10.1
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getContentsBase(const Folder &ifObj,  std::vector< tag_t > &values, std::vector< int > &isNull ) const;


    ///
    /// This operation deletes inputs objects in bulk. It either deletes none of the input objects or deletes all the input objects. It doesn't support partial deletion.
    /// @version Teamcenter 11.6
    /// @param inputs - A vector of data that contains reference to the object to be deleted.
    /// @param bd - A data structure to store objects and other information relevant for set-based operation.
    /// @return - Returns ITK_ok on Success. Otherwise, returns the specific error code.
    ///
    int  fnd0BulkDeleteBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @param isLockForDelete - A boolean to indicate if object(s) are to be locked for deletion
    /// @param allowRelock - A boolean to indicate if object(s) can be relocked, which will discard all unsaved changes, if already locked by the same user
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0LockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd, const bool isLockForDelete, const bool allowRelock );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0RefreshBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0SaveBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0UnlockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// Description for the Finalize Create Input
    /// @version Tc 8
    /// @param creInput - desc for  creInput parameter
    /// @return - Return desc for Initialize for Create
    ///
    int  finalizeCreateInputBase(const Folder &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// desc for setPropertiesFromCreateInpu
    /// @version Tc 8
    /// @param creInput - Description for CreateInput
    /// @return - return desc for setPropertiesFromCreateInput
    ///
    int  setPropertiesFromCreateInputBase(const Folder &ifObj,  ::Teamcenter::CreateInput *creInput );



protected:
    //  Pointer to the instance
    static FolderDelegate*  m_pInstance;

    FolderDelegate();
    virtual ~FolderDelegate();
    static void setInstance( FolderDelegate*  instance );


private:
    friend class  ::Teamcenter::FolderGenImpl;

};

#include <tc/libtc_undef.h>
#endif  //  TEAMCENTER__FOLDERDELEGATE_HXX
