//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, POM_application_object
    Filename:   POM_application_object.hxx
    Module:     tccore
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__POM_APPLICATION_OBJECT__HXX
#define TEAMCENTER__POM_APPLICATION_OBJECT__HXX

#include <string>
#include <vector>
#include <unidefs.h>
#include <common/tc_deprecation_macros.h>
#include <tccore/POM_object.hxx>

#include <tccore/libtccore_exports.h>

namespace Teamcenter
{
    class POM_application_object;
}
namespace Teamcenter
{
    class POM_application_objectImpl;
}
namespace Teamcenter
{
    class POM_application_objectDelegate;
}
namespace Teamcenter
{
    class POM_application_objectDispatch;
}
namespace Teamcenter
{
    class POM_application_objectGenImpl;
}
namespace Teamcenter
{
    class RootObjectImpl;
}

class  TCCORE_API  Teamcenter::POM_application_object
     : public  ::Teamcenter::POM_object
{
public:

    /**
     * Get the Interface Name
     * @return - return desc for getInterfaceName
     */
    static const std::string&  getInterfaceName();


    ///
    /// Getter for a Tag Array Property
    /// @version Teamcenter 10.1.1
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0DigitalSignAuditLogs( std::vector< tag_t > &values, std::vector< int > &isNull ) const;

    ///
    /// Getter for an Integer Property
    /// @version Teamcenter 10.1.1
    /// @param value - Parameter Value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0DSState( int &value, bool &isNull ) const;

    ///
    /// Operation to apply Digital Signature
    /// @version Teamcenter 10.1.1
    /// @param encryptedString - encryptedString
    /// @return - returns an int value
    ///
    int  fnd0ApplySignature( const std::string *encryptedString );

    ///
    /// OwningGroup
    /// @version Teamcenter 9
    /// @param groupName - groupName
    /// @param output - output
    /// @return - int
    ///
    int  fnd0isOwningGroup( const std::string &groupName, bool *output );

    ///
    /// OwningUser
    /// @version Teamcenter 9
    /// @param userName - OwningUser
    /// @param output - output
    /// @return - int
    ///
    int  fnd0isOwningUser( const std::string &userName, bool *output );

    ///
    /// Operation for voiding Digital Signatures
    /// @version Teamcenter 10.1.1
    /// @param dsObjsToVoid - List of digital signature objects to be voided
    /// @param comments - Void Comments
    /// @return - returns int
    ///
    int  fnd0VoidSignature( const std::vector< tag_t > *dsObjsToVoid, const std::string *comments );
protected:
    //  Method to initialize
    virtual void initialize( ::Teamcenter::RootObjectImpl*  impl );

    /**
     * Constructor
     */
    POM_application_object();

    /**
     * Destructor
     */
    virtual ~POM_application_object();

private:
    //  Getter method for the Implementation Object
    POM_application_objectImpl*  getPOM_application_objectImpl() const;
    //  Setter method for the Implementation Object
    ::Teamcenter::RootObjectImpl*  setPOM_application_objectImpl( ::Teamcenter::RootObjectImpl*  impl );

    //  Method to set the delete impl boolean
    void setDeleteImpl( bool  del );

    // Pointer to the Implementation object
    POM_application_objectImpl*  m_pom_application_objectImpl;

    //  Flag to indicate if Implementation object needs to be deleted
    bool  m_deleteImpl;

    /**
     * Name of the Business Object
     */
    static std::string  name;

    /**
     * Private default constructor. We do not want this class instantiated without the business object passed in.
     * @param POM_application_object - desc for POM_application_object parameter
     */
    POM_application_object( const POM_application_object& );
    POM_application_object& operator=( const POM_application_object& );

    friend class  POM_application_objectDelegate;
    friend class  POM_application_objectDispatch;
    friend class  POM_application_objectGenImpl;
};

#include <tccore/libtccore_undef.h>
#endif //   TEAMCENTER__POM_APPLICATION_OBJECT__HXX
