//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, POM_objectDelegate
    Filename:   POM_objectDelegate.hxx
    Module:     tccore
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__POM_OBJECTDELEGATE_HXX
#define TEAMCENTER__POM_OBJECTDELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <tccore/POM_object.hxx>

#include <tccore/libtccore_exports.h>

namespace Teamcenter
{
    class POM_objectDelegate;
}
namespace Teamcenter
{
    class POM_objectImpl;
}
namespace Teamcenter
{
    class POM_object;
}
namespace Teamcenter
{
    class POM_objectGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  TCCORE_API Teamcenter_alias::POM_objectDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the POM_objectDelegate instance
    static POM_objectDelegate&  getInstance();

    //  Method to create the POM_objectImpl pointer
    static POM_objectImpl*  createImpl( POM_object&  ifObj );

    //  Method to delete the POM_objectImpl pointer
    static void deleteImpl( POM_objectImpl*  impl );


    ///
    /// Getter for the multifield key string Property
    /// @version Teamcenter 10.1
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0mfkinfoBase(const POM_object &ifObj,  std::string &value, bool &isNull ) const;


    ///
    /// Getter for a string Property
    /// @version Teamcenter 8.3
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getFnd0objectIdBase(const POM_object &ifObj,  std::string &value, bool &isNull ) const;


    ///
    /// This operation deletes inputs objects in bulk. It either deletes none of the input objects or deletes all the input objects. It doesn't support partial deletion.
    /// @version Teamcenter 11.6
    /// @param inputs - A vector of data that contains reference to the object to be deleted.
    /// @param bd - A data structure to store objects and other information relevant for set-based operation.
    /// @return - Returns ITK_ok on Success. Otherwise, returns the specific error code.
    ///
    int  fnd0BulkDeleteBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation verifies whether a particular property (propertyName) value of a secondary object referenced by the BO (Master form, dataset, ICO and so on) matches the propertyValue depending on the comparator. The secondary object type is objectType and it is referenced by the BO using relationtype. All secondary objects that match the relationtype and objecttype criteria will be checked. If one of them fail the operation will return fail.
    /// @version Teamcenter 8.2
    /// @param relationType - The name of the relation of the secondary objects.
    /// @param objectType - The type of the secondary objects.
    /// @param propertyName - The name of the property to match.
    /// @param propertyValue - The value of the property, in string format, to match.
    /// @param matchall - Whether to do the comparison for all the secondary objects.
    /// @param op - A value signifying the comparator operation.
    /// @param result - Whether a match is found.
    /// @return - Zero (0) if everything is alright otherwise the error code.
    ///
    int  fnd0chkObjPropBase(const POM_object &ifObj,  const std::string &relationType, const std::string &objectType, const std::string &propertyName, const std::string &propertyValue, const bool &matchall, const std::string &op, bool *result );


    ///
    /// Operation to create/setting values for shadow object
    /// @version Teamcenter 11.1
    /// @param pCreInput - create input
    /// @return - returns status as int
    ///
    int  fnd0CreateShadowObjectBase(const POM_object &ifObj,  ::Teamcenter::CreateInput *pCreInput );


    ///
    /// Deletes the instance.
    /// @version Teamcenter 11.1
    /// @return - Failure code.
    ///
    int  fnd0DeleteBase(const POM_object &ifObj  );


    ///
    /// to differentiate between real and shadow object
    /// @version Teamcenter 11.1
    /// @param isEdit - boolean
    /// @return - returns status as int
    ///
    int  fnd0IsShadowObjectForEditBase(const POM_object &ifObj,  bool *isEdit );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @param isLockForDelete - A boolean to indicate if object(s) are to be locked for deletion
    /// @param allowRelock - A boolean to indicate if object(s) can be relocked, which will discard all unsaved changes, if already locked by the same user
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0LockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd, const bool isLockForDelete, const bool allowRelock );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0RefreshBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0SaveBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// operation for creating/setting values to shadow object during saveas
    /// @version Teamcenter 11.1
    /// @param pSvAsInput - save as input
    /// @param newShObjTag - new shadow object
    /// @return - returns status as int
    ///
    int  fnd0SaveAsShadowObjectBase(const POM_object &ifObj,  ::Teamcenter::SaveAsInput *pSvAsInput, tag_t *newShObjTag );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0UnlockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// Operation is to provide basic pre release validations to the objects which are going to be released through <b>CM_validate_and_promote </b>workflow handler.
    /// @version Teamcenter 11.2.3
    /// @param inputObjects - A vector of data that contains reference to the objects to be validated for release.
    /// @param bulkData - A data structure to store objects and other information relevant for set-based operation.
    /// @param isDryRun - A boolean flag to check whether the input operation is  dry run operation or not.
    /// @param validationResults - A data structure to store the validation results for the input objects.
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0ValidateBOTypeForReleaseBase( std::vector<  ::Teamcenter::BulkInput* > *inputObjects, ::Teamcenter::BulkData *bulkData, const bool isDryRun, std::map< tag_t,std::vector< std::string > > *validationResults );


    ///
    /// Operation is to provide basic post validations to the objects which are promoted to public using <b>CM-promote-change-notice</b> workflow handler. This operation does not support logically deleted objects.
    /// @version Teamcenter 11.2.3
    /// @param inputObjects - A vector of data that contains reference information to the objects which are promoted.
    /// @param bulkData - A data structure to store objects and other information relevant for set-based operation.
    /// @param isDryRun - A boolean flag to check whether the input operation is  dry run operation or not.
    /// @param validationResults - A data structure to store the validation results for the input objects.
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0ValidateBOTypePostPromoteBase( std::vector<  ::Teamcenter::BulkInput* > *inputObjects, ::Teamcenter::BulkData *bulkData, const bool isDryRun, std::map< tag_t,std::vector< std::string > > *validationResults );


    ///
    /// Operation is to provide basic pre validations to the objects which are going to be promoted to public using the <b>CM-promote-change-notice</b> workflow handler. This operation does not support logically deleted objects.
    /// @version Teamcenter 11.2.3
    /// @param inputObjects - A vector of data that contains reference to the objects which are to be promoted to public.
    /// @param bulkData - A data structure to store objects and other information relevant for set-based operation.
    /// @param isDryRun - A boolean flag to check whether the input operation is  dry run operation or not.
    /// @param validationResults - A data structure to store the validation results for the input objects.
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0ValidateBOTypePrePromoteBase( std::vector<  ::Teamcenter::BulkInput* > *inputObjects, ::Teamcenter::BulkData *bulkData, const bool isDryRun, std::map< tag_t,std::vector< std::string > > *validationResults );


    ///
    /// This operation tests if the given object is local to the database or not.
    /// @version Tc 8
    /// @param result - Returns result as false if given object is local to the database, else returns result as true.
    /// @return - Return error code.
    ///
    int  isReplicaBase(const POM_object &ifObj,  bool *result );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be created
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0CreateBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0CreatePostBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be created
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0FinalizeCreateInputBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0FinalizeSaveAsInputBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0PerformDeepCopyBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0SaveAsBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0SaveAsPostBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be created
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0SetPropertiesFromCreateInputBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0SetPropertiesFromSaveAsInputBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.4
    /// @param inputs - A vector of data that contains reference information to the object to be created
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0ValidateCreateInputBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.3
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - 
    ///
    int  fnd0ValidateSaveAsInputBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// perform deep copy
    /// @version Teamcenter 9
    /// @param pOperationInput - desc
    /// @param vecDeepCopyData - deep copy data
    /// @return - returns an int
    ///
    int  performDeepCopyBase(const POM_object &ifObj,  ::Teamcenter::OperationInput *pOperationInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );


    ///
    /// desc for validate for create
    /// @version Tc 8
    /// @param creInput - desc for creInput parameter
    /// @return - ret desc for validate for create
    ///
    int  createBase(const POM_object &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// desc for createPost
    /// @version Tc 8
    /// @param creInput - Description for the Create Input
    /// @return - return desc for createPost
    ///
    int  createPostBase(const POM_object &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// Description for the Finalize Create Input
    /// @version Tc 8
    /// @param creInput - desc for  creInput parameter
    /// @return - Return desc for Initialize for Create
    ///
    int  finalizeCreateInputBase(const POM_object &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// finalize operation input
    /// @version Teamcenter 9
    /// @param pSavAsInput - desc
    /// @param vecDeepCopyData - desc
    /// @return - returns an int
    ///
    int  finalizeSaveAsInputBase(const POM_object &ifObj,  ::Teamcenter::SaveAsInput *pSavAsInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );


    ///
    /// save as operation
    /// @version Teamcenter 9
    /// @param pSavAsInput - save as input
    /// @param vecDeepCopyData - vector deepcopy data
    /// @param newObjTag - new object tag
    /// @return - returns an int
    ///
    int  saveAsBase(const POM_object &ifObj,  ::Teamcenter::SaveAsInput *pSavAsInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData, tag_t *newObjTag );


    ///
    /// Generic saveAsPost operation.
    /// @version Teamcenter 8.1
    /// @param pSavAsInput - Input argument as SaveAsInput object.
    /// @param vecDeepCopyData - vector deepcopy data
    /// @return - Return integer value.
    ///
    int  saveAsPostBase(const POM_object &ifObj,  ::Teamcenter::SaveAsInput *pSavAsInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );


    ///
    /// desc for setPropertiesFromCreateInpu
    /// @version Tc 8
    /// @param creInput - Description for CreateInput
    /// @return - return desc for setPropertiesFromCreateInput
    ///
    int  setPropertiesFromCreateInputBase(const POM_object &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// setproperties from saveas input
    /// @version Teamcenter 9
    /// @param pSavAsInput - desc
    /// @return - returns an int
    ///
    int  setPropertiesFromSaveAsInputBase(const POM_object &ifObj,  ::Teamcenter::SaveAsInput *pSavAsInput );


    ///
    /// desc for validate for create
    /// @version Tc 8
    /// @param creInput - desc for creInput parameter
    /// @return - ret desc for validate for create
    ///
    int  validateCreateInputBase(const POM_object &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// validate saveas input
    /// @version Teamcenter 9
    /// @param pSavAsInput - desc
    /// @param vecDeepCopyData - desc
    /// @return - returns an int
    ///
    int  validateSaveAsInputBase(const POM_object &ifObj,  ::Teamcenter::SaveAsInput *pSavAsInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );



protected:
    //  Pointer to the instance
    static POM_objectDelegate*  m_pInstance;

    POM_objectDelegate();
    virtual ~POM_objectDelegate();
    static void setInstance( POM_objectDelegate*  instance );


private:
    friend class  ::Teamcenter::POM_objectGenImpl;

};

#include <tccore/libtccore_undef.h>
#endif  //  TEAMCENTER__POM_OBJECTDELEGATE_HXX
