//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2010.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/**
    @file

    This file contains the interface to Teamcenter types.

*/


#ifndef TCTYPE_HXX
#define TCTYPE_HXX

#include <string>

#include <unidefs.h>

#include <extensionframework/OperationDispatcher.hxx>
#include <property/BulkPropertyContextData.hxx>

#include <tccore/libtccore_exports.h>

using namespace Teamcenter;

/**
   This function will return the Operation Dispatcher for a given property operation.
*/
extern TCCORE_API int TCTYPE_find_prop_operation_dispatcher (
       tag_t                 type_tag,
       const char*           prop_name,
       const char*           msg_name,
       int*                  opint,
       OperationDispatcher** op_dispatcher
       );

/**
   This function will return the Operation Dispatcher for a given operation.
*/
extern TCCORE_API int TCTYPE_find_operation_dispatcher (
       tag_t                 type_tag,
       const char*           msg_name,
       int*                  opint,
       OperationDispatcher** op_dispatcher
       );

/**
   Register #BulkOperation_bulk_loader_t function pointer for a given type and operation ID.

   @returns
   <ul>
   <li>#ITK_ok on success
   <li>Possibly other errors.
   </ul>
*/
extern TCCORE_API int TCTYPE_register_operation_bulk_fn(
       tag_t                 type_tag,                      /**< (I) Tag of object type to register */
       const char*           operation_id,                  /**< (I) Operation ID to register */
       BulkOperation_bulk_loader_t batch_func_ptr           /**< (I) Function pointer to register */
       );

/**
   Retrieve #BulkOperation_bulk_loader_t function pointer for a given type and operation ID.

   @returns
   <ul>
   <li>#ITK_ok on success
   <li>Possibly other errors.
   </ul>
*/
extern TCCORE_API int TCTYPE_find_operation_bulk_fn(
       tag_t                 type_tag,                      /**< (I) Tag of object type */
       const char*           operation_id,                  /**< (I) Operation ID */
       BulkOperation_bulk_loader_t* batch_func_ptr          /**< (O) Registered function pointer */
       );

#include <tccore/libtccore_undef.h>
#endif
