//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, NXAgentRevisionDelegate
    Filename:   NXAgentRevisionDelegate.hxx
    Module:     validation
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__NXAGENTREVISIONDELEGATE_HXX
#define TEAMCENTER__NXAGENTREVISIONDELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <validation/NXAgentRevision.hxx>

#include <validation/libvalidation_exports.h>

namespace Teamcenter
{
    class NXAgentRevisionDelegate;
}
namespace Teamcenter
{
    class NXAgentRevisionImpl;
}
namespace Teamcenter
{
    class NXAgentRevision;
}
namespace Teamcenter
{
    class NXAgentRevisionGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  VALIDATION_API Teamcenter_alias::NXAgentRevisionDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the NXAgentRevisionDelegate instance
    static NXAgentRevisionDelegate&  getInstance();

    //  Method to create the NXAgentRevisionImpl pointer
    static NXAgentRevisionImpl*  createImpl( NXAgentRevision&  ifObj );

    //  Method to delete the NXAgentRevisionImpl pointer
    static void deleteImpl( NXAgentRevisionImpl*  impl );


    ///
    /// Getter for a Tag Property
    /// @version Teamcenter 8.2
    /// @param value - Parameter value
    /// @param isNull - Returns true if the Parameter value is null
    /// @return - Status. 0 if successful
    ///
    int  getValidation_closure_ruleBase(const NXAgentRevision &ifObj,  tag_t &value, bool &isNull ) const;


    ///
    /// Setter for a Tag Property
    /// @version Teamcenter 8.2
    /// @param value - Value to be set for the parameter
    /// @param isNull - If true, set the parameter value to null
    /// @return - Status. 0 if successful
    ///
    int  setValidation_closure_ruleBase(NXAgentRevision &ifObj,  const tag_t &value, bool isNull );


    ///
    /// This operation will evaluate the compound result of given validation target objects and return the corresponding compound results via an output parameter.
    /// @version Teamcenter 8.2
    /// @param validationTargetObjects - A vector of validation target object tags whose compound result will be evaluated for this validation agent revision.
    /// @param compoundResult - The vector of corresponding compound results for the given vector of validation target objects.
    /// @return - The status code. ITK_ok indicates that the operation is successfully executed.
    ///
    int  evaluateCompoundResultBase(const NXAgentRevision &ifObj,  const std::vector< tag_t > &validationTargetObjects, std::vector< bool > &compoundResult );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @param isLockForDelete - A boolean to indicate if object(s) are to be locked for deletion
    /// @param allowRelock - A boolean to indicate if object(s) can be relocked, which will discard all unsaved changes, if already locked by the same user
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0LockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd, const bool isLockForDelete, const bool allowRelock );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0SaveBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference to the object to be refreshed
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0UnlockBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This ioperation will retun a vector of ValidationResult object tags via an ouput paramter.
    /// @version Teamcenter 8.2
    /// @param valDataRevisions - A vector of ValDataRevision objects that will be used to limit the scope of the ValidationResult  objects.
    /// @param selectedObjects - A vector of selected objects that the system will use to find the actual target objects. The resulting target objects will be used to find the associated ValidationResult objects.
    /// @param targetObjects - A vector objects that will be used to find the associated ValidationResult objects.
    /// @param validationResultObjects - A vector of ValidationResult tags that are found from the given inut criteria.
    /// @return - The status code. ITK_ok indicates that this operation is successfully executed.
    ///
    int  getValidationResultsBase(const NXAgentRevision &ifObj,  const std::vector< tag_t > &valDataRevisions, const std::vector< tag_t > &selectedObjects, const std::vector< tag_t > &targetObjects, std::vector< tag_t > &validationResultObjects );


    ///
    /// This operation will return a vector of validation target object tags via an output parameter.
    /// @version Teamcenter 8.2
    /// @param valDataRevisions - A vector of ValDataRevision objects that will be used to limit the scope of the targets.
    /// @param selectedObjects - A vector of selected objects that the system will use to find the actual target objects.
    /// @param targetObjects - A vector of target object tags that are found from the given input criteria.
    /// @return - The return status code. ITK_ok means thatthe operation is successfully executed.
    ///
    int  getValidationTargetsBase(const NXAgentRevision &ifObj,  const std::vector< tag_t > &valDataRevisions, const std::vector< tag_t > &selectedObjects, std::vector< tag_t > &targetObjects );


    ///
    /// This operation will perform the validation tasks. Each validation agent revision must implement this method to process the validation tasks.
    /// @version Teamcenter 8.2
    /// @param valDataRevisionObjects - A vector of ValDataRevision objects that will be used to validate against the validation targets
    /// @param selectedObjects - A vector of selected objects that this validation agent will use to find the actual validation targets for this validation run.
    /// @param targetObjects - A vector of validation targets for this validation run.
    /// @return - The status code returned from the run. TIK_ok indicates that the validation run is executed successfully.
    ///
    int  runValidationBase(const NXAgentRevision &ifObj,  const std::vector< tag_t > &valDataRevisionObjects, const std::vector< tag_t > &selectedObjects, const std::vector< tag_t > &targetObjects );


    ///
    /// desc for createPost
    /// @version Tc 8
    /// @param creInput - Description for the Create Input
    /// @return - return desc for createPost
    ///
    int  createPostBase(const NXAgentRevision &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// Description for the Finalize Create Input
    /// @version Tc 8
    /// @param creInput - desc for  creInput parameter
    /// @return - Return desc for Initialize for Create
    ///
    int  finalizeCreateInputBase(const NXAgentRevision &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// desc for setPropertiesFromCreateInpu
    /// @version Tc 8
    /// @param creInput - Description for CreateInput
    /// @return - return desc for setPropertiesFromCreateInput
    ///
    int  setPropertiesFromCreateInputBase(const NXAgentRevision &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// desc for validate for create
    /// @version Tc 8
    /// @param creInput - desc for creInput parameter
    /// @return - ret desc for validate for create
    ///
    int  validateCreateInputBase(const NXAgentRevision &ifObj,  ::Teamcenter::CreateInput *creInput );



protected:
    //  Pointer to the instance
    static NXAgentRevisionDelegate*  m_pInstance;

    NXAgentRevisionDelegate();
    virtual ~NXAgentRevisionDelegate();
    static void setInstance( NXAgentRevisionDelegate*  instance );


private:
    friend class  ::Teamcenter::NXAgentRevisionGenImpl;

};

#include <validation/libvalidation_undef.h>
#endif  //  TEAMCENTER__NXAGENTREVISIONDELEGATE_HXX
