//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, NXCheckMateRevisionDelegate
    Filename:   NXCheckMateRevisionDelegate.hxx
    Module:     validation
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__NXCHECKMATEREVISIONDELEGATE_HXX
#define TEAMCENTER__NXCHECKMATEREVISIONDELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <validation/NXCheckMateRevision.hxx>

#include <validation/libvalidation_exports.h>

namespace Teamcenter
{
    class NXCheckMateRevisionDelegate;
}
namespace Teamcenter
{
    class NXCheckMateRevisionImpl;
}
namespace Teamcenter
{
    class NXCheckMateRevision;
}
namespace Teamcenter
{
    class NXCheckMateRevisionGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  VALIDATION_API Teamcenter_alias::NXCheckMateRevisionDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the NXCheckMateRevisionDelegate instance
    static NXCheckMateRevisionDelegate&  getInstance();

    //  Method to create the NXCheckMateRevisionImpl pointer
    static NXCheckMateRevisionImpl*  createImpl( NXCheckMateRevision&  ifObj );

    //  Method to delete the NXCheckMateRevisionImpl pointer
    static void deleteImpl( NXCheckMateRevisionImpl*  impl );


    ///
    /// This operation will evaluate the compound result of given validation target objects and return the corresponding compound results via an output parameter.
    /// @version Teamcenter 8.2
    /// @param validationTargetObjects - A vector of validation target object tags whose compound result will be evaluated for this validation agent revision.
    /// @param compoundResult - The vector of corresponding compound results for the given vector of validation target objects.
    /// @return - The status code. ITK_ok indicates that the operation is successfully executed.
    ///
    int  evaluateCompoundResultBase(const NXCheckMateRevision &ifObj,  const std::vector< tag_t > &validationTargetObjects, std::vector< bool > &compoundResult );


    ///
    /// Finalize operation input.
    /// @version Teamcenter 10.1
    /// @param pReviseInput - desc
    /// @param vecDeepCopyData - desc
    /// @return - returns n int.
    ///
    int  finalizeReviseInputBase(const NXCheckMateRevision &ifObj,  ::Teamcenter::ReviseInput *pReviseInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );


    ///
    /// This operation is not supported now, there will be no support for issues stemming from uses of this operation.
    /// @version Teamcenter 11.2.2
    /// @param inputs - A vector of data that contains reference information to the object to be saved
    /// @param bd - A data structure to store objects and other information relevant for set-based operation
    /// @return - This operation returns ITK_ok on success. Otherwise, it will return specific error code.
    ///
    int  fnd0SaveBase( std::vector<  ::Teamcenter::BulkInput* > *inputs, ::Teamcenter::BulkData *bd );


    ///
    /// This ioperation will retun a vector of ValidationResult object tags via an ouput paramter.
    /// @version Teamcenter 8.2
    /// @param valDataRevisions - A vector of ValDataRevision objects that will be used to limit the scope of the ValidationResult  objects.
    /// @param selectedObjects - A vector of selected objects that the system will use to find the actual target objects. The resulting target objects will be used to find the associated ValidationResult objects.
    /// @param targetObjects - A vector objects that will be used to find the associated ValidationResult objects.
    /// @param validationResultObjects - A vector of ValidationResult tags that are found from the given inut criteria.
    /// @return - The status code. ITK_ok indicates that this operation is successfully executed.
    ///
    int  getValidationResultsBase(const NXCheckMateRevision &ifObj,  const std::vector< tag_t > &valDataRevisions, const std::vector< tag_t > &selectedObjects, const std::vector< tag_t > &targetObjects, std::vector< tag_t > &validationResultObjects );


    ///
    /// This operation will return a vector of validation target object tags via an output parameter.
    /// @version Teamcenter 8.2
    /// @param valDataRevisions - A vector of ValDataRevision objects that will be used to limit the scope of the targets.
    /// @param selectedObjects - A vector of selected objects that the system will use to find the actual target objects.
    /// @param targetObjects - A vector of target object tags that are found from the given input criteria.
    /// @return - The return status code. ITK_ok means thatthe operation is successfully executed.
    ///
    int  getValidationTargetsBase(const NXCheckMateRevision &ifObj,  const std::vector< tag_t > &valDataRevisions, const std::vector< tag_t > &selectedObjects, std::vector< tag_t > &targetObjects );


    ///
    /// This operation will perform the validation tasks. Each validation agent revision must implement this method to process the validation tasks.
    /// @version Teamcenter 8.2
    /// @param valDataRevisionObjects - A vector of ValDataRevision objects that will be used to validate against the validation targets
    /// @param selectedObjects - A vector of selected objects that this validation agent will use to find the actual validation targets for this validation run.
    /// @param targetObjects - A vector of validation targets for this validation run.
    /// @return - The status code returned from the run. TIK_ok indicates that the validation run is executed successfully.
    ///
    int  runValidationBase(const NXCheckMateRevision &ifObj,  const std::vector< tag_t > &valDataRevisionObjects, const std::vector< tag_t > &selectedObjects, const std::vector< tag_t > &targetObjects );


    ///
    /// desc for createPost
    /// @version Tc 8
    /// @param creInput - Description for the Create Input
    /// @return - return desc for createPost
    ///
    int  createPostBase(const NXCheckMateRevision &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// Description for the Finalize Create Input
    /// @version Tc 8
    /// @param creInput - desc for  creInput parameter
    /// @return - Return desc for Initialize for Create
    ///
    int  finalizeCreateInputBase(const NXCheckMateRevision &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// finalize operation input
    /// @version Teamcenter 9
    /// @param pSavAsInput - desc
    /// @param vecDeepCopyData - desc
    /// @return - returns an int
    ///
    int  finalizeSaveAsInputBase(const NXCheckMateRevision &ifObj,  ::Teamcenter::SaveAsInput *pSavAsInput, std::vector<  ::Teamcenter::DeepCopyData* > *vecDeepCopyData );


    ///
    /// desc for setPropertiesFromCreateInpu
    /// @version Tc 8
    /// @param creInput - Description for CreateInput
    /// @return - return desc for setPropertiesFromCreateInput
    ///
    int  setPropertiesFromCreateInputBase(const NXCheckMateRevision &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// desc for validate for create
    /// @version Tc 8
    /// @param creInput - desc for creInput parameter
    /// @return - ret desc for validate for create
    ///
    int  validateCreateInputBase(const NXCheckMateRevision &ifObj,  ::Teamcenter::CreateInput *creInput );



protected:
    //  Pointer to the instance
    static NXCheckMateRevisionDelegate*  m_pInstance;

    NXCheckMateRevisionDelegate();
    virtual ~NXCheckMateRevisionDelegate();
    static void setInstance( NXCheckMateRevisionDelegate*  instance );


private:
    friend class  ::Teamcenter::NXCheckMateRevisionGenImpl;

};

#include <validation/libvalidation_undef.h>
#endif  //  TEAMCENTER__NXCHECKMATEREVISIONDELEGATE_HXX
