//Copyright 2020 Siemens Digital Industries Software
//==================================================
//Copyright $2020.
//Siemens Product Lifecycle Management Software Inc.
//All Rights Reserved.
//==================================================
//Copyright 2020 Siemens Digital Industries Software

/*==================================================================================================
File description:
    This file contains the declaration for the Business Object, ValToolAgentRevisionDelegate
    Filename:   ValToolAgentRevisionDelegate.hxx
    Module:     validation
    @BMIDE autogenerated
==================================================================================================*/

#ifndef TEAMCENTER__VALTOOLAGENTREVISIONDELEGATE_HXX
#define TEAMCENTER__VALTOOLAGENTREVISIONDELEGATE_HXX

#include <common/tc_deprecation_macros.h>
#include <validation/ValToolAgentRevision.hxx>

#include <validation/libvalidation_exports.h>

namespace Teamcenter
{
    class ValToolAgentRevisionDelegate;
}
namespace Teamcenter
{
    class ValToolAgentRevisionImpl;
}
namespace Teamcenter
{
    class ValToolAgentRevision;
}
namespace Teamcenter
{
    class ValToolAgentRevisionGenImpl;
}

namespace Teamcenter_alias = ::Teamcenter;


class  VALIDATION_API Teamcenter_alias::ValToolAgentRevisionDelegate
{
public:
    //  Method to initialize this Class
    static int initializeClass();

    //  Method to get the ValToolAgentRevisionDelegate instance
    static ValToolAgentRevisionDelegate&  getInstance();

    //  Method to create the ValToolAgentRevisionImpl pointer
    static ValToolAgentRevisionImpl*  createImpl( ValToolAgentRevision&  ifObj );

    //  Method to delete the ValToolAgentRevisionImpl pointer
    static void deleteImpl( ValToolAgentRevisionImpl*  impl );


    ///
    /// Getter for an String Array Property
    /// @version Teamcenter 8.2
    /// @param values - Parameter value
    /// @param isNull - Returns true for an array element if the parameter value at that location is null
    /// @return - Status. 0 if successful
    ///
    int  getValidation_argumentsBase(const ValToolAgentRevision &ifObj,  std::vector< std::string > &values, std::vector< int > &isNull ) const;


    ///
    /// Setter for an string Array Property
    /// @version Teamcenter 8.2
    /// @param values - Values to be set for the parameter
    /// @param isNull - If array element is true, set the parameter value at that location as null
    /// @return - Status. 0 if successful
    ///
    int  setValidation_argumentsBase(ValToolAgentRevision &ifObj,  const std::vector< std::string > &values, const std::vector< int > *isNull );


    ///
    /// This operation will evaluate the compound result of given validation target objects and return the corresponding compound results via an output parameter.
    /// @version Teamcenter 8.2
    /// @param validationTargetObjects - A vector of validation target object tags whose compound result will be evaluated for this validation agent revision.
    /// @param compoundResult - The vector of corresponding compound results for the given vector of validation target objects.
    /// @return - The status code. ITK_ok indicates that the operation is successfully executed.
    ///
    int  evaluateCompoundResultBase(const ValToolAgentRevision &ifObj,  const std::vector< tag_t > &validationTargetObjects, std::vector< bool > &compoundResult );


    ///
    /// This ioperation will retun a vector of ValidationResult object tags via an ouput paramter.
    /// @version Teamcenter 8.2
    /// @param valDataRevisions - A vector of ValDataRevision objects that will be used to limit the scope of the ValidationResult  objects.
    /// @param selectedObjects - A vector of selected objects that the system will use to find the actual target objects. The resulting target objects will be used to find the associated ValidationResult objects.
    /// @param targetObjects - A vector objects that will be used to find the associated ValidationResult objects.
    /// @param validationResultObjects - A vector of ValidationResult tags that are found from the given inut criteria.
    /// @return - The status code. ITK_ok indicates that this operation is successfully executed.
    ///
    int  getValidationResultsBase(const ValToolAgentRevision &ifObj,  const std::vector< tag_t > &valDataRevisions, const std::vector< tag_t > &selectedObjects, const std::vector< tag_t > &targetObjects, std::vector< tag_t > &validationResultObjects );


    ///
    /// This operation will return a vector of validation target object tags via an output parameter.
    /// @version Teamcenter 8.2
    /// @param valDataRevisions - A vector of ValDataRevision objects that will be used to limit the scope of the targets.
    /// @param selectedObjects - A vector of selected objects that the system will use to find the actual target objects.
    /// @param targetObjects - A vector of target object tags that are found from the given input criteria.
    /// @return - The return status code. ITK_ok means thatthe operation is successfully executed.
    ///
    int  getValidationTargetsBase(const ValToolAgentRevision &ifObj,  const std::vector< tag_t > &valDataRevisions, const std::vector< tag_t > &selectedObjects, std::vector< tag_t > &targetObjects );


    ///
    /// This operation will perform the validation tasks. Each validation agent revision must implement this method to process the validation tasks.
    /// @version Teamcenter 8.2
    /// @param valDataRevisionObjects - A vector of ValDataRevision objects that will be used to validate against the validation targets
    /// @param selectedObjects - A vector of selected objects that this validation agent will use to find the actual validation targets for this validation run.
    /// @param targetObjects - A vector of validation targets for this validation run.
    /// @return - The status code returned from the run. TIK_ok indicates that the validation run is executed successfully.
    ///
    int  runValidationBase(const ValToolAgentRevision &ifObj,  const std::vector< tag_t > &valDataRevisionObjects, const std::vector< tag_t > &selectedObjects, const std::vector< tag_t > &targetObjects );


    ///
    /// desc for createPost
    /// @version Tc 8
    /// @param creInput - Description for the Create Input
    /// @return - return desc for createPost
    ///
    int  createPostBase(const ValToolAgentRevision &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// Description for the Finalize Create Input
    /// @version Tc 8
    /// @param creInput - desc for  creInput parameter
    /// @return - Return desc for Initialize for Create
    ///
    int  finalizeCreateInputBase(const ValToolAgentRevision &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// desc for setPropertiesFromCreateInpu
    /// @version Tc 8
    /// @param creInput - Description for CreateInput
    /// @return - return desc for setPropertiesFromCreateInput
    ///
    int  setPropertiesFromCreateInputBase(const ValToolAgentRevision &ifObj,  ::Teamcenter::CreateInput *creInput );


    ///
    /// desc for validate for create
    /// @version Tc 8
    /// @param creInput - desc for creInput parameter
    /// @return - ret desc for validate for create
    ///
    int  validateCreateInputBase(const ValToolAgentRevision &ifObj,  ::Teamcenter::CreateInput *creInput );



protected:
    //  Pointer to the instance
    static ValToolAgentRevisionDelegate*  m_pInstance;

    ValToolAgentRevisionDelegate();
    virtual ~ValToolAgentRevisionDelegate();
    static void setInstance( ValToolAgentRevisionDelegate*  instance );


private:
    friend class  ::Teamcenter::ValToolAgentRevisionGenImpl;

};

#include <validation/libvalidation_undef.h>
#endif  //  TEAMCENTER__VALTOOLAGENTREVISIONDELEGATE_HXX
